(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[     22353,        597]
NotebookOptionsPosition[     21606,        549]
NotebookOutlinePosition[     22078,        567]
CellTagsIndexPosition[     22035,        564]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Chapter 23 Entropy (p. 393)", "Title",
 InitializationCell->True,
 CellChangeTimes->{
  3.44307511577*^9, {3.4521374941477604`*^9, 3.4521374953297606`*^9}, {
   3.5311202189360676`*^9, 3.5311202206321645`*^9}, {3.587958675555621*^9, 
   3.5879586783478994`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "Lautrup`"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390206896411786*^9, 3.390206896721786*^9}, {
   3.4430751032139997`*^9, 3.4430751055150003`*^9}, 3.479282147012*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 23.3 Fluctuations (p. 398)\
\>", "Title",
 CellChangeTimes->{{3.452137571601761*^9, 3.452137587936761*^9}, {
  3.5026003204886*^9, 3.5026003268576*^9}, {3.5879586577483053`*^9, 
  3.5879586672754903`*^9}}],

Cell[CellGroupData[{

Cell["Margin table (p. 400)", "Section",
 CellChangeTimes->{{3.5026003486806*^9, 3.5026003629186*^9}, {
  3.587958649660303*^9, 3.587958655788063*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4521375755057607`*^9, 3.4521375784517603`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(14\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575609162034212*^9, 3.5866037180462255`*^9, 3.5866039271095066`*^9, 
   3.5879588999746027`*^9, 3.587958935047013*^9, 3.5879589734138384`*^9, {
   3.5879590217978544`*^9, 3.5879590459298787`*^9}}]
}, Open  ]],

Cell["Parameters for liquids", "Text",
 CellChangeTimes->{{3.5879586306598825`*^9, 3.587958632252082*^9}, {
  3.587958724035675*^9, 3.587958729491322*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"name", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Water\>\"", ",", "\"\<Ethanol\>\"", ",", "\"\<Glycerol\>\"", ",", 
     "\"\<Mercury\>\"", ",", "\"\<Bromine\>\""}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"liquid", " ", "names"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Mmol", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"18.", ",", "46.", ",", "92.", ",", "201", ",", "160"}], "}"}], 
    RowBox[{"Gram", "/", "Mole"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Molar", " ", "masses"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.0", ",", "0.79", ",", "1.26", ",", "13.5", ",", "3.10"}], 
     "}"}], 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", "densities", " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cp", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4.18", ",", "2.44", ",", "2.43", ",", "0.14", ",", "0.474"}], 
     "}"}], 
    RowBox[{
     RowBox[{"Joule", "/", "Kelvin"}], "/", "Gram"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "specific", " ", "heats", " ", "at", " ", "constant", " ", "pressure"}], 
   " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.21", ",", "0.75", ",", "0.49", ",", "0.18", ",", "1.12"}], 
     "}"}], 
    RowBox[{"Milli", "/", "Kelvin"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"thermal", " ", "expansivities"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.49", ",", "0.76", ",", "0.25", ",", "0.037", ",", "1.45"}], 
     "}"}], 
    RowBox[{"Nano", "/", "Pascal"}]}]}], " ", 
  RowBox[{"(*", " ", "compressibilities", " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4479955652358*^9, 3.4479955918958*^9}, 
   3.4479957795908003`*^9, {3.4480007837218*^9, 3.4480007973998003`*^9}, {
   3.4480019408157997`*^9, 3.4480019516317997`*^9}, {3.4480019929278*^9, 
   3.4480020184958*^9}, {3.4480020506238003`*^9, 3.4480020531028*^9}, {
   3.4480021222728*^9, 3.4480021798248*^9}, {3.4480023174268*^9, 
   3.4480023441108*^9}, {3.448083287060773*^9, 3.448083306291773*^9}, {
   3.4480834257007732`*^9, 3.4480834413807735`*^9}, {3.448083780220773*^9, 
   3.448083785108773*^9}, {3.448083955740773*^9, 3.4480839659017735`*^9}, {
   3.4480841267557735`*^9, 3.448084137204773*^9}, {3.4480843501347733`*^9, 
   3.448084367348773*^9}, 3.448084421655773*^9, {3.448084612492773*^9, 
   3.448084704973773*^9}, {3.448085162359773*^9, 3.448085164376773*^9}, {
   3.4480861738897734`*^9, 3.4480861870077734`*^9}, {3.448086273839773*^9, 
   3.4480863872327733`*^9}, {3.448086778945773*^9, 3.448086790494773*^9}, {
   3.448087455520773*^9, 3.4480874633097734`*^9}, {3.4480875051847734`*^9, 
   3.4480875342767735`*^9}, {3.4480916355487733`*^9, 3.448091658954773*^9}, {
   3.448091723445773*^9, 3.4480918654207735`*^9}, {3.448091961560773*^9, 
   3.448091967329773*^9}, {3.4481198578120003`*^9, 3.448119872102*^9}, {
   3.448120828334*^9, 3.448120829512*^9}, {3.448121347238*^9, 
   3.448121347514*^9}, {3.448121392215*^9, 3.448121438726*^9}, {
   3.4481214756099997`*^9, 3.448121485979*^9}, {3.4481580002501483`*^9, 
   3.4481580031641483`*^9}, {3.4481621331951485`*^9, 
   3.4481621353211484`*^9}, {3.448162205739148*^9, 3.4481622060431485`*^9}, {
   3.4481622833551483`*^9, 3.4481622845851483`*^9}, {3.4481628945561485`*^9, 
   3.4481628953881483`*^9}, {3.4481637813231487`*^9, 
   3.4481637821221485`*^9}, {3.4481639518201485`*^9, 
   3.4481639526501484`*^9}, {3.4481642329711485`*^9, 
   3.4481642344741488`*^9}, {3.448605045433*^9, 3.448605050212*^9}, 
   3.4492008684056187`*^9, {3.4521376273317604`*^9, 3.452137634929761*^9}, {
   3.4521377636687603`*^9, 3.452137766785761*^9}, {3.4521378666267605`*^9, 
   3.4521378784497604`*^9}, {3.4521379395087605`*^9, 
   3.4521379667377605`*^9}, {3.4521380146237607`*^9, 
   3.4521380211377606`*^9}, {3.4521380552657604`*^9, 3.4521380614537606`*^9}, 
   3.4521383063007603`*^9, {3.5879586817093177`*^9, 3.587958721742318*^9}, {
   3.587958755005481*^9, 3.5879587774622936`*^9}, {3.587958820517709*^9, 
   3.587958861565836*^9}}],

Cell["Specific gas constant", "Text",
 CellChangeTimes->{{3.4521383274737606`*^9, 3.4521383305127606`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rmol", "=", 
   RowBox[{"MolarGasConstant", "//", "ToSI"}]}], ";"}], "\n", 
 RowBox[{"R", "=", 
  FractionBox["Rmol", "Mmol"]}]}], "Input",
 CellChangeTimes->{{3.4521383331117606`*^9, 3.452138345318761*^9}, {
   3.586603851561031*^9, 3.586603865139737*^9}, 3.5866039196475716`*^9, {
   3.587958869910878*^9, 3.587958912341195*^9}, {3.58795898998787*^9, 
   3.587959004825762*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"461.9145611111111`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"180.7491760869565`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"90.37458804347825`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"41.36548308457711481428282353934363939292`5.743742898942648"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"51.96538812500000048544279707130044698656`5.743742898942648"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.587958900758735*^9, 3.5879589355911045`*^9}, {
  3.587958973992911*^9, 3.5879590465469685`*^9}}]
}, Open  ]],

Cell["Adiabatic ratio", "Text",
 CellChangeTimes->{{3.4481581941481485`*^9, 3.4481581992101483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"T", "=", 
   RowBox[{"300", "Kelvin"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], "T"}], 
     RowBox[{"\[Beta]", " ", "\[Rho]", " ", "cp"}]], "//", "ToSI"}]}], 
  ";"}], "\n", 
 RowBox[{"\[Gamma]", "=", 
  FractionBox["1", 
   RowBox[{"1", "-", "\[Delta]"}]]}]}], "Input",
 CellChangeTimes->{{3.448158206093148*^9, 3.4481582112451487`*^9}, {
  3.4481583227171483`*^9, 3.4481583310851483`*^9}, {3.4481583727501483`*^9, 
  3.4481584475121484`*^9}, {3.4481585150571485`*^9, 3.4481585353141484`*^9}, {
  3.4492005516146183`*^9, 3.4492006154376183`*^9}, {3.5879589449402857`*^9, 
  3.5879589555956244`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.0065013243438479`", ",", "1.1301856312093723`", ",", 
   "1.1038764385221078`", ",", "1.1614349775784754`", ",", 
   "1.2145116883561058`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5756091669668036`*^9, 3.586603720020474*^9, 3.586603929204842*^9, 
   3.5879589022269125`*^9, 3.5879589370463033`*^9, 3.5879589754120502`*^9, {
   3.5879590238171644`*^9, 3.5879590479421496`*^9}}]
}, Open  ]],

Cell["Heat capacity at constant volume", "Text",
 CellChangeTimes->{{3.452138378464761*^9, 3.4521383827207603`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cv", "=", 
  RowBox[{
   FractionBox["cp", "\[Gamma]"], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4521383849387608`*^9, 3.4521383895107603`*^9}, {
   3.587958963540603*^9, 3.5879589675150795`*^9}, 3.587959018180442*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"4153.`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"2158.9373750832783`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"2201.3333333333335`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"120.54054054054055`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"390.2803114571746`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.575609167252837*^9, 3.586603720062515*^9, 3.586603929226743*^9, 
   3.5879589022669306`*^9, 3.5879589370663013`*^9, {3.587958968590249*^9, 
   3.5879589754730935`*^9}, {3.587959023883117*^9, 3.587959048006163*^9}}]
}, Open  ]],

Cell["Fluctuation constants", "Text",
 CellChangeTimes->{{3.4521383960047607`*^9, 3.4521384078887606`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AT", "=", 
  RowBox[{
   SqrtBox[
    FractionBox["R", "cv"]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4521384098167605`*^9, 3.4521384429727607`*^9}, {
  3.4521384929237604`*^9, 3.4521384939607606`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3335030890483541`", ",", "0.2893464382685451`", ",", 
   "0.2026190432820923`", ",", "0.5858042025336904`", ",", 
   "0.36489571733739073`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5756091684789853`*^9, 3.5866037205255804`*^9, 3.586603929607831*^9, 
   3.5879589027229853`*^9, 3.587958937311285*^9, 3.5879589754920983`*^9, {
   3.587959024184196*^9, 3.5879590483192186`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A\[Rho]", "=", 
  RowBox[{
   SqrtBox[
    RowBox[{"\[Beta]", " ", "R", " ", "\[Rho]", " ", "T"}]], "//", 
   "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.452138422344761*^9, 3.4521384888237605`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.260579048435083`", ",", "0.18043431380084723`", ",", 
   "0.0924142768738072`", ",", "0.0787313002574191`", ",", 
   "0.2647174453763153`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.575609170498229*^9, 3.5866037216056805`*^9, 3.586603930435937*^9, 
   3.5879589037000837`*^9, 3.587958937997402*^9, 3.5879589761541405`*^9, {
   3.5879590250532646`*^9, 3.587959049138295*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"name", ",", "AT", ",", "A\[Rho]"}], "}"}], "//", "Transpose"}], "//",
   "TableForm"}]], "Input",
 CellChangeTimes->{{3.5026001227546*^9, 3.5026001953226*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Water\"\>", "0.3335030890483541`", "0.260579048435083`"},
    {"\<\"Ethanol\"\>", "0.2893464382685451`", "0.18043431380084723`"},
    {"\<\"Glycerol\"\>", "0.2026190432820923`", "0.0924142768738072`"},
    {"\<\"Mercury\"\>", "0.5858042025336904`", "0.0787313002574191`"},
    {"\<\"Bromine\"\>", "0.36489571733739073`", "0.2647174453763153`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.575609170653246*^9, 3.5866037216866827`*^9, 3.5866039304869127`*^9, 
   3.587958903748073*^9, 3.5879589380473676`*^9, 3.5879589762191486`*^9, {
   3.5879590251083097`*^9, 3.5879590491892824`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1048, 838},
WindowMargins->{{205, Automatic}, {Automatic, 59}},
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 268, 5, 65, "Title",
 InitializationCell->True],
Cell[1756, 42, 218, 4, 41, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2011, 51, 223, 5, 65, "Title"],
Cell[CellGroupData[{
Cell[2259, 60, 151, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[2435, 66, 129, 2, 41, "Input"],
Cell[2567, 70, 417, 10, 21, "Message"]
}, Open  ]],
Cell[2999, 83, 155, 2, 30, "Text"],
Cell[3157, 87, 4266, 91, 145, "Input"],
Cell[7426, 180, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[7558, 185, 416, 9, 77, "Input"],
Cell[7977, 196, 4497, 105, 43, "Output"]
}, Open  ]],
Cell[12489, 304, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[12615, 309, 750, 19, 119, "Input"],
Cell[13368, 330, 425, 9, 41, "Output"]
}, Open  ]],
Cell[13808, 342, 116, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[13949, 347, 251, 5, 56, "Input"],
Cell[14203, 354, 4526, 107, 43, "Output"]
}, Open  ]],
Cell[18744, 464, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18876, 469, 237, 6, 66, "Input"],
Cell[19116, 477, 424, 9, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19577, 491, 223, 6, 45, "Input"],
Cell[19803, 499, 421, 9, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20261, 513, 224, 6, 41, "Input"],
Cell[20488, 521, 1078, 23, 111, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature SvDNdxh1yBFXFAg5tiFa@CBj *)
