(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[    469666,       9209]
NotebookOptionsPosition[    456997,       8761]
NotebookOutlinePosition[    457491,       8780]
CellTagsIndexPosition[    457448,       8777]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Hydrostatic shapes", "Title",
 InitializationCell->True,
 CellChangeTimes->{3.4309104887455997`*^9}],

Cell["<<Lautrup`", "Input",
 PageWidth->Infinity,
 InitializationCell->True,
 CellChangeTimes->{{3.3961770879009137`*^9, 3.3961770884489136`*^9}, 
   3.3961786858489137`*^9, 3.479209087289*^9},
 ShowSpecialCharacters->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 4.2 The centrifugal force", "Title",
 CellChangeTimes->{{3.501738196579872*^9, 3.5017382121697645`*^9}, 
   3.575537837813204*^9}],

Cell[CellGroupData[{

Cell["Case: Newton's bucket", "Section",
 CellChangeTimes->{{3.5017382894891863`*^9, 3.5017382909372697`*^9}, 
   3.575537837813204*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{3.575537837814204*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(3\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.5755382106819444`*^9, 3.586581208313941*^9, 
  3.5869672123416877`*^9, 3.5869692199035683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{3.575537837825209*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalOmega]", "=", 
   RowBox[{"2", 
    RowBox[{"\[Pi]", "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"angular", " ", "frequency"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "=", 
    RowBox[{"10.", " ", "Centimeter"}]}], " ", 
   RowBox[{"(*", " ", "radius", " ", "*)"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", "AccelerationDueToGravity"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4032385264445767`*^9, 3.4664841508755655`*^9, 3.575537837826208*^9, 
   3.5869668442525215`*^9, {3.586966906716017*^9, 3.586966954907799*^9}, {
   3.5869670085782385`*^9, 3.5869670230999813`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Height at rim", "Subsection",
 CellChangeTimes->{3.5755378378302083`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", "=", 
  RowBox[{
   RowBox[{
    FractionBox[
     SuperscriptBox["\[CapitalOmega]", "2"], 
     RowBox[{"2", 
      SubscriptBox["g", "0"]}]], 
    SuperscriptBox["a", "2"]}], "//", 
   RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5755361761038227`*^9, 3.575536176795905*^9}, {
   3.575536637340165*^9, 3.5755366430208454`*^9}, 3.5755378378312063`*^9}],

Cell[BoxData[
 TemplateBox[{"2.012839124693827`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"cm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Centimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575538210963978*^9, 3.5865812084509363`*^9, 
  3.5869672126177206`*^9, 3.586969220156596*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4.1 Ultracentrifuge", "Section",
 CellChangeTimes->{{3.501738330192515*^9, 3.5017383389770174`*^9}, 
   3.5755378378412066`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{3.5755378378412066`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(4\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{{3.575538240268492*^9, 3.575538257656579*^9}, 
   3.5865812086089144`*^9, 3.5869672128737507`*^9, 3.586969220411625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5869681331461706`*^9, 3.5869681343443146`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", "AccelerationDueToGravity"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"10.", " ", "Centimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"radius", " ", "of", " ", "centrifuge"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{"1000.", " ", 
    RowBox[{"Kilogram", "/", 
     SuperscriptBox["Meter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"water", " ", "density"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[CapitalOmega]", "=", 
  RowBox[{
   RowBox[{"60000.", " ", "RPM"}], " ", "//", "ToSI", 
   RowBox[{"(*", " ", 
    RowBox[{"rotations", " ", "per", " ", "minute"}], " ", 
    "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.4664841795792074`*^9, 3.466484180316249*^9}, {
   3.466484238285565*^9, 3.4664842775648117`*^9}, {3.466484314761939*^9, 
   3.4664843219263487`*^9}, 3.5755378378462105`*^9, {3.586966963147787*^9, 
   3.586966996158747*^9}, {3.586967034111302*^9, 3.586967067534313*^9}, {
   3.5869676745911493`*^9, 3.5869676768134174`*^9}, 3.58696771399988*^9, {
   3.586968147171853*^9, 3.5869681737740445`*^9}, {3.587091414891181*^9, 
   3.5870914171114473`*^9}}],

Cell[BoxData[
 TemplateBox[{"6283.185307179587`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"per \"", "\[InvisibleSpace]", "\"second\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: reciprocal seconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["1", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5869681741380873`*^9, 3.586969220524638*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5869681860735235`*^9, 3.586968192727319*^9}}],

Cell["Acceleration at the rim", "Text",
 CellChangeTimes->{{3.586967133959282*^9, 3.5869671415761957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["\[CapitalOmega]", "2"]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{3.575537837852209*^9}],

Cell[BoxData[
 TemplateBox[{"3.9478417604357433`*^6"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            SuperscriptBox["\"s\"", "2"]}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meters per second squared"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", 
        SuperscriptBox["\"Seconds\"", "2"]]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.575538211524044*^9, 3.5755382579876204`*^9}, 
   3.5865812087449484`*^9, 3.58696721320479*^9, 3.586969220625651*^9}]
}, Open  ]],

Cell["g-factor", "Text",
 CellChangeTimes->{{3.586967158072176*^9, 3.586967160023408*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["g", 
  SubscriptBox["g", "0"]]], "Input",
 CellChangeTimes->{3.5755378378572106`*^9}],

Cell[BoxData["402567.8249387654`"], "Output",
 CellChangeTimes->{{3.575538211636057*^9, 3.5755382581006336`*^9}, 
   3.586581208801979*^9, 3.5869672133158035`*^9, 3.5869692207926702`*^9}]
}, Open  ]],

Cell["Pressure at the rim", "Text",
 CellChangeTimes->{{3.5869671812239532`*^9, 3.586967184055292*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    SubscriptBox["\[Rho]", "0"], 
    SuperscriptBox["\[CapitalOmega]", "2"], 
    SuperscriptBox["a", "2"]}], "//", 
   RowBox[{"ToUnit", "[", "Atmosphere", "]"}]}]}]], "Input",
 CellChangeTimes->{3.5755378378612103`*^9}],

Cell[BoxData[
 TemplateBox[{"1948.1084433435692`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"atm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: atmospheres"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Atmospheres\""}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.575538211909093*^9, 3.5755382583556643`*^9}, 
   3.5865812089409795`*^9, 3.586967213577834*^9, 3.5869692210507016`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 4.3 The figure of Earth", "Title",
 CellChangeTimes->{{3.501738767266514*^9, 3.5017387732648573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(5\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755383498826456`*^9, 3.5755388908595543`*^9, 3.575538961405019*^9, {
   3.575538997046294*^9, 3.575539021731258*^9}, 3.5865812091029997`*^9, 
   3.586967213841866*^9, {3.586969209844359*^9, 3.5869692213187337`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", 
   RowBox[{"AccelerationDueToGravity", "//", "N"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"EarthRadius", "//", "N"}]}], ";"}], "\n", 
 RowBox[{"\[CapitalOmega]", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"2", "\[Pi]"}], "SiderealDay"], "//", "ToSI", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"absolute", " ", "angular", " ", "rotation", " ", "rate"}], " ", 
    "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.394535773620536*^9, 3.394535845186536*^9}, 
   3.3946033082629385`*^9, {3.430281032777295*^9, 3.4302810398802958`*^9}, {
   3.5869674393909297`*^9, 3.586967472170863*^9}, {3.5869680848953824`*^9, 
   3.5869680866715937`*^9}}],

Cell[BoxData[
 TemplateBox[{"0.00007292115855306578`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"per \"", "\[InvisibleSpace]", "\"second\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: reciprocal seconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["1", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755383500336623`*^9, 3.5755388909465656`*^9, 3.575538961592041*^9, {
   3.575538997231316*^9, 3.5755390219112797`*^9}, 3.586581209127983*^9, 
   3.5869672138878727`*^9, {3.586969209979375*^9, 3.586969221364739*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.586968276536376*^9, 3.5869683011593285`*^9}}],

Cell["Ratio of centrifugal acceleration to standard gravity", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "=", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["\[CapitalOmega]", "2"], "a"}], 
    SubscriptBox["g", "0"]], "100", "Percent"}]}]], "Input",
 CellChangeTimes->{{3.57553894981863*^9, 3.5755390167046537`*^9}}],

Cell[BoxData[
 TemplateBox[{"0.34584403372260447`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"%\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: percent"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Percent\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755383501986837`*^9, 3.5755388911275854`*^9, {3.5755389546282053`*^9, 
   3.575539022105302*^9}, 3.5865812092630396`*^9, 3.586967214160904*^9, {
   3.5869692101743975`*^9, 3.586969221552762*^9}}]
}, Open  ]],

Cell[TextData[{
 "Earth\[CloseCurlyQuote]s levitation angular velocity (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"q", "=", "1"}], ")"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.501739110137125*^9, 3.501739138920771*^9}, {
  3.5017392342412233`*^9, 3.5017392410336123`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[CapitalOmega]", "0"], "=", 
  RowBox[{
   SqrtBox[
    FractionBox[
     SubscriptBox["g", "0"], "a"]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.430105373865345*^9, 3.430105403235345*^9}}],

Cell[BoxData[
 TemplateBox[{"0.0012399763901912288`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"per \"", "\[InvisibleSpace]", "\"second\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: reciprocal seconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["1", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575538350352702*^9, 3.575538891279606*^9, 3.5755389619210815`*^9, {
   3.575538997557358*^9, 3.575539022251321*^9}, 3.5865812093470483`*^9, 
   3.586967214321925*^9, {3.586969210339418*^9, 3.5869692216977797`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", "\[Pi]"}], 
   SubscriptBox["\[CapitalOmega]", "0"]], "//", 
  RowBox[{"ToUnit", "[", "Minute", "]"}]}]], "Input",
 CellChangeTimes->{{3.430105407158345*^9, 3.4301054410973454`*^9}}],

Cell[BoxData[
 TemplateBox[{"84.45302341886519`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"min\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: minutes"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Minutes\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575538350408709*^9, 3.575538891337613*^9, 3.575538961967087*^9, {
   3.575538997604362*^9, 3.5755390222983265`*^9}, 3.586581209376051*^9, 
   3.5869672144109335`*^9, {3.586969210397425*^9, 3.5869692217977934`*^9}}]
}, Open  ]],

Cell["Intuitive depth of polar \"valley\"", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", " ", "a"}], "//", 
  RowBox[{"ToUnit", "[", "Kilometer", "]"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"22.058406277153914`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755383504747167`*^9, 3.5755388913796167`*^9, 3.575538962009091*^9, {
   3.575538997641368*^9, 3.5755390223913364`*^9}, 3.586581209422058*^9, 
   3.5869672145229473`*^9, {3.5869692104974365`*^9, 3.5869692220498233`*^9}}]
}, Open  ]],

Cell["Actual centrifugal deformation", "Text",
 CellChangeTimes->{{3.5017401383049326`*^9, 3.501740155968943*^9}, 
   3.5017402686173863`*^9, 3.50174042778449*^9, {3.5017404629845037`*^9, 
   3.5017404657286606`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["a", "equator"], "=", 
   RowBox[{"6378.137", "Kilometer"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["a", "pole"], "=", 
   RowBox[{"6356.752", "Kilometer"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.430114312016*^9, 3.430114354083*^9}, {3.430114567535*^9,
    3.4301145861099997`*^9}, 3.430115192308*^9, 3.5017399832190623`*^9, {
   3.501740223066781*^9, 3.501740235076468*^9}, 3.5017402686183863`*^9, 
   3.50174042778549*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", "equator"], "-", 
  SubscriptBox["a", "pole"]}]], "Input",
 CellChangeTimes->{{3.43011458992*^9, 3.430114591909*^9}, 
   3.5017399832210627`*^9, {3.5017402382836514`*^9, 3.501740268620386*^9}, 
   3.5017404277874904`*^9}],

Cell[BoxData[
 TemplateBox[{"21.38499999999931`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755383505207205`*^9, 3.5755388914246225`*^9, 3.575538962058096*^9, {
   3.575538997691375*^9, 3.5755390224403434`*^9}, 3.586581209446062*^9, 
   3.586967214650963*^9, {3.586969210553442*^9, 3.586969222113829*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4.2 Rotating neutron star (pulsar)", "Section",
 CellChangeTimes->{{3.4031691133729696`*^9, 3.40316911620597*^9}, {
  3.5017393526489964`*^9, 3.501739369720972*^9}, {3.501739793153191*^9, 
  3.5017397932741985`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.40316913198197*^9, 3.4031691348789697`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(6\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755383507737527`*^9, 3.5755388916856537`*^9, 3.57553896232213*^9, {
   3.5755389979434032`*^9, 3.575539022691373*^9}, 3.5755392210951786`*^9, 
   3.5865812096020813`*^9, 3.586967214970001*^9, 3.586968499649146*^9, {
   3.586969210826476*^9, 3.5869692224808736`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.40316914090897*^9, 3.4031691425099697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", "GravitationalConstant"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalOmega]", "=", 
   FractionBox[
    RowBox[{"2", "\[Pi]"}], 
    RowBox[{"1.4", " ", "Milli", " ", "Second"}]]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"angular", " ", "frequency"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"10", " ", "Kilometer"}]}], " ", 
  RowBox[{"(*", " ", "radius", " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"M", "=", 
  RowBox[{"2", "SunMass", " ", 
   RowBox[{"(*", " ", "mass", " ", "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.4031691446059694`*^9, 3.4031691924309697`*^9}, {
  3.40316935745597*^9, 3.4031693709429693`*^9}, {3.40316943886397*^9, 
  3.4031694698559694`*^9}, {3.40316988870397*^9, 3.40316989215897*^9}, {
  3.40317002433597*^9, 3.40317002793497*^9}, {3.4031701795509696`*^9, 
  3.40317018430297*^9}, {3.5869676534256105`*^9, 3.5869676574530935`*^9}, {
  3.5869678269424295`*^9, 3.5869678296947594`*^9}, {3.586967884750367*^9, 
  3.586967911883622*^9}, {3.5869679493441167`*^9, 3.586967968111367*^9}}],

Cell[BoxData[
 TemplateBox[{"3.9782`*^30"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"kg\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilograms"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilograms\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5869679178683386`*^9, {3.586967949734163*^9, 3.5869679686164274`*^9}, 
   3.5869684997581577`*^9, {3.586969210881483*^9, 3.58696922253288*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalOmega]", "//", "ToSI"}]], "Input",
 CellChangeTimes->{{3.5017396515900946`*^9, 3.5017396607066154`*^9}}],

Cell[BoxData[
 TemplateBox[{"4487.9895051282765`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"per \"", "\[InvisibleSpace]", "\"second\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: reciprocal seconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["1", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575538350875763*^9, 3.5755388919146805`*^9, 3.5755389624181395`*^9, {
   3.5755389980344133`*^9, 3.5755390229184003`*^9}, 3.575539221330206*^9, 
   3.586581209652049*^9, 3.5869672160231276`*^9, 3.5869684998121643`*^9, {
   3.5869692109924965`*^9, 3.5869692225968876`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.586968397367872*^9, 3.5869683983749924`*^9}}],

Cell["Surface gravity", "Text",
 CellChangeTimes->{{3.4031694116789694`*^9, 3.4031694141739693`*^9}, {
   3.4031695522869697`*^9, 3.4031695999979696`*^9}, 3.586968411111521*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["g", "0"], "=", 
  RowBox[{
   FractionBox[
    RowBox[{"G", " ", "M"}], 
    SuperscriptBox["a", "2"]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.40316941865397*^9, 3.4031694734549694`*^9}}],

Cell[BoxData[
 TemplateBox[{"2.6549870288000005`*^12"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            SuperscriptBox["\"s\"", "2"]}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meters per second squared"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", 
        SuperscriptBox["\"Seconds\"", "2"]]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755383511137934`*^9, 3.5755388921777124`*^9, 3.5755389627781844`*^9, {
   3.5755389982644424`*^9, 3.5755390231864324`*^9}, 3.575539221558234*^9, 
   3.586581209774125*^9, 3.5869672163631687`*^9, {3.586968492995347*^9, 
   3.586968500049192*^9}, {3.586969211230523*^9, 3.58696922284892*^9}}]
}, Open  ]],

Cell["Centrifugal acceleration", "Text",
 CellChangeTimes->{{3.586968414234897*^9, 3.5869684182643814`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["g", "c"], "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CapitalOmega]", "2"], "a"}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4031696064319696`*^9, 3.40316961727897*^9}}],

Cell[BoxData[
 TemplateBox[{"2.0142049798141553`*^11"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            SuperscriptBox["\"s\"", "2"]}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meters per second squared"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", 
        SuperscriptBox["\"Seconds\"", "2"]]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575538351366824*^9, 3.5755388922857246`*^9, 3.575538962883197*^9, {
   3.575538998531473*^9, 3.5755390232954454`*^9}, 3.5755392216612463`*^9, 
   3.586581209826067*^9, 3.586967216502186*^9, {3.586968493170368*^9, 
   3.5869685001572065`*^9}, {3.5869692113435364`*^9, 3.5869692242670875`*^9}}]
}, Open  ]],

Cell["\<\
Centrifugal acceleration in units of surface gravity\
\>", "Text",
 CellChangeTimes->{{3.5869684588072443`*^9, 3.586968481143924*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "=", 
  RowBox[{
   FractionBox[
    SubscriptBox["g", "c"], 
    SubscriptBox["g", "0"]], "100", "Percent"}]}]], "Input",
 CellChangeTimes->{{3.40316967220597*^9, 3.40316968164697*^9}, {
  3.586968485199413*^9, 3.5869684882067723`*^9}}],

Cell[BoxData[
 TemplateBox[{"7.586496498721256`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"%\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: percent"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Percent\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755383515038404`*^9, 3.5755388924127407`*^9, 3.575538963002211*^9, {
   3.5755389986644897`*^9, 3.5755390234364624`*^9}, 3.5755392217792606`*^9, 
   3.586581209896077*^9, 3.5869672166572037`*^9, {3.586968488693831*^9, 
   3.5869685002792196`*^9}, {3.5869692114735537`*^9, 3.586969224506118*^9}}]
}, Open  ]],

Cell["\<\
Ratio of q for star and Earth (see above)\
\>", "Text",
 CellChangeTimes->{{3.5869685301218014`*^9, 3.5869685381197615`*^9}, {
  3.5869685743601093`*^9, 3.5869685770634327`*^9}, {3.5869686162341347`*^9, 
  3.5869686165191665`*^9}, {3.586968738423794*^9, 3.5869687408230815`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "/", 
  TemplateBox[{"0.3458"},
   "QuantityUnit",
   DisplayFunction->(TooltipBox[
     StyleBox[
      RowBox[{#, "\[InvisibleSpace]", 
        StyleBox[
         RowBox[{" ", 
           RowBox[{"\"%\""}]}], "QuantityUnitTraditionalLabel"]}], 
      ShowStringCharacters -> False], "Unit: percent"]& ),
   InterpretationFunction->(RowBox[{"Quantity", "[", 
      RowBox[{#, ",", "\"Percent\""}], "]"}]& )]}]], "Input",
 CellChangeTimes->{{3.4031702339829693`*^9, 3.4031702411029696`*^9}, {
  3.5017398568838367`*^9, 3.501739860459041*^9}, {3.5869685814589615`*^9, 
  3.586968591883211*^9}}],

Cell[BoxData["21.938971945405598`"], "Output",
 CellChangeTimes->{
  3.5755383515538464`*^9, 3.5755388924597464`*^9, 3.5755389630382156`*^9, {
   3.5755389987094955`*^9, 3.5755390234754667`*^9}, 3.575539221816264*^9, 
   3.586581209920082*^9, 3.5869672167812214`*^9, {3.586968493329387*^9, 
   3.586968500318226*^9}, 3.5869685925972977`*^9, {3.5869692115705643`*^9, 
   3.5869692246591353`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Centrifugal deformation of a spherical planet", "Section",
 CellChangeTimes->{{3.3946814792479353`*^9, 3.394681482992935*^9}, 
   3.394681995008935*^9, 3.5017404277954907`*^9, {3.5017404844577312`*^9, 
   3.5017404907850933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{3.5017404277954907`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(7\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755383518178787`*^9, 3.5755388927227783`*^9, 3.5755389633122478`*^9, {
   3.575538998980527*^9, 3.575539023751501*^9}, 3.5865812107532277`*^9, 
   3.5869672174122934`*^9, 3.586969031423951*^9, {3.5869692118435974`*^9, 
   3.5869692252031994`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.58696868304915*^9, 3.5869687124076824`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", "AccelerationDueToGravity"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a", "=", "EarthRadius"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", "5.5"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "density", " ", "of", " ", "Earth"}], " ", "*)"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "1"], "=", "4.5"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "mantle", " ", "density"}], " ", "*)"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"q", "=", 
   RowBox[{"0.35", " ", "Percent"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "centrifugal", " ", "acceleration", " ", "in", " ", "units", " ", "of", 
    " ", "surface", " ", "gravity"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.394603687079938*^9, 3.394603687461938*^9}, {
   3.4302887217052956`*^9, 3.4302888048892956`*^9}, {3.4302894577532954`*^9, 
   3.4302894770002956`*^9}, {3.4302897445872955`*^9, 
   3.4302897721682954`*^9}, {3.4304572702646084`*^9, 3.4304572964486084`*^9}, 
   3.5017404277964907`*^9, {3.5869687009012938`*^9, 3.586968702078434*^9}, {
   3.5869687880117455`*^9, 3.5869688661901236`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5869686936724243`*^9, 3.586968694647542*^9}}],

Cell["Centrifugal deformation range", "Text",
 CellChangeTimes->{{3.5869689362275286`*^9, 3.586968951847402*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "0"], "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " "}]], "q", " ", "a"}], "//", 
   RowBox[{"ToUnit", "[", "Kilometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.501740551188548*^9, 3.501740578686121*^9}}],

Cell[BoxData[
 TemplateBox[{"11.161739749999999`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575538351933892*^9, 3.5755388929738073`*^9, 3.5755389634222617`*^9, {
   3.5755389990865393`*^9, 3.575539023992528*^9}, 3.586581211370262*^9, 
   3.586967217579314*^9, 3.586969031616974*^9, {3.58696921195461*^9, 
   3.5869692253382177`*^9}}]
}, Open  ]],

Cell["Correction factor", "Text",
 CellChangeTimes->{{3.586968979400709*^9, 3.586968982056028*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{"1", "-", 
    RowBox[{
     FractionBox["3", "5"], 
     FractionBox[
      SubscriptBox["\[Rho]", "1"], 
      SubscriptBox["\[Rho]", "0"]]}]}], ")"}], 
  RowBox[{"-", "1"}]]], "Input",
 CellChangeTimes->{
  3.5017404277964907`*^9, {3.5869690200325837`*^9, 3.5869690244431133`*^9}}],

Cell[BoxData["1.9642857142857144`"], "Output",
 CellChangeTimes->{
  3.5755383519718966`*^9, 3.5755388930128126`*^9, 3.5755389636302867`*^9, {
   3.575538999124544*^9, 3.575539024029532*^9}, 3.5865812114402905`*^9, 
   3.5869672176203194`*^9, {3.5869690260453043`*^9, 3.586969031659979*^9}, {
   3.5869692120656257`*^9, 3.586969225805273*^9}}]
}, Open  ]],

Cell["\<\
Corrected centrifugal deformation range\
\>", "Text",
 CellChangeTimes->{{3.5869689956716595`*^9, 3.586969005287814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["h", "0"], "=", 
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " "}]], "q", " ", "a"}], 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["3", "5"], 
      FractionBox[
       SubscriptBox["\[Rho]", "1"], 
       SubscriptBox["\[Rho]", "0"]]}]}]], "//", 
   RowBox[{"ToUnit", "[", "Kilometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4302887501392956`*^9, 3.4302887548262954`*^9}, {
   3.430457282367608*^9, 3.4304572872816086`*^9}, 3.501740427797491*^9}],

Cell[BoxData[
 TemplateBox[{"21.9248459375`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575538352071907*^9, 3.5755388931218266`*^9, 3.575538963735297*^9, {
   3.575538999219556*^9, 3.575539024125543*^9}, 3.5865812115442867`*^9, 
   3.586967217734334*^9, 3.586969031755989*^9, {3.5869692121686363`*^9, 
   3.5869692259182854`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proof of eq. (4.11)", "Section",
 CellChangeTimes->{{3.5017418966655054`*^9, 3.5017418973685455`*^9}, {
  3.586969085431429*^9, 3.5869690859754953`*^9}, {3.586969162727705*^9, 
  3.586969169639536*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.430104899551345*^9, 3.430104902689345*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(5\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575538352322938*^9, 3.575538893381858*^9, 3.575538964023332*^9, {
   3.5755389994775867`*^9, 3.5755390243855762`*^9}, 3.5865812126324596`*^9, 
   3.5869672180173674`*^9, 3.586969032022022*^9, {3.5869692124346685`*^9, 
   3.5869692268413982`*^9}}]
}, Open  ]],

Cell[TextData[{
 "Put ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{"cos", " ", "\[Theta]"}]}], TraditionalForm]]],
 " and calculate integral"
}], "Text",
 CellChangeTimes->{{3.5017422430573177`*^9, 3.5017422529068813`*^9}, {
  3.5869692574010673`*^9, 3.5869692609354877`*^9}, {3.587016137453381*^9, 
  3.5870161378664303`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", 
   RowBox[{"-", "1"}], "1"], 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["c", "2"], 
      SuperscriptBox["u", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["c", "2"]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["u", "2"]}], ")"}]}], "-", 
     FractionBox["1", "3"]}], 
    SqrtBox[
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", "u"}], ")"}]}]]], 
   RowBox[{"\[DifferentialD]", "u"}]}]}]], "Input",
 CellChangeTimes->{{3.43062421213161*^9, 3.4306243841966095`*^9}, {
  3.4306254788136096`*^9, 3.4306254805846095`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["2", "15"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["c", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5755383562184067`*^9, 3.5755388965982456`*^9, 3.575538964734419*^9, {
   3.5755390002886834`*^9, 3.575539025049656*^9}, 3.5865812156548166`*^9, 
   3.586967221125741*^9, 3.5869690327141037`*^9, {3.586969213120752*^9, 
   3.5869692276354914`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 4.4 The Earth, the Moon, and the tides", "Title",
 CellChangeTimes->{{3.5017388907655773`*^9, 3.501738892175658*^9}, {
  3.501740872360918*^9, 3.5017408823214884`*^9}}],

Cell[CellGroupData[{

Cell["The tidal field", "Section",
 CellChangeTimes->{{3.5017411395061984`*^9, 3.5017411432404118`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.501741146460596*^9, 3.5017411498677907`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(1\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.5755393703820896`*^9, 3.5755394639573174`*^9, 
  3.586581216105897*^9, 3.586967221488783*^9, 3.5869692288466377`*^9, 
  3.587092651067505*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5870162771641455`*^9, 3.587016278874349*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", 
   RowBox[{"GravitationalConstant", "//", "ToSI"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"EarthRadius", "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", "=", 
   RowBox[{"MoonOrbitRadius", "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", " ", "=", " ", 
   RowBox[{"MoonMass", "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", " ", "=", " ", 
   RowBox[{"EarthMass", "//", "N"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5017411769083376`*^9, 3.5017411851398087`*^9}, {
  3.5017413636040163`*^9, 3.501741364619074*^9}, {3.5755394581536217`*^9, 
  3.5755394594837804`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5870162873073626`*^9, 3.58701628881054*^9}}],

Cell["Distance of CM from center of Earth", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "=", 
  RowBox[{
   RowBox[{"DD", " ", 
    FractionBox["m", 
     RowBox[{"m", "+", "M"}]]}], "//", 
   RowBox[{"ToUnit", "[", "Kilometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.575539529084132*^9, 3.5755395318584657`*^9}}],

Cell[BoxData[
 TemplateBox[{"4672.250467672661`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575539370717129*^9, 3.575539464258355*^9, 
  3.5755395365700293`*^9, 3.586581216222912*^9, 3.586967221676806*^9, 
  3.5869692301857996`*^9, 3.587092651275529*^9}]
}, Open  ]],

Cell["\<\
Depth of center-of-mass of Earth-Moon system\
\>", "Text",
 CellChangeTimes->{{3.5870163055165467`*^9, 3.587016311196229*^9}, {
  3.58701639938781*^9, 3.587016409883068*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "-", "d"}], "//", 
  RowBox[{"ToUnit", "[", "Kilometer", "]"}]}]], "Input",
 CellChangeTimes->{{3.5755395612900143`*^9, 3.57553956189707*^9}}],

Cell[BoxData[
 TemplateBox[{"1705.8865323273385`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755393708081408`*^9, 3.5755394643533664`*^9, 
  3.5755395626441603`*^9, 3.586581216294947*^9, 3.586967221794821*^9, 
  3.5869692303848248`*^9, 3.5870926513655405`*^9}]
}, Open  ]],

Cell["\<\
Uniform (non-tidal) Moon acceleration field acting on Earth\
\>", "Text",
 CellChangeTimes->{{3.501741405180394*^9, 3.5017414268166313`*^9}, {
  3.58701642865132*^9, 3.5870164313706474`*^9}, {3.5870164616752834`*^9, 
  3.587016463530506*^9}, {3.5870165630994525`*^9, 3.5870165919459133`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"G", " ", "m"}], 
   SuperscriptBox["DD", "2"]], "//", 
  RowBox[{"ToUnit", "[", "Micrometer", "]"}]}]], "Input",
 CellChangeTimes->{{3.5017411948403635`*^9, 3.5017412325405197`*^9}}],

Cell[BoxData[
 TemplateBox[{"33.18896058870014`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"\[Micro]m\"", "\[InvisibleSpace]", "\"/\"", 
            "\[InvisibleSpace]", 
            SuperscriptBox["\"s\"", "2"]}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: micrometers per second squared"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Micrometers\"", 
        SuperscriptBox["\"Seconds\"", "2"]]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755393711031785`*^9, 3.5755394646223993`*^9, 
  3.586581216718953*^9, 3.5869672220828557`*^9, 3.5869692307328634`*^9, 
  3.587092651644574*^9}]
}, Open  ]],

Cell["Scale of tidal Moon field", "Text",
 CellChangeTimes->{{3.5017414333840075`*^9, 3.5017414370412164`*^9}, {
  3.587016744690242*^9, 3.5870167470025177`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", "a", " ", "G", " ", "m"}], 
   RowBox[{
    SuperscriptBox["DD", "3"], " "}]], "//", 
  RowBox[{"ToUnit", "[", "Micrometer", "]"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"1.6520540075779993`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"\[Micro]m\"", "\[InvisibleSpace]", "\"/\"", 
            "\[InvisibleSpace]", 
            SuperscriptBox["\"s\"", "2"]}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: micrometers per second squared"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Micrometers\"", 
        SuperscriptBox["\"Seconds\"", "2"]]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755393714732203`*^9, 3.5755394650294456`*^9, 
  3.5865812170309715`*^9, 3.5869672225739145`*^9, 3.586969232292054*^9, 
  3.587092652063622*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tidal range", "Section"],

Cell["Tidal constant", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["H", "0"], "=", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], "a", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["a", "DD"], ")"}], "3"], 
    FractionBox["m", "M"]}], "//", 
   RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5017410922724967`*^9, 3.5017410974957952`*^9}}],

Cell[BoxData[
 TemplateBox[{"53.77318290302951`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"cm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Centimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575539597824379*^9, 3.5865812171590443`*^9, 
  3.586967223011969*^9, 3.5869692328211155`*^9, 3.5870926522976503`*^9}]
}, Open  ]],

Cell["\<\
Influence of tidal range self-potential\
\>", "Text",
 CellChangeTimes->{{3.3946814792479353`*^9, 3.394681482992935*^9}, {
  3.394681990400935*^9, 3.3946819921609354`*^9}, {3.394682148720935*^9, 
  3.394682150272935*^9}, {3.5017416569627953`*^9, 3.501741659095917*^9}, {
  3.5870172666028624`*^9, 3.5870172699942694`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Rho]", "1"], "=", 
    RowBox[{"1.0", " ", 
     RowBox[{"Kilogram", "/", 
      SuperscriptBox["Meter", "3"]}]}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"water", " ", "density"}], " ", "*)"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{"5.5", " ", 
    RowBox[{"Kilogram", "/", 
     SuperscriptBox["Meter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "density", " ", "of", " ", "Earth"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.394603687079938*^9, 3.394603687461938*^9}, {
  3.3946821585639353`*^9, 3.394682159809935*^9}, {3.430711263271407*^9, 
  3.430711269012407*^9}, {3.5017417144200816`*^9, 3.501741760077693*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", 
   RowBox[{
    FractionBox["3", "5"], 
    FractionBox[
     SubscriptBox["\[Rho]", "1"], 
     SubscriptBox["\[Rho]", "0"]]}]}]]], "Input",
 CellChangeTimes->{{3.3946821862419353`*^9, 3.394682206034935*^9}, {
  3.430711284254407*^9, 3.4307113203504066`*^9}}],

Cell[BoxData["1.1224489795918369`"], "Output",
 CellChangeTimes->{3.5755395982854347`*^9, 3.586581217535077*^9, 
  3.5869672233390074`*^9, 3.586969233817235*^9, 3.587092652596686*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tidal cycles", "Section",
 CellChangeTimes->{{3.501744602041244*^9, 3.5017446039123507`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4303796650230246`*^9, 3.4303796680930247`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(9\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.5755396439039087`*^9, 3.5865812177841063`*^9, 
  3.5869672236110387`*^9, 3.5869692342932916`*^9, 3.587092652860718*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coefficients", "Subsection",
 CellChangeTimes->{{3.4304523039746084`*^9, 3.4304523055606084`*^9}}],

Cell["Use \[Psi] = \[CapitalOmega] t+ \[Phi] to write", "Text",
 CellChangeTimes->{{3.5870175236767073`*^9, 3.5870175524581614`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cos\[Theta]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "\[Delta]", "]"}], 
     RowBox[{"Sin", "[", "\[Delta]0", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Delta]", "]"}], 
     RowBox[{"Cos", "[", "\[Delta]0", "]"}], 
     RowBox[{"Cos", "[", "\[Psi]", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4303797052110248`*^9, 3.430379755295025*^9}}],

Cell[TextData[{
 "Take ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["h", "0"], "=", 
    RowBox[{"1", " ", "to", " ", "get"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5870175656267414`*^9, 3.5870175809715824`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox["cos\[Theta]", "2"], "-", 
    FractionBox["1", "3"]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.430379674864025*^9, 3.4303797021740246`*^9}, {
  3.430379767183025*^9, 3.4303798870230246`*^9}, {3.430379919953025*^9, 
  3.430379946848025*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "3"]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]0", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Psi]", "]"}], "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", "\[Delta]", "]"}], " ", 
   RowBox[{"Cos", "[", "\[Delta]0", "]"}], " ", 
   RowBox[{"Cos", "[", "\[Psi]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Delta]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Delta]0", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Delta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Delta]0", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.5755396441159334`*^9, 3.586581219480283*^9, 
  3.586967223733054*^9, 3.5869692343402977`*^9, 3.587092652900723*^9}]
}, Open  ]],

Cell["Simplify the squared cosine", "Text",
 CellChangeTimes->{{3.587017587404356*^9, 3.587017599994866*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "//.", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cos", "[", "\[Psi]", "]"}], "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"2", "\[Psi]"}], "]"}], "+", "1"}], "2"]}]}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.430379948703025*^9, 3.430379956734025*^9}, {
  3.430380254208025*^9, 3.430380259503025*^9}, {3.430380524319025*^9, 
  3.430380524815025*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "3"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]0", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]0", "]"}], "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "\[Psi]"}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", "\[Delta]", "]"}], " ", 
   RowBox[{"Cos", "[", "\[Delta]0", "]"}], " ", 
   RowBox[{"Cos", "[", "\[Psi]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Delta]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Delta]0", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Delta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Delta]0", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.575539644155939*^9, 3.5865812195503445`*^9, 
  3.58696722378006*^9, 3.5869692343923025`*^9, 3.587092652933728*^9}]
}, Open  ]],

Cell[TextData[{
 "Check the expression for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5870176159637804`*^9, 3.5870176443831935`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "3"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "\[Delta]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "\[Delta]0", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Delta]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Delta]0", "]"}], "2"]}]}], "\[Equal]", 
   RowBox[{
    FractionBox["3", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Delta]", "]"}], "2"], "-", 
      FractionBox["1", "3"]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Delta]0", "]"}], "2"], "-", 
      FractionBox["1", "3"]}], ")"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.430380274656025*^9, 3.4303804024310246`*^9}, {
  3.430380528833025*^9, 3.430380529184025*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5755396442689514`*^9, 3.5865812196483436`*^9, 
  3.586967223862071*^9, 3.586969234484313*^9, 3.5870926530367393`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4.3 The Stanford Experiment and Figure 4.1", "Section",
 CellChangeTimes->{{3.430379659727025*^9, 3.4303796628760247`*^9}, {
  3.501744566921235*^9, 3.501744580168993*^9}, {3.5017454798804536`*^9, 
  3.5017454846727276`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4304524101856084`*^9, 3.4304524132636085`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(33\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.5755396519038696`*^9, 3.5865812206974325`*^9, 
  3.586967224144102*^9, 3.5869692347593465`*^9, 3.5870926532957706`*^9, 
  3.5870932842924843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5054081372385683`*^9, 3.50540814530903*^9}, {
  3.5870176749588604`*^9, 3.5870176761860056`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]", "=", 
   RowBox[{"37.4", "Degree"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Stanford", " ", "latitude"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]0", "=", 
   RowBox[{"20.", " ", "Degree"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"lunar", " ", "latitude", " ", 
    RowBox[{"(", "guess", ")"}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h0", "=", 
   RowBox[{"90", "Centimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"tidal", " ", "range", " ", 
    RowBox[{"(", "guess", ")"}]}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a", "=", "18"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"start", " ", "time"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"a", "+", "56"}]}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"finish", " ", "time"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LunarDay", "=", 
   RowBox[{"24.8379", "Hour"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.430452318077608*^9, 3.4304523195346084`*^9}, {
   3.4304524753366084`*^9, 3.430452522615608*^9}, {3.430452586398608*^9, 
   3.4304525879396086`*^9}, {3.430452996405608*^9, 3.430452999084608*^9}, {
   3.4304530611186085`*^9, 3.4304531397086086`*^9}, {3.4304532304076085`*^9, 
   3.4304532306876087`*^9}, 3.4304533721546087`*^9, {3.4304536425506086`*^9, 
   3.4304536918826084`*^9}, {3.4304538470946083`*^9, 
   3.4304538473706083`*^9}, {3.4304538813076086`*^9, 
   3.4304538820086083`*^9}, {3.430453913537608*^9, 3.4304539156306086`*^9}, {
   3.4304539605486083`*^9, 3.4304539644426084`*^9}, {3.4304547761256084`*^9, 
   3.4304548112786083`*^9}, {3.4304550163626084`*^9, 
   3.4304550600466084`*^9}, {3.4304551266796083`*^9, 3.430455127294608*^9}, {
   3.4304555854936085`*^9, 3.430455586457608*^9}, {3.4304556338406086`*^9, 
   3.430455660188608*^9}, {3.4304557228146086`*^9, 3.4304557546196084`*^9}, {
   3.4304559328516083`*^9, 3.4304559334366083`*^9}, 3.430456406740608*^9, 
   3.4304575508356085`*^9, {3.4304576207236085`*^9, 3.430457634016608*^9}, {
   3.4304593573776083`*^9, 3.4304593576266084`*^9}, {3.4304593929286084`*^9, 
   3.4304593932596083`*^9}, {3.4304594245426083`*^9, 3.430459444023608*^9}, {
   3.4304781990100126`*^9, 3.4304781994200125`*^9}, {3.430489812931012*^9, 
   3.4304899205970125`*^9}, {3.4304899561180124`*^9, 
   3.4304899562880125`*^9}, {3.4304901500410123`*^9, 
   3.4304901843940125`*^9}, {3.430490700577012*^9, 3.43049081056*^9}, {
   3.430490864977*^9, 3.430490898441*^9}, {3.430493949023*^9, 
   3.4304939492980003`*^9}, {3.430493994766*^9, 3.4304940525810003`*^9}, {
   3.430494437539*^9, 3.4304944643900003`*^9}, {3.430494868374*^9, 
   3.4304948744700003`*^9}, {3.430494931828*^9, 3.430494936646*^9}, {
   3.4304949952869997`*^9, 3.430495043322*^9}, {3.43049561626*^9, 
   3.430495655627*^9}, {3.430497991759*^9, 3.430498017657*^9}, {
   3.430498058972*^9, 3.4304980592650003`*^9}, {3.430498089535*^9, 
   3.4304982171029997`*^9}, {3.4304982638190002`*^9, 3.430498286837*^9}, {
   3.4304983562019997`*^9, 3.430498376324*^9}, {3.501744084044616*^9, 
   3.501744113099278*^9}, {3.501744158364867*^9, 3.501744184347353*^9}, {
   3.50174501597992*^9, 3.501745081226652*^9}, {3.501745191643967*^9, 
   3.5017452199155846`*^9}, {3.5017455673204546`*^9, 
   3.5017456851011915`*^9}, {3.587017736974304*^9, 3.5870177446732244`*^9}, {
   3.5870177860151854`*^9, 3.5870178137305107`*^9}, {3.587017852175124*^9, 
   3.5870178691541605`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5870914943437157`*^9, 3.587091495333832*^9}}],

Cell[TextData[{
 "Radial gravity in units of standard gravity  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Gamma]", "=", 
    RowBox[{
     SubscriptBox["g", "r"], "/", 
     SubscriptBox["g", "0"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " "
}], "Text",
 CellChangeTimes->{{3.5870919616237803`*^9, 3.5870920232931848`*^9}, {
  3.587092125064392*^9, 3.5870921762205286`*^9}, {3.5870922091254773`*^9, 
  3.5870922376048937`*^9}, {3.587092470696863*^9, 3.5870924788048344`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "h0"}], 
    RowBox[{"EarthRadius", " "}]], " ", "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4304533786386085`*^9, 3.430453395063608*^9}, {
   3.4304556815696087`*^9, 3.4304556818126087`*^9}, {3.430456946516608*^9, 
   3.430456966740608*^9}, 3.4304939609440002`*^9, {3.4304949657869997`*^9, 
   3.430494968113*^9}}],

Cell[BoxData["2.8221406971973163950539162140936`8.*^-7"], "Output",
 CellChangeTimes->{3.5755396521949043`*^9, 3.586581221000511*^9, 
  3.586967224271117*^9, 3.5869692349703712`*^9, 3.5870926534607906`*^9, 
  3.5870932845395117`*^9}]
}, Open  ]],

Cell["Lunar angular frequency", "Text",
 CellChangeTimes->{{3.587092251542568*^9, 3.5870922654142327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalOmega]", "=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "LunarDay"], "//", 
    RowBox[{"ToUnit", "[", 
     RowBox[{"1", "/", "Hour"}], "]"}]}], "//", "NoUnit"}]}]], "Input",
 CellChangeTimes->{{3.430452318077608*^9, 3.4304523195346084`*^9}, {
   3.4304524753366084`*^9, 3.430452522615608*^9}, {3.430452586398608*^9, 
   3.4304525879396086`*^9}, {3.430452996405608*^9, 3.430452999084608*^9}, {
   3.4304530611186085`*^9, 3.4304531397086086`*^9}, {3.4304532304076085`*^9, 
   3.4304532306876087`*^9}, 3.4304533721546087`*^9, {3.430454460681608*^9, 
   3.4304544752316084`*^9}, {3.5017448955040293`*^9, 3.501744899580262*^9}, {
   3.501744943935799*^9, 3.501744953901369*^9}, {3.5017450919492655`*^9, 
   3.501745096501526*^9}, {3.5052909355298204`*^9, 3.5052909397540617`*^9}}],

Cell[BoxData["0.2529676545593462`"], "Output",
 CellChangeTimes->{3.575539652264911*^9, 3.586581221072481*^9, 
  3.5869672243421254`*^9, 3.586969235053383*^9, 3.587092653521797*^9, 
  3.5870932846035194`*^9}]
}, Open  ]],

Cell["\<\
Coefficients of null potential surface (4.21)\
\>", "Text",
 CellChangeTimes->{{3.587092281030106*^9, 3.587092282902331*^9}, {
  3.587092399030265*^9, 3.587092417878525*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A0", "=", 
  RowBox[{
   FractionBox["3", "2"], 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Delta]", "]"}], "2"], "-", 
     FractionBox["1", "3"]}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Delta]0", "]"}], "2"], "-", 
     FractionBox["1", "3"]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.430452554424608*^9, 3.4304525819156084`*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.011544324799402376`"}]], "Output",
 CellChangeTimes->{3.5755396523149176`*^9, 3.5865812214795723`*^9, 
  3.586967224383131*^9, 3.586969235096389*^9, 3.5870926535538025`*^9, 
  3.5870932846415234`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A1", "=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"Sin", "[", 
    RowBox[{"2", "\[Delta]"}], "]"}], 
   RowBox[{"Sin", "[", 
    RowBox[{"2", "\[Delta]0"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4304526234896083`*^9, 3.430452657275608*^9}}],

Cell[BoxData["0.31015032289497024`"], "Output",
 CellChangeTimes->{3.575539652356922*^9, 3.586581222063647*^9, 
  3.586967224426136*^9, 3.5869692351503935`*^9, 3.5870926535858054`*^9, 
  3.5870932846755285`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A2", "=", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Delta]0", "]"}], "2"]}]}]], "Input",
 CellChangeTimes->{{3.4304526610786085`*^9, 3.4304526774956083`*^9}}],

Cell[BoxData["0.2786352731379508`"], "Output",
 CellChangeTimes->{3.5755396523939266`*^9, 3.5865812221856194`*^9, 
  3.586967224469141*^9, 3.5869692352024*^9, 3.587092653618811*^9, 
  3.5870932847085304`*^9}]
}, Open  ]],

Cell[TextData[{
 "Change in strength of gravity relative to standard gravity ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"here", " ", "-", 
     SubscriptBox["g", "0"]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.4304577796776085`*^9, 3.430457792018608*^9}, {
  3.430494903083*^9, 3.430494903784*^9}, {3.5870924299899793`*^9, 
  3.5870924473980684`*^9}, {3.587092496021901*^9, 3.587092528194762*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{"-", "\[Gamma]"}], 
     RowBox[{"(", 
      RowBox[{"A0", "+", 
       RowBox[{"A1", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[CapitalOmega]", " ", "t"}], "]"}]}], "+", 
       RowBox[{"A2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"\[CapitalOmega]", " ", "t"}], ")"}]}], "]"}]}]}], 
      ")"}]}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.4304526862716084`*^9, 3.4304526909106083`*^9}, {
   3.4304529581646085`*^9, 3.4304529880976086`*^9}, 3.4304531183316083`*^9, {
   3.4304532084586086`*^9, 3.4304532172186084`*^9}, {3.430453307966608*^9, 
   3.4304533172536087`*^9}, {3.430453404478608*^9, 3.4304534052126083`*^9}, 
   3.4304534361586084`*^9, {3.4304544843296084`*^9, 3.4304544957696085`*^9}, {
   3.430454815049608*^9, 3.4304548285156083`*^9}, {3.4304577626376085`*^9, 
   3.4304577877986083`*^9}, {3.4304944741809998`*^9, 3.430494477516*^9}}],

Cell["Plot of calculated g[t] ", "Text",
 CellChangeTimes->{{3.58709254552684*^9, 3.587092598230166*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figa", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t", "]"}], 
     SuperscriptBox["10", "9"]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "a", ",", "b"}], "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "250"}], ",", "150"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", "Black"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4304531954816084`*^9, 3.4304532070986085`*^9}, {
   3.4304532384366083`*^9, 3.430453248952608*^9}, {3.4304532831726084`*^9, 
   3.4304532882846084`*^9}, {3.4304533226096087`*^9, 3.4304533458946085`*^9}, 
   3.4304535008026085`*^9, 3.430453652400608*^9, {3.4304540931186085`*^9, 
   3.430454189464608*^9}, {3.4304544984256086`*^9, 3.4304545453556085`*^9}, {
   3.4304546383176084`*^9, 3.430454666853608*^9}, {3.4304548422086086`*^9, 
   3.4304548553046083`*^9}, {3.4304548925406084`*^9, 3.4304549850226088`*^9}, 
   3.4304550715336084`*^9, 3.4304551498426085`*^9, {3.4304558815486083`*^9, 
   3.4304559057926083`*^9}, {3.430457563016608*^9, 3.4304575673006086`*^9}, {
   3.4304578325646086`*^9, 3.430457899655608*^9}, {3.4304579500726085`*^9, 
   3.4304581638826084`*^9}, 3.4304582320986085`*^9, {3.4304592901806087`*^9, 
   3.4304592911216087`*^9}, {3.4304593351876087`*^9, 
   3.4304593395606084`*^9}, {3.4304779852810125`*^9, 
   3.4304779924680123`*^9}, {3.430478108412012*^9, 3.4304781220460124`*^9}, {
   3.430489356610012*^9, 3.4304893814910126`*^9}, {3.4304894124820127`*^9, 
   3.4304894619340124`*^9}, {3.4304895248020124`*^9, 3.430489533318012*^9}, {
   3.4304896377480125`*^9, 3.4304896411180124`*^9}, {3.430489676721012*^9, 
   3.4304896829230127`*^9}, {3.4304897260990124`*^9, 3.4304897564630127`*^9}, 
   3.430490203575012*^9, {3.430493474602*^9, 3.4304934811470003`*^9}, {
   3.501744206094597*^9, 3.5017442380954275`*^9}, {3.501744269983251*^9, 
   3.501744274948535*^9}, {3.5017443299046783`*^9, 3.5017443399102507`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwUmXk8VG8bxlXWkpJKKFmKsWRfxn4ZhhnGLJYZCVmmslUoJZVCi1CWtFBJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{20., 0},
  Frame->True,
  FrameLabel->{None, None},
  Method->{},
  PlotRange->{{18, 74}, {-250, 150}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5755396529559946`*^9, 3.586581222266629*^9, 
  3.586967224758176*^9, 3.58696923528941*^9, 3.5870926539288464`*^9, 
  3.587093284783541*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement data", "Subsection",
 CellChangeTimes->{{3.505408151582389*^9, 3.505408153261485*^9}, {
  3.5054086348680315`*^9, 3.505408635741081*^9}}],

Cell["Pick up Stanford data", "Text",
 CellChangeTimes->{{3.5870926097335443`*^9, 3.5870926180055366`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rawfig", "=", 
   RowBox[{"ImageData", "[", 
    RowBox[{"Import", "[", "\"\<data/shapes.stanforddata.jpg\>\"", "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4304757059470124`*^9, 3.430475714457012*^9}, 
   3.4304780045760126`*^9, 3.4309104985826*^9, {3.5017425484207835`*^9, 
   3.501742556260232*^9}, {3.5017426131394854`*^9, 3.5017426319955635`*^9}, {
   3.5017427208606462`*^9, 3.501742728348075*^9}, {3.503374324976756*^9, 
   3.5033743255737906`*^9}, {3.5053737830461864`*^9, 
   3.5053737902055964`*^9}, {3.505407977961458*^9, 3.505407978903512*^9}, {
   3.505408376230238*^9, 3.5054083768372726`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"height", ",", "width", ",", "depth"}], "}"}], "=", 
  RowBox[{"Dimensions", "[", "rawfig", "]"}]}]], "Input",
 CellChangeTimes->{{3.5017427517644143`*^9, 3.50174275833879*^9}, {
  3.587093301258517*^9, 3.5870933287428145`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"319", ",", "508", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.57553965366508*^9, 3.58658122346378*^9, 
  3.586967225402255*^9, 3.586969235390424*^9, 3.587092654650934*^9, 
  3.5870932848835535`*^9, 3.5870933520596137`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pixels", "=", 
   RowBox[{"Reverse", "[", 
    RowBox[{"rawfig", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.4304757609650126`*^9, {3.5017426185097923`*^9, 3.501742624085111*^9}, {
   3.5017427312982435`*^9, 3.501742735171465*^9}, {3.5017427735656614`*^9, 
   3.501742799004116*^9}, {3.501742860285621*^9, 3.5017428822038746`*^9}, {
   3.5017429227251925`*^9, 3.5017429286685324`*^9}, {3.5054084414079657`*^9, 
   3.5054084509135094`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct figure", "Subsection",
 CellChangeTimes->{{3.587093405143982*^9, 3.5870934078143034`*^9}}],

Cell["Plot pixels with locator", "Text",
 CellChangeTimes->{{3.5870927282947693`*^9, 3.587092748661213*^9}, {
  3.587092803013735*^9, 3.587092804437907*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"{", 
    RowBox[{"10", ",", "10"}], "}"}]}], ";"}], "\n", 
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Raster", "[", "pixels", "]"}], ",", 
     RowBox[{"Locator", "[", 
      RowBox[{"Dynamic", "[", "p", "]"}], "]"}], ",", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Dynamic", "[", "p", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"300", ",", "20"}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4304758312430124`*^9, 3.430475950893012*^9}, {
   3.4304761207520123`*^9, 3.4304761208870125`*^9}, {3.5017428950366087`*^9, 
   3.5017429350518975`*^9}, 3.5054086699650383`*^9, 3.505408845192061*^9}],

Cell[BoxData[
 GraphicsBox[{RasterBox[CompressedData["
1:eJzsvWmTLVd1/pndn6D992w8RH8DY5vBgJ1fgcnMtiM6ol+3ADNjNy95KQnN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    "]], LocatorBox[Dynamic[$CellContext`p]], InsetBox[
    DynamicBox[ToBoxes[$CellContext`p, TraditionalForm],
     ImageSizeCache->{7., {2., 5.}}], {300, 20}]},
  ImageSize->600]], "Output",
 CellChangeTimes->{3.575539653777094*^9, 3.5865812236078377`*^9, 
  3.586967225528269*^9, 3.58696923544643*^9, 3.58709265829537*^9, 
  3.5870932849355593`*^9, 3.5870933521116185`*^9}]
}, Open  ]],

Cell["\<\
Determine actual raster dimensions by means of locator\
\>", "Text",
 CellChangeTimes->{{3.587092889000054*^9, 3.5870929138620358`*^9}, {
  3.587093045556836*^9, 3.5870930842454786`*^9}, {3.587093238089939*^9, 
  3.587093239926158*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xmin", ",", "ymin"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"2.93", ",", "2.93"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"xmax", ",", "ymax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"498.5", ",", "317.4"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xsize", "=", 
   RowBox[{"xmax", "-", "xmin"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ysize", "=", 
   RowBox[{"ymax", "-", "ymin"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4304760025250125`*^9, 3.4304760037820125`*^9}, {
  3.4304760556780124`*^9, 3.4304761160080123`*^9}, {3.4304761968750124`*^9, 
  3.4304762710170126`*^9}, {3.4304771975580125`*^9, 3.4304772006710124`*^9}, {
  3.4304772722110124`*^9, 3.4304772753350124`*^9}, {3.501743724663061*^9, 
  3.501743761221152*^9}, {3.5017440121255026`*^9, 3.5017440484835825`*^9}, {
  3.50174532055134*^9, 3.501745373588374*^9}, {3.5017454140196867`*^9, 
  3.501745425772359*^9}}],

Cell["\<\
Construct desired image dimensions\
\>", "Text",
 CellChangeTimes->{{3.5870929265495586`*^9, 3.5870929330293355`*^9}, {
  3.5870930358616734`*^9, 3.587093040566238*^9}, {3.587093070743861*^9, 
  3.5870930754774265`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Xmin", ",", "Ymin"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"-", "250"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Xmax", ",", "Ymax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"b", ",", "150"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Xsize", "=", 
   RowBox[{"Xmax", "-", "Xmin"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ysize", "=", 
   RowBox[{"Ymax", "-", "Ymin"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4304774225170126`*^9, 3.4304776108890123`*^9}, {
  3.4304894791530123`*^9, 3.4304894846170125`*^9}, {3.4304895837380123`*^9, 
  3.4304895863710127`*^9}, {3.4304896476450124`*^9, 3.4304896507570124`*^9}, {
  3.4304896930990124`*^9, 3.4304897028630123`*^9}, {3.4304897625830126`*^9, 
  3.4304897651970124`*^9}}],

Cell["\<\
Convert raster to desired image\
\>", "Text",
 CellChangeTimes->{{3.587093362742894*^9, 3.587093370804861*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"raster", "=", 
   RowBox[{"Raster", "[", 
    RowBox[{"pixels", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Xmin", "-", 
          RowBox[{"Xsize", 
           FractionBox["xmin", "xsize"]}]}], ",", 
         RowBox[{"Ymin", "-", 
          RowBox[{"Ysize", " ", 
           FractionBox["ymin", "ysize"]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Xmax", "+", 
          RowBox[{"Xsize", " ", 
           FractionBox[
            RowBox[{"width", "-", "xmax"}], "xsize"]}]}], ",", 
         RowBox[{"Ymax", "+", 
          RowBox[{"Ysize", " ", 
           FractionBox[
            RowBox[{"height", "-", "ymax"}], "ysize"]}]}]}], "}"}]}], "}"}]}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4304763742890124`*^9, 3.4304763923410125`*^9}, 
   3.4304764263220124`*^9, {3.4304764851660123`*^9, 3.4304765210320125`*^9}, {
   3.4304767848190126`*^9, 3.4304768289610124`*^9}, {3.4304768622040124`*^9, 
   3.4304768910840125`*^9}, {3.4304776203660126`*^9, 
   3.4304776701440125`*^9}, {3.4304778593970127`*^9, 3.430477861615012*^9}, {
   3.4304779120620127`*^9, 3.4304779278880124`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figb", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"raster", ",", 
    RowBox[{"AspectRatio", "\[Rule]", 
     RowBox[{"1", "/", "GoldenRatio"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4304769009820127`*^9, 3.4304769049890127`*^9}, {
   3.4304769417930126`*^9, 3.4304770043880124`*^9}, {3.5017431884373903`*^9, 
   3.501743225587515*^9}, {3.501743260269499*^9, 3.5017433127475004`*^9}, {
   3.5017443778924236`*^9, 3.501744395108408*^9}, 3.5017444374598303`*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsvWmTLVd1/pndn6D992w8RH8DY5vBgJ1fgcnMtiM6ol+3ADNjNy95KQnN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   "], {{17.668906511693606`, -253.72690558717844`}, {75.07351131020845, 
   152.03517028651385`}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948]]], "Output",
 CellChangeTimes->{3.575539653880105*^9, 3.586581224330914*^9, 
  3.5869672257602973`*^9, 3.58696923552244*^9, 3.5870926583733797`*^9, 
  3.587093285051573*^9, 3.58709335219763*^9}]
}, Open  ]],

Cell["Show combined images", "Text",
 CellChangeTimes->{{3.587093425431419*^9, 3.5870934298779507`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figa", ",", "figb", ",", "figa"}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", "\"\<shapes-stanford\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4304770076200123`*^9, 3.4304770111270123`*^9}, {
   3.4304780198210125`*^9, 3.4304780221070127`*^9}, 3.4304902087750125`*^9, 
   3.4309105005336*^9, {3.5017429815565577`*^9, 3.501742984363718*^9}, {
   3.5017430408199472`*^9, 3.5017430441321363`*^9}, {3.501743126068823*^9, 
   3.501743154524451*^9}, {3.5017432380612288`*^9, 3.50174324088439*^9}, {
   3.501743299564747*^9, 3.5017433024129095`*^9}, {3.5017436890130215`*^9, 
   3.501743695403387*^9}, {3.5017442970598*^9, 3.501744299938965*^9}, {
   3.5017444174116836`*^9, 3.5017444226359825`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5755396540871305`*^9, 3.586581224587961*^9, 
  3.5869672260943365`*^9, 3.5869692357234635`*^9, 3.587092658594407*^9, 
  3.587093285273599*^9, 3.5870933524076543`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwUmXk8VG8bxlXWkpJKKFmKsWRfxn4ZhhnGLJYZCVmmslUoJZVCi1CWtFBJ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      "]]}}, RasterBox[CompressedData["
1:eJzsvWmTLVd1/pndn6D992w8RH8DY5vBgJ1fgcnMtiM6ol+3ADNjNy95KQnN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    "], {{17.668906511693606`, -253.72690558717844`}, {75.07351131020845, 
    152.03517028651385`}}], {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwUmXk8VG8bxlXWkpJKKFmKsWRfxn4ZhhnGLJYZCVmmslUoJZVCi1CWtFBJ
WiVtpBI5JaJEC5Il6kclpZBI4j3vXz7355znuZfrvp/zfI1q0Gb3dTNFRESo
oiIi//97L1lXTkTECImj09k3R/io2t9zZZ2oEcSH2G/V+/moTcy2fS5phN7t
bEez93w075oMPS5rhNrKtXLUp3z8jGwgdNWNUPT6rvK1bD7GNu7lZ2kaYYfj
S9qig3xMhZl8G9MxwikXqaKlO/iQXndavtrECBPfN4+J+fJBWR2xabWTEaQ6
TpRiGR/6fBXRKhcj+NN9VXOl+TDzaM5ZwTGCXnJaYOZfLzi6Wdf8EBhhwRKK
8+o2LwTYSy89EGqEp5U3d7EPe+Gk1rX622lG2LtjLPBNryfOagSsXZJphG2H
SjbNafTEJfWFo7uPGUF2qXzzhzJPlC7bpcLMM0J16ec5YQc98VKWtb37hhEi
Ig6xB9Q9ITkxsEL6jRFito7gpYsH5o2dLY96S+YrGej9b5UHFv/y4L7tMEJb
3jG95/M9sGLwwc6CXiMwy/nDzBZ34GPqa+pvI0Qe4Vq3r3bH9mc6e9cpGKPD
nSa3h8dD79D2ai1lY+xK+Tb7sw4P7gpPxAfVjJHF/SvfK8aDbojv4W26xkh7
76Vy9h4XPWKHcw/aGaOUE2y+UoELF/vB0sJ1xmCWRo/cPewG5Xs3+7/fMgb1
79ktqbeckdo9qXu7zBgNo7USZ9ycMS7OjNz2wBgp88UaJ7844Y3Xh99TT4xh
vdr9wrVlTkgekRWd32aMF8xs7u94RwzrbVE2mjLGEelhjQNq9qi5aOqxzcUE
va3nJJSGjSHDUL3fzzaB++ezsQ/kjMH/Kr3cz8MEytsCYhNJnT/r9X518DVB
7A2tfRlbDCB1LytRdpMJmhyH/kq+1ILbsx+3rmWawPSRxJ3g0sVoGSyc/1+b
CX4kWr5PSFAj+syVGzkbTOE4Y96IsZIjkZbOa78Wboq/7uLixcccCZPP+z5J
RZpinkhXoep8OpF4fGCqOtYU5dOfQn6LOhEqo/f0qSmmwBH6AqVBZ8L3tkem
SrEpFj05WFpe4Uq81j3kOTRsii1N/H/sszwibl9FAHvMFJLNAV8T23mEaueP
iKK/pnjYybh0YpE7EZnK379O1AzqoYzRtanuhMxX9bJ3i8zw4KjZd/cYD4J5
+aH8Y6oZCg9d3f7X3osgVH+1Z8WbQbQ2z8HynjfReL4qm51khgKZHX6+w95E
x8pU9uxkM+j63ZW00F1N/NZSe5yQaYaXPza9X3Z2NbHKiFsYecEME8lUr9gE
HyKXdm07+5kZmsLefU8x9yWuPNluOLvJDCJm9I3tEb5EmZPDQM0bM8zwu2rZ
fM6XeOXS7m/TZQapBYveP57tR0h6SDrp/jRDSczm6Kg2PyImWLhw9mJzaM09
xaIFrSUS+/QbaxTN8UghIK4mcy2RseHvwYTl5hh9PqrZS6wlroVn/R2nmOPB
5IjjuEwA8XEL8fGzlTnCwl8Sx0MDCO6+pbdqAs1hFlJ0tGphIOEv/iUsYb05
Eh8LZ+poBRLhySUrbMLNsVvmwjU/m0DiQJrLydKt5lhTsdhUfl0gUZkdu+f8
QXNkLXn27uWtQEL7YrNbQrE58i0jZecjiJArsNP+dssckTJrlAs5QcRk3lVx
QZk5SkpDRuesDSIaT+6t0q0yx9JM61l6u4OI6DRdw7aX5sjNmHjbWRZErDl0
Yq5DizmY2ZphlU+CCMcDM78WvzPHZtrf7nWvg4jFe9sKkj6aozDJNXvu9yDi
/pZ9C/V/mcONulnt9vJgoiDyx8+ccXM8exDS+FwnmEjZ6PNC9J85frw3vVVk
Hkz4bjA40C5Gxb+/kfxKdjAhsqZzbL88FWLx84bV4oKJfoFz808lKqy76lVC
9wUTrz1v31yjQoV+sPairUeCiQvs5FBDLSoeB/tfeXsumGDQTDo6LamYjlRR
fVUTTBjanb3rbEeFmdMXZYvGYELRenb2bQcq4uz3XRe2BhPfTHtYySwqEq3e
/RX7FEy0GLlqjXCpkKr3jt35PZh4qF8m5u9FRXeTpWjpr2AiXSvtobE/FXNi
j73eOFNIxGqM5eYFUfHs0aOOQUkhEaAetF1qAxUNffcSjOYJCaNlVIPuzVTY
ioVaz1ASEkqK56VdtpL+nrxZnqYiJETlZfpLY6nob9po826lkGid33suJYGK
lh/nmu7rC4mquZz40f1UbDkwoehmIiSuzC73CUihwtdQhF1AFRKZEivNnx+h
opeXw79vLSTiRDPkzI5SUfT4hnoWhETwjL8/8k9QUU8xvKjrKCRYU+sa5pym
QgXzGpKdhYTp35dXtuVTMaSGlEsuQkJ53Gr/hwtU7E97+Hq/m5CQGL0UyCqk
Qlw+JUeDKyR+Dsna3i2mIm3r5TfJ7kLi3eAuRbXbVDidV9l+zVNIPB74/Dut
jMx/qdjOTL6QKPri/masnIoskbC35t5CIruv8kZQFRU5FmH7z64WErs+UtJe
VFMhf1ZjT52PkFjXfTSEWkdFzPzaqttrhESp+InhGS+o0Hj+rDbUl6yXXu6u
56+oaP25W+ktaXt4nRE/1kpFfmftgwnSLtiVn+HfQcXEjd+Xmkl76Px5RUoP
Fcn8ui4haeP5pQtDvWR/JQYEFZH7pw8X6j3op4Kb50a9Qvp/r1B8b98gGW/l
QeEaMr5V9jdp7BEq9u2K/P5EQMYbUtIgP076f/+6vddLSDSkl/E/TFJxTf0/
0wcepL537/dcnWEBdpatFIMnJMLeV4RtFbdAj+1AQCpbSJSLEb9s5ljA86nA
Zb+rkJBaVR0vMd8COyTXNJsyhIS3Z63kq4UWUHtuPO8MqdflnfVZuQoWSA9N
ln5A6vm7oGGpUNkC/RHru9NJvbOHXhuMaVpgvu5vb39jIfHfktZyQtcCYyLV
ut56ZP/hnWOKoQXWRbENpLSExKsj3d7LrCzQ3KxvkLlMSKiUffz4yc4Cn5Y+
FYbIC4nIrr6Im44WeBCZZzE2X0jI6H7b68C2wD3HRgfrWULCpX78SmigBSht
xRc39AYTOT//Ghmvt0Cxwey86Y5g4ov8dMVkmAXa9/ev5r4JJg6sF3uVvtUC
i07WP136KJionrXgz52DFri+9mfs+pxgYoHOoqQ9aRaQ6Lm/t56c5yD3JXOZ
mRbQyLOr/ZREngfnlFU7cy0QckjkA3djMGFtq8Oced0CwXuLdvVbBxOp6/Te
PL9tgYQL/IwVBsFEe5qh37G7FhBNfX9TST2Y2NFhHkV5ZIHVDx8vsZMMJspi
HXPYzRY43j/vRWBTEKFf4tefO2EBRy0LIy9eEPE+/YoCe9oCaYw6tUfk+ZkW
McKcIWoJZa2svz/0g4gvKw9d3TDXEtkHRM6fmBtE5J8sDTdRsUThWPJt+dpA
Yn78nMEXdEtcFt2Xv1I3kHjow1dOcLEEEa+y47N8IBFhfo5twrHE0kHlq1Gz
Aom6n2Y3cr0tsWja9FjPuwAiITgockO4Jf51z3Ey3hdADDPuD4tkWiLOdPCR
VN5aIn+lqHrpMXJ9Skzk701rCfZMjseGXEtQf6y8utduLXH1QW/Ji/OWoFOj
TaK6/YkgvfkxuWWWULyfQ+1Q9CfeyG0YM+60RO7m3QOn9/oSpe8XTq7XtIJT
2pxfW2VWE7Zm0+x6HSsINbtcH7Z5E08P95/TMbCCaPmOHQ0F3kS79UPnn1Qr
iHyNLbU08yamczcc3eFihU3xNmHbfASEi6BcO22jFZa5ZDno5HgR3U1rV98q
sQLn+5UzN0Z5xOxHV8v+2lnD+tJa1W0PHIkJ2qq7FY7WWLhE7IqkmSPR/+TG
3d1Maxw27zlx4qYDUVdXem/a3RqaGnKSpRdpxMGXD8tnrbfGw7qrnpQMEKI9
rx/OSbPGIXtr49kvqcS/qYlapTZrCO37Apc0qhDf9u5+2tlpjQPV+95WZCwj
OmeK1J35YI2cwIGPmw8qEBXiYvXLB6wRsn6qJ32nLBEnM++5+pQ18lrlvodK
tVX9XqbepLPCBo1K9Wv2jyzDT2vXt1aRNjiq+mW45CR5j7HYOFG01QbnKOHX
uqLNccAsfdnSHTZYUJowsJz8riw1eBM8mWCDsFOzrD7+tYCz+pqfFUdt4P7S
U3ou1wZ5UuFStnfJ9/PPCWm99mC1plhhygbz2mrPlI84Q/7NNf+bM21x/ejy
raUcBj42NSaoSNii/WiluGwRA7H1C+pE5tvCur1p+vtaJs5X5Ho+UrXFFKPa
S+GxCyYKrm6k0W2RMLDQl7fBDZc3PzvrmGaLuXvsgzfJ8/BS1SQ0L8MWhh8j
Lo9Z8DDx5ozReLYt8p0339P05YFNjaopOmOLmeeKJXae5eG3yJKBBTdssaAq
U+eTqjscs9aZfXhli4cnjjVmLfLAJsemactWW/TQ9tZvMPLAyd/U+ux2W/hM
PdnezfbAgI+0L+M/WwwYSmmUHfBAlnpJwo1ftkjbEVnyd8gDPaUiL3bL2yHo
kkPNE5I3Zm8IO/5WyQ4t+iVGt154wkShea2hih2k52ybaUvyysHdl4d7KXYI
vl2xhTrfC3pO7CUsSzvIr64qvh7sBe/xux8u2tpBd0mO4entXki8qlo0TbPD
4KTpaa1UL7TIjNqUuNphwEx39opbXtj19lSwop8d7LU7vh0f98KlQ2Krtgba
Ib9phm2SFB8vrTb/frHODkrvkzbOU+RDPZ92KGGTHR7URu6XsOTjWUj/9S97
7FA6q/DF9hg+fil6xNL22eEzu8tCmMSH8osK+9PJdhiLEQ7+zOAj2jCjmZNp
hyvP5A8OXOVDYcJsoqzADhuNA6gh7XxcbaVGbb5shzDtQT+HT3xYllh+0bxm
h/e1mu3Xh/jwibBtPXnHDjpShkfMJQT4yoAbr9wOXo/qNb1kBYhbSXsiVWUH
asfpjllKAuS+p9+Oq7MDgerNi1YJoP3AWcv4hR1ev/r2JNZUgPITzPyBV3bY
uvPPsk02ArhsdZW/0GqHZeEWD0YdBWjnuh3x7bBD+nPP7nksAcJWccQW9djB
8xqzqcJdgAkp3q4XvaQ+naGvJ70FUKz2DLMdtENCj6SVuVCAq2f5H34P22Hn
rHJLo1ABLHd5e98Ys4Ne+O+ERxsFeObt07Rh0g7K5zOC+6IEKFbUU88QAdRm
njPJixFgVPKG/7eZgIh2EutbrAA2Y/q5DDHANe6N6MudAuzvu9lyQQI4ti3i
PjNegBdvDGVnzAYkVIR1q/cKsOjxbZafNLCeJpUlkiiA303j5PsywNXSnljb
JAEu5pVWL5IFFh0u+CC3T4DvaabTUXKAGNPcOIG0TXeWWTYuAiK+lLYeIO3d
oebbtJcAi/+tMV9J2jWCe7cOKAJPi7Mf+5L7zXWy+P5xKeBUPPB5FenPy6Sc
Yrec9L9ynkIOGc8ZNSvhKVVA8fjz+jwy3r75FWfH1IHiK5KRdrsEWDVt3eGh
AZiN1STt3CFAzPfKxTcpZL518ns8tglQ2WHrLq0DyFepv38aLYDYs6rDIauA
d3uWLX+3SQC3e6h/og8MMhweHwwT4NilR6KqRsC2ve3M5nUCdGXTsNsEyDbT
tawKEGBlUvXOd2ZA4ukEBeYaATZGOd41tQBiI1Uio70EuLO2ZjjTCojxd66z
4gjwz81Jb9AGmMfXvn6RIcBhbcbFSzSyXlpX/PwsBWhZUt8zkw5cOefBvGYk
wDIJl6VrnYEND5vF87RJff9zPSrPAvz2unEjFEh9XzU0bmEDzX82zHWZT+pL
uM1+yQWMGo5NNYiTep7mJCR7Aa/vnhh5MszHotSXFb0CYOEFVXOrL3z47eCN
wwe44aKmt7qLj+9eHpv/+APDpuvqj9TyMXeewC8sBEhdnaowks3H43JN7bww
YOO2vB15yXzErh///SoCsIkozJixi4/eypwMiyigSrRv5VAgH+URndWScYD6
YSWRA9p8hDwL1L6cCrh1uryffcOL5HijsfbDgOY1ye7teV54ozrriUwGsP/r
vZWXDnvBdscFv23ZgHDnZRlmuBcWUT5n0M8AGSvZLuXqXni8P2Lsv+uA7kWF
wK5Dnog1tHkifwv4t0C/51qMJ1Z1zc10LQHemn+hMgI9cdLkhnbJXSCI4mPZ
Z+6Jzf8N+SUSgLTb1n/PP3pgqf32JyqvgU2fa7u+6ntg22RCpt8o8PyolEfC
NR7WVirfIcaA9C2dMXMzeWDEP2hTnwDaAg8T22N4UBAZXf51CiTPnyj8asND
xayQ69sk7bHPsuWj8AUXM+ewn6cr2ePzPUNnqSYOjigoij22t4dugn1PqjIL
29vLKCsd7cG7Kyc18tEVAac8WMlO9hj2SHnmedkVhssOH2W72qOuo+vlPANX
NKuIqHV42mPplvdNOfYuUKR8sv21wR6ZosVHC9czcNnsdqzGEXsEqJ7e0Frj
SDZC9Ob4DHvkPbObtj/iiLaNxutbs+yR4qpS8IHvCMmLpR4HTthjyp99ofqL
A0Lk7up9yrfHulznAMxzgPbPB70XS+xRX3XpfFKIPR6n7ur4d8ceI54pqUMm
9vDRtHntdc8eHcr2n67NsEeq/8MqsUrSn2z/uOxp4FsDkbuu1h6H1Pqs4wvt
cL2whrvynT1+LHpr+6rYGk70A867O+xxPjxP/j7PGu97nGxbuuwxkHw9MvS3
FeYtqdPZ/9EeVQGhFno0K0QeeCbeN2AP1YBZbzP+s4BRcFPFhSl7vO5l633l
kBw9lV4yKULD9n3C2SkzzBGUy73qOYsG8fyxCoVSMxx99eqEqCQNj/zSkmWX
muGXXXO0UJaGN5IxXmfHTFC29B1lxQoa7A6J6ot0G6Eipv+mhwYNSsnJNU8u
GOFx4x9qEoWGzRpz3sSEG6FxryLzoy4NKta90wV/DdHXuyY035SGhwusJLia
hvhqEzHUZE5DidvnvrxfBvh5fNeOaQsaLOY+/d372ACTjDOH/G1paKk4fGJN
kAEWFr8vXOpMg8Dy1TlNH30oiv8wZDFpePff8ZdxovpQWTt9f6cr+dyjq7Lx
ph50ZVWetXNoOBxiNy9hnh6MwgzcZ7vTEJb3JvK/R6tArUa7hScNFxRqUtnb
VsEhJvDrSW8aZjoa+jj16YLRGBVd50ODlAv3fOtZXbA1EyfGfGmgVcx8tc1X
Fz7vCmYLAmnY9cE15nuHDqJterUXhdFwOeKXdfeINmKP/7rtGEHDyYQPgYpV
2oj/IWq1dRMNnLEOZlSaNlLOrXR9E03Dlg9RXttXaSNjwvTNzBgabl589pIy
QxvHPZzWGG0nz1jO2YcTrVo4J7YhPHMnDcMVnnNFD2nhkv/2EWI3DbZdTB+b
dVq4dvfgzp97aAi9/m4o10ELt+efnKWSSMO8QlxZtkIL90KvpHL20XCjcZVj
rbgWHj6+J7fnAA0/Lj2MPzZAwROl+lPXk8n8knbOSntNwbOt79Tfp9AwJukZ
efUBBS9f9BfNPUyD2ozTXkOXKGjVmDC2SafBebOkWWA2BZ17ZldEZNIwa/Da
gYkkCj62KTqePkqDg/uf65UxFHw21Gl4fox8fuyuZFEoBd9SrDz/nqBh26zZ
PY/XUjD8n2undi4NV+6EbhHzpmDc2lfoc5qGKdeLI9HuFEwdi/h2KI+G5uHu
pDkcCkR/7Np6P58G6+IMiyY3CmYzDk9+KSD1+5Sw9CGbgvnnzuxbcpGGNc6v
NNp4FCyeKJZmXKbB790Px2UCCpZ6PMzeXkiD3oYCr8P+FKhda1x6uYjUR3um
NiWEAopY94XWYhp0Knfv/76FglX+P3TFb9Lw3aN9WVcCBesbns9Zd5vUt+1w
acRRCvIsr3ytLqVhdO5y/4OXKXh7ZV+92l0aNumu26/7kIxHPvBKwn0aeIRP
4pq3FDD32xzseUBD6SXVXLkRChJHFNbbPaRh4W6JaQ9ZLfxqeq3+7zEN+T/9
lcK8tLDK9sZM3xoasu5tfWezUwvrr6V+KH9Kw9qaf0PHzmuhLdnxbGwD2f/Z
56Ma/2pBdkwl/m0jOX8G15jXdLThsu6fr9krsh948/yl/LVRYV+m+KuFBs+l
41yrZ9oYvZH1x72NhtRlV+fMFdWBnvLmtlvtNBRtUHsggA7yJzSPb+6moZ+T
2ccldPAuRDSm8QMNx+Q1Cv/O0sWCtz0eq3ppUJdrHpZ30cW+khzZgS/k+bBv
c8/pLl1Uqm77yRwg6xPUajlDZxV+p7s3XflOw7h3cHJj3CqERMw5vH6YBn/j
5wW5qnpgrdwt+fEvDU+Xx0aWpOpj/9HVnzFFQ3z02XjFb/p4OMOs9qyIAwoM
vf6FaRrA4P1gkp+YA7o9jnuePUyeFycCpttkHNBnwhJ9tMEQbmI2781lHWC5
fNGipecMcWCLQuVxOQcozBz9nN1hiHHO6zjPJQ5Q3Zzzu83DCJ2Sjr+bVMnn
c5tfx/KMsWi7SoveCge4pse6Zhw1BrtvsuSwhgO04ucNl7Uag3h0J8pVxwFO
RPBHrQATXIjT/F5r4gCpT19tNu4xRcS32b2Vzg4gfNdEHPxujgVLzD1/MR3Q
rNeUuMiSivsOwU+0WQ54dWmbT9RBKsRPPbhwgusApZwY95QVFjjHjFgXtdoB
xWdy+ZIhlmi99OLTinAHiP3cUemzgLxIBWb0px5xQN7DLeRhZA+51kU/Vrc4
gBOWl1wx7oxvi2XKqt46wLxFsWzImIFagfjule0OkPPe/9FuMwNx737PHnrv
AHHFoAvLPzHQ0/lWI5n87q3cuHLr3WYmrv+X41/21wEO0vQtOSWucBla1rhA
zRE7eLKj8WEcrDBafCx2hSN0dKP/yF3kYCpaxve9hiN476hHkro5uPVrqr9Q
h/zOyv+xHdXiYsl4t5i9qSM8DvRLcs9w8WnqnM1mhiOsNDb8GYvnIVFao/j5
JkeIdJ8xstD0wBwKzVkjyhFsndrxV3YeyHbw/7B3iyP0KTerLL09cDnu+CKz
WEcUhryoiU32QMMX8fj8BEeMlJQqHPnkgUU1n9kx2Y4osxn8vOakJ/J6ZvU3
HXdEgdoOdlqxJyiTy5O0cxxRVW8/Ev/YE5bG3ne7zzhCqBJVeHnAE/7n6pa7
XHaE546LvT8svXBld+FP5XJH9EhXBV5p8IJhTk3KjgpHSI39GznV5YXy0g8r
mh86Qjv4lDx90AsvBhRWH6p2RODIrkV3ZPgYXp3yaKTBERWmFPaYKx87Yy6t
YTc5Ijjpb3WiDx+imY9Hr7xyxApNg9+VIXzI101o+bc6otLlv0fYx4e1WXhW
Xbcj3PdIXxfe5aOGd1BX/aMjXJa/KvGp5oO98Xzt7l5yP+/Ps/428hF4oWPC
qN8RTXxOv3kfH1+rxrIPDziC7itl9uYHH1s75PS/fHfE7o/frRZP8HFgASv4
zLAjFAa1RjPmCjBPL+Tf2C9HhGb0b3y6WICTzH0n3MccEStxTfv8cpLP9lY8
l5gkn//plmEYCGB8um1d0JQjtsy1mj2fKkDF3V/TFSJ01A5vGYqzE6BpUNck
WoyOvZotduZuAtQ+Pbn2ggQd2UN7ZJU9yPfzRVNbpei43mvw5xbJgyU7Issk
pekwkO8/MOxH+nPv/GApQ8eWcjVWd5AA53QYczfOp0Ps4puO7RvI+ERLqWcX
0BHfsvnZg3AB0ruWC18tpMNncKD46mYBDpSlps+SpyPoatUyxy0kj6WPlZsq
0PGd+eX2QZKPtoYEf9qgRMeF8a8SMSQ/hdk3yeYuo+O3ztt7c0i+ClS0smlY
Tsf8CUawK8lf3iOXQqZU6eCFhl8yJvmM3bAg22AFHdR7E2pPEgSgX4yvCtKg
gzjjtHOS5Dnr+K9fsyl0zEw08egkec9YwF/8VJsOpxv23GCSB7UNHtv/0aXD
eed+hUzSVpXS26ijT8edkBLBOtJe8jHnpJ8hHQNYdqebXD/vgdiTdGM66lbe
6Zom9xfPjvrxyJSO86fm7akh/U9GdCn+MieBKnUdw4CMb4TOdNKwpOOn1fGv
dmT8X5XvRHlb0xFH11ryi+ThnjGVMym2dKjFcfezyPzfvkyrqwAdkXX9nxlk
fRoLx0cGaXRMLkwY+0LyY02icLkqnY7/5rhv1CXrW7HmpYuHMx26X5micmT9
r869cu6uKx2Hz/cdqgsk9fok96LfjQ6/jQO/j/uSelXtGVfi0nHCsztBQkDy
eJSAs9eTjqhZjBmNLgLscqmOu82nY+rsYIK6owDR6vqXer3pWKLwlapoI0BA
i/g/hh+pV2lczNdVAgiuR1N2rqWjspd2rHolqcfB9x7FgWS/dNUtt1lG1t+i
7KrsejrMMr5WzJ8jgPyZdd7tm+jw3hMUbfqRD5ltr5Kko+jQuHDMbO5bch45
Njdst9Bx8tJD9X3PyfkVWSR+fjsd6+bQJ9glfDQKn5SE76WjXNLyoFc8OY82
Bt1nEunoy0mLUY/ko2Lx6dkv99Fx+0bXw3SSBwvrtgSaHKKjuo6t7ODAxz5d
9Xn/MulYH34wV24mH9cV12T6Z9ORfjwt1ueHF9okj8oRx+mI+cPR0Ov0gm7f
zCVJp+joLVD6vLPUC81nPqpIXaSjYMKOcWutF6ZSFc+HXaZju15Zpz/TC5Q4
95UNhXSIaM6MzDHywi7+Y63063SE3L7bcWeWF9TnFRgtukeuf1fteSTfE6x/
70q3ldPxeN+4z6UDntg2IGveVkFH94kkE1aEJ549TbA69YiOMRfJf/Zmnoje
G+io+pyOT/f3lrY/8cDjIRX+qvd0fJj14f6PBnd86/ZuO9JDxynXT0mTRe5Y
3Jjh8/MjHW47ft7PTXFH2FWRtSWf6TgzMVKY5uSOBcE9GyyGyHynv33i3Och
qPnsDrqoE8Q+yiddSuFixl3lM37aTnALrn8uqHLFyaBLN4/rOiEz6qzH3lBX
GMjoPWnSc8LVZ2NXZsiR/LjOZsDe2AkHlAcrFwhd8FDO10LD2glYdsg/dYr8
/kXmtAy6OaHwef7cukVO+KW1UGZvlBNctOW1uUV2+HRaak/BPSdomeV3rgqX
QaHegNZSR2e8XKywNMiaRax4FrRhh5MzGv+FMu5XsYi8de0XWhnOmOP/uvIT
zY3IOl2/PNPNGeEhR50eMNhE3Owri8QFzuScr1UQ0+ISrE/CGT9DnfH4keKM
PF13YvDM+7bqdGeIXlEK+beQT4RY8BerZjlDuKTYr5XHJz42v/CIz3ZGof4G
k21H+ETrnMpGao4zqly4GuISAqJqx6knxQXOuHhdcIcxKiAyvLxvnrhDvl+o
Hh9Ss5ownvv6YHiHM/RDfBRe6PoRiutz+PldzrC7nKom4edHzKwKWNnS7Yye
XUldw2l+xOvIH49te53xZWiDT+eAHxHdLD0l+90ZMzbeYX+86E/cPOW89d6U
M8QFF47PFgsgTv6ScfguwsDi65o5yYoBxF63Vlm1WQyE5h3Kf6cfQHCmhTdS
JRi4KacQMLI6gBgMSvzqP58BifPOFpNFAYSudmWAmBoDSJmKUHQOJBYm7dO3
XMFASXG4zbnVgcRkh+vUJg0GvMxVfo6GBxLPD7efatNmQOm1f6NERiARNjTW
WkTec7rrR71rWgKJwntGbu50Br4/3nM1VBBEZMhOKB10ZsD0fXf/tfVBRGzY
o68PmOS9Z+Lo7fsxQQRjKTd5JZuBvxTvz3pHg4gvezZWj/MZcB5Rckh4HkRo
OF+xOBvCQJHDv9ajhsGE/R2rtbPCGVg6gM9utsGEr3rTvg0bGdjCy/lY7RJM
ZE2PNulHM/Dm5N4rH4OCiX93HdYTOxlYdKtIqS89mFii8TZ1RTwDBUuUNGJz
gwmj7LBbyXsZ2JEQu7rmQjAREpk5yd3PgPT0YPThe8FEM6U768MRBmbGazk0
dQYTP45H36NnMvD09Qp/vb5gYraY+PvCo6S/9hoTp+/BBD7oakWfJPNxmth+
djKYWMMh2K25DAQab8vpmSUktlV6bLU8Q/rfH9bzbraQuJYTVzWzgIFVCqcE
v+SFxFMJmb71FxhoX1vmvEhZSHyMOTf7+SUGjHZJdX1XFxJL3Ou8jhYxsDuK
dqBGT0gYE2t2jhUzkLF04bonxkKCrfcjf81NBuRCf8fHUYVE0uzF39TvMBA8
PkdK2l5I5MUWyibfZeAHz4Xz2VFI3Ptkbf7tPpmf8OauHQwh8cbzpS+3goFq
50d7HrsKicHHwYmlDxlYbbGe8ZgtJKQMxy4vecRA1NDg01iekFhxNuXFrmoG
FMdkh/o8hITdXOWRnhoG7vZ/uyvFFxI+O28todeR+leLLugVCImYfkfbwmcM
+C5w+r11tZDIELQFz33BQMgqMb8KHyFRVBN+KKqJgVLfKbvyNUKi1nj6essr
Bs7/88rd5CskPpzLarZoZqDwzMmQd6Q9OU9j4kwrA8lzH1z5/+/L8vH3l898
x8C1CEWf16Rt9I1FX9/BQKXurt0BpO3m0xP2rIsBl7kyiy6S+4fUbcnQ62Hg
+rz1K/JJ/0lmEmVZHxlYEpx4k0fGl3cht+N3LwP3GPVV98n47y/Qm7HmMwPq
PyV92ryERPPeRxpV/Qy0uG5PLibzHxz0ZKl/Y2Cg65aXBVkfKb8vUQcHGRDb
XfliJ1m/Fc93nhj4yYBAVnxqK1lfW4t5lZwRBn4y/UdXkPVffbngY8koAzou
09WppD5bF5lJLhkn68VJ3lkIIZGeVL9q1wQ5n+wpvXhrIXF1yNejZ5IB19Tn
w1Kk3j0vkvKuzGDi3GlpUWeyP64utjoxQ5SJmRde/5LVIuu/djjdR5yJY3VL
Ro+T/TR7KCBBeg4TFsOdaU1k/zVbLIlbN5eJwppva5JkyfwTm6IfzmPiHeVs
4RDZr8YLbYWRC5nwc1e3nSL7e8p31Ld+MRPx9UTt6dFgou7iNS81BSbGXx7n
/Sbnwddcybl5GWlHx023dwUTB3zGtaiaTOTpXvq3qTyY4J6/oZapxcT6jVde
9t8MJpS+rVf6qsPEn3O3+1UuBxM3d7dInzZg4tu/PZefZAUT7/Jv/5i2YIJx
Y/vVz+uDiQv9oV+8rZmI+xL3j7kmmNhkpPrhli0TWvxyrTBOMDHzSfrrYAcm
CtiFg71mwYTu54g7T1lMzOs5lPVsZjDxW3/FdRUO6b/RaJ7aaBDxKLbj0g4e
E5p3s+kWn4MI/myXkzp8Jo446n66/CyI2LNKc2f6WiYMJpevP3wkiHi95QME
0Ux0xq3IvTc7iDhdcdLi5lYmSr5Eten+CSQ2iHGNpLYzMdjXtmndZ/I8Pf5Q
/cFOJnw6NYZXVAcSK8tPiS/fz4QIsenWp+2BRKwIv+HTCSZqyn9vrG4NIG6K
+/Hlc5mo2nWzWa46gPgiLexxPs1Ef+k+mumNAMJbIfrXlXwmKl/e3vbtQABB
NTqyNLyQSZ6vIXamJgHEeHBtxI9yJi7nuC4YlV5LxD41mzvexSS5yGFmxhJf
4uYLmxOUHiY8GW0yNZ/WEF/eOKqu/shEtbtrx+3SNYR3j7tp+ScmXowEtD3g
rCGofzb57frBxOurmadyEn2Ice3LxSIzXPAmK0DXotOb2HFEni21wgUSW78r
dQm9iN7Cr3qhGi64Xd3i/E3Di+DWVM6rp7hg6xdZh6dfPAmNyeBXyatcoBz7
Tasv3JN4HXrTU9LcBUU6l6J6NnsQOnTmGgkX8h4xtqOqeTOP6PobFyIW6YI7
mt8yTt5wIexD3yfOqHABX+/nO72VJoQibcYo9aELdHOuBVD0jYlhxRUbIgkX
sHQFPhstjIgLDaGu3U9ccHfLb8MvbANC0mBUrvKFC+6brAmdO0khGn/PuRjb
7YKZ2/r9VAg5wmefxdMfM13hszRNQ+SQOoz9fC00xUguj3t0O9lzJaTN9hT5
S7jinDH/4BllTVR+fpL+Yo4rckauhrpf14aKK9e7aKErpt1DWk51GeCT7Ib+
9RquyKUGVD96bI7os9lz3jNdUbRsvcvtCBom3Du4s1muMPz5Za9sEw2J4mrH
zdiuWPixvuqrgQOObryhku5O7u9/NUV8xAGlVs9MscYVNkxP/8eRJDe9nV5b
EOGK5ZfNSlg8BuJTnS42bnKFdJh+1OOrDIjbHf46EemKMacyr/xZTMhfUozx
iHGFWpVqYkYJE9Stpimi8a4w+ht6XkPaFTvmh5euT3cF93WpLv+sG2Y+ufUn
K9MVPefUetsH3ZCyfdy26qgrLinKDd6zYSP3/f56+ZOuCNvqdmf3OzbKr+W/
r8sn/ZXd/n1IlItJRqukzm1XmFiWR31S52Hf5FK2oNQV7/b8ekt34kH6ZvDR
pDJXiHdfU2WF8LBMfmhZZ7krfss2a7GKeLDtm2N8uNqV3PftqOwqd+xNsPf7
0eyKzi1n9uxY7gFrF88/Lm9dwUuSeJdl64GxBRuOXXrniqPsP7ts/Tyw6ULa
C7/3ruA4vSp0zfHAmqdvbRo+u+L+BpazubQnFmd8faf5lcx7qvhop6YnXnv/
i0n65grkFcYscPAE46vadcshVySfUeDox3rCbO4m5cIJV9hXvzDW6vLEUMve
ctF/rhDy08bYo564lneUHzBN9kdNv6XoXPL+b3D/iLwoC4vTGnuXWnlhvofo
9P65LDhXlDWKZnmhQUn+1Id5LGTLbTl44ZIXDvZqmdssYIEls5D5ppzkjRjO
5l+LWRD78ba964MXBk7mdgepsDCD3b7xsjYflwKLdz5UYyGw+HlmlRUfQdqE
vOJKFi7kZn9az+Kj7UEf55UWC8TPuHXBEXxk7xsf0NVlQaJM5e69nXxw3OYk
J+uxEHXxWvKZFD5q3xsQdsYsyPSHLlp8mY+Eyw6+p0xZWNR8dc7VUj6sI/nj
v81ZkEsbHHvxiI+SGbsMrluz0M5jOtS285G/4mn+UicW5ok3qe6WEMD3+zvr
WAYLDQuvGh+TJXmw7FvbGxdyvfXJU7ZKAhxxXiCbymGhbmi2qxPJl8z5K4s/
8VgYiVopcdFUANF35kyaJwsVyjtnHid5dGeYX8IfbxaO2zXf12cJYGYcucxr
DQvekVr/2twFGP6beP+mHwtzZFYfWbRagOInx7ykA1go/ttS1ucvQMjhK0Mb
glhw+rn2MVMowAr+g8PVQha+6s6Ytg8VoFu5UWv5BhZOrpSubNwoQO7nnpq4
UBauL1Pg/IwSgH9zJLA1nAXru7NmX44RYI8ZP11qEws3WLazH8YKcKXiXoV1
JAvn9qudiSV5/xVN6evmaBaMfPuk3+4WYKJut/z5rWR8gvCL7/YIoM7pcWzd
xkL9BafSvQkCsFpo0VI7WFDWv5PckChAzJqLZ613sjBwMW9LZZIAeR8kXmze
zcKyxKynHvsEeLohbKJgD9k/IrVt6aT983uDZmsCC18WLvgXRdoKW/W9pPax
YOs5lDpBrqdNZCZaH2DBoG33ey3SDt/768bmZBYeKmzm/P/392xxQVdBCgub
n8hbxe8VoDLt/uzWNBayEoKnz8cL8GnBUqpUOguvHjT/jdolwLyc+HXWmWT9
fBIzv+wQgLr8Q9bmoyx0b1+kLrldgMCLDkTBMRb8pZ4ufLVFgBSdS99bTrBw
NdmvwSFSgJJbkkpSuSz8OqJ9KyBCgE7zcIb1abJe4ZK6lBAB9BwNzhfks+Bb
OXnkHqmf4FnWy5YCFlos/biJpL57uaP/JC+S/XvMz2fcQ4DXvuXemwtZODvL
cs6AswB/Py49UFDEQs5x+xMh9qTeoXtKWopZmKi2NMu2JOsb4yhjfZuFcE32
wTEdsr5/L1ltLiXny05V22CFALUJUqEFZSyUWbo/WrJUgCVHGqslH7AwblhZ
+Xe2ABWXvHe0VLPQOWPv68V9fPTpPrgkWUv2u67mcCc5DzIly5qt6sjnKplz
BC/5CKj6qFfQwEJyB+EcWs6HaFtE76YWFham6w0vTOVjlX+TbMFbFnTuO/93
KJ4Pfq+hXcs7FiIz1mvejeLjys/fOVbvWZj82f/NWsAHSyqBI/mZzD9R9rDY
cnK+LY+Vnxsn369r+DSvwAs/W6ptRf+ysO3QPMO+dC+wooYfr//HgmtbdVbU
bi+SgznPdWa64Y3QtP22wAsxi2Z33pnjhlCTbVsHJb3A/xn/r17ZDbnTBh/E
1nqS348QDDu6gVJR8fdVtzu22p944unsBq/yqf+Mat3xsrOGcZfpBlF3tRkb
rrkjWU6dt4vthpyY+7msWHeM7+0KFPd2w7Lr1iWaMu5oW+OepBjuhvWZK44M
G/GQK2tdS8t0wxfWHUOjJjaEYeUdu4664Z/tg9s+J9nQq6YOlR1zQ8yL5Dth
gWw82mq6VCfXDQeH751wHiHXvdWLljvvBt8fezRUF7vBLE9VubfUDVmef4zv
rHbFa22Jbfvb3DAQffGG53/OOJ20P7Wq3Q2N0ubT2685Y33nrHN/Ot2gtKv7
RGmMM/4cFmnY+MENUr0BF/ZIOkNl6I8q/6sbHK07/zug74RNd7+90Jh0Q0vc
m7Xn9zlCyvH1yrrlbBTkHbsn42WPxO1bZcZU2bh7fipr6Up7TF5dPLZyBRvH
ZGTmbBoFBmXX1CVR2KgmUm70HAded/8XZmfIxiqliFuscjuc3jl6o4zGxjbr
dfFRP62x6MaJk32ObJxcUXZPKdcaRz5aJCx0ZiPd69jyaEdrJDDj3aNd2bD6
W7lA95QV1stLjK7yZONyCe/DPJ4l9EuWWF5cx8bjYoXswB5zXPlUrta8gY2f
P2JNnh4zh5qi35xZYWz8vbnV4Y+rORYmnOsM2MQGM91L6lm5GcbZ2nuWbmdD
4k3HIW6BKdl3DRtcd7AxvDhUgeVviq93NnHjdrIxoF5rr6Zkiq6lJapte9hk
HXdLrjthgsdfrZ4cTSb96dzrjso1hpXy+2uPU9hgGzY0bvYzRilv77GhNDZ0
pW8v8VI1xuV7T9ZzMtnQOuN/o6PICGkH3KTm5LJRnKhsPaPBEGLlP4YsTrOx
7tDV+KDjhoj/ntkekseGlHvgurJAQ0R6thbVFrDxMGCAa/XXAF5qa9mJRWzc
Y60u6LQwwMzwF4d7itm4XXbxgLKkAa6XWL2wvcmG4tO8fwtu6EOcvoT1t5SN
Wc/XZxAjerh9+EDq6rtszH0uvHAmRw9rW389u3ufjcARmeq39nq4t+EVc+tD
NmqW12NjzioIb9odek2wYf03LukFYxXm/ymuM6hmo23G9InsCV2EpqQ4f3/K
RnD4dmrAOl0oFjvQ179iQ8XuQSTFWwe1o7f2PXlD9sOTue8mFHUQbavyRK2V
Dd6FEjvHHm08b5qkdbezcUrCo5oWrY3YJeGJNl3kfh3D8/7aamNF4LtHp7rZ
KBEsLzeQ0cau4Tvw7mXjufnSBwqlWqBYrdhb9omNszkpxU0pWmhJyqpa2M9G
XuMtE0mhFhIbRKajB9gwn9O1+YmdFvQWbbZ99Z2NqdIb4WLKWmj369qt/5ON
06LL1RqmKDhwybXy8DAb3YoRcQofKTD6cX9y4BcbofuVmYNPKeg2p1i7jLHh
YDbNcb1JQdre4zuv/GHjwTc5W8NTFFDrRR+IT7JJPj91Iz+Zgl7ZLRPCKTbU
JyT0cmMpyPD5YFEtwkHv/Wl95XAKrM9zdqjO4uCmHV9hVQAF/QOV9/aIccCa
KW31VEDBcRPd8S4JDvoWsN5841FA251rbj2bg6ALYXPz2BQM1khuz5XmYKNo
74wONwpyZbaXjctw8Ffct+w8hwInQd8oX5YDl94zy8Y9KBg562F6R46D2uTT
8m0+FOR/ebRVbjEHMYItUQ5CCliGBqVRSzg46L+hzyKSgvEdeSNNihwETH1R
fBBPwYXH0sZ6yzhYP/P4pdp0CrhzdkanLedAqGs92/c8BZMe/be+qnKwz7Cz
NO4+BVdOC4YYKzigahfPVHtNgVdfjcFlDQ5eRqvY8L5TMFPPJFJMi4OOqb5c
iTlauL6t4EawDgeKykN2jjpaEJfco6diwIFn+6Is1hYt3OZ+3xhvxIG/2Emt
xae0sDZnTXGnCQf/kmy6Amu0cE+bqptjwYHHxrr8OFVtCLdcCh+z4qC6R1Oc
7qGN+RULi7xsyfx7rxulHdRGqNuQ1gIHDr5/TyJSxrSR6HFjwpnOgXuteL++
vg5Or974fLczB9yfpw0nQnTwcl1/RL8rB9lrdtuNf9QBNf7DDcKTXP8na+6m
n7pw33d2728+Bwv/dQvmW6xCRIofT3c1ud81kexnSauQf/zd8Ak/DtZwPtH3
LNeD5I1XppvXc3BFs8Hr1mZ9qN1JF78YwoG1QM6zo04f1g/c3raHcTD/cxpf
fIEBIp/Wxzpt5uBT34UFtpEGaOt+9GBZLAetlWJqF6mGuDz/tn3DITKe1B0Z
uuNGIBZHLpiZxoH0n9R9wSbGaF+q95/5EQ4atUrOJkcZQ0br6r7zWRxcexwx
58SgMbbZFzyNO8WBaXHfuRMjJnCKznLTKuYg4lWHS5GmOQJiucprb3CwyVqu
aDLKHHHxMj+yb3FwL2p5nEqlOa6npGSIlJH5hqgVvfWiYvH5xDdvH3Kgltwl
8yLDAn1volcfeMnB0GrfGgkda3K+JvcOvOYgRGa9xetka+ydffAKt4WDD1fd
wiM+W0PR/tSYYjsHk8P3k0Qv24B9vfrYjf84eLataFOUvh3Kkhe+bvvNQT51
9UqWoT2qlddcPCbDxXtq2pu2M47IfjO57IsJFz0yebRqknuyGj2UFplxoebQ
+noryQUZ9VeX0My58Fjpk6pM3nsPV3nLnbYg36e0zfHoY+FAUakk15aLKlcD
V+kmN8QmRYzcdeZiAbUoSTmPA1/jzrqDPlzMP3Zn7rsjPPjoGdeWruGSHHs2
5VMhD95aKdUffLkQrbjv/foJD17LqQ+t1nIxc4GEtf0ED+w52SU/gkl/6c17
g4Ldgf9c8wQbufhtIFXzeZUHVhx9sEVzLxd7ah9n1JzxxLuIcgskcJGoKny+
/ZYnjjjdn/ZO5MI/v4b264knxv+Upabs4+JPSrYVc8ATDQG3z39P5mLkbXYT
19QLCZa3QsVTuDB/+UhIc/aC2cKb+stTuXAebPo17u2F/KfFD7iHubix+GXM
7Z3kfUqv8E1JJhefXMQc6A+9oC15Jachi4u6Uxt/shq90PPh0tq+o+R+Vy9k
LXzvBZdjFwYWH+fiaUI5/cOkF5Qnz86Ky+VCw0oye605H29a8uqzTnHBcTGW
4dP5SL5xJr3oNBfCyy33JTz4GA46pdSVx4XqZvnVuRtJnqs/bozzXFwacPsY
cZaPneeP/fG+wIXT7BlzVhXxYbA7uyrqIhcGY3oD58v4yDXIcj1/mYuUrhXX
ShpIPpydKVtxhYuMKcpu1///Xteb/ra5kIsiaHw68YGPTScOB4tfI+sXfXET
a5QP9ag0reXFXCQr3k8umSL50yX1h/l1sv6aP/RfkDxIm0reGXqTC4UzB7UW
Kwgw9vagfeItLqaj9RIcVQW4duuAxKnbZHyaByLVtUheXLfvaEMpF4NqP/SH
zAVosE1a3XeHi8xdvPndtgIkLklcPlVG1sNBunAnXYBvz/cU6d/not242riK
J8C5i/FRjHIu7t7ZYr9OQPLbnt3mgQ/I/k3+anvPVwDCaGd1ViWp3/BpbvB6
kgek4w4VPeRCzs8hrTxMAO1PsZwnVVw8vp8iXrmJ5MOq7Yu6CC6yk/r4YdEk
L+Vs6xh9xMW8CObixyQPMrfEnJOp5sKyyrC7muTBKdbWDZpPuIgjzrltJnmw
RGPLKtRwISGiOV1N8mCISPSIdy05D4UdWY9IHizrbRUeesrFXuUvVgdJHhSr
t2q9X8dF5O3JjD6SzzyL852/1nMxdPvV0v//vl2QKXZf8Tlpx3MjwkjeG4oJ
03Zt4GJD1XGZDNKGT9OpnS+4+Hf0TzaLtI/Ymsy91kjmVyJ59Cy5vkstJ76z
iZy/3Zl5yeT+uhJTP6RfcTE8s4AjQfqPGwgKtHnNhaRIGpTI+Oqbnr7e+Ias
R+3nuU9I/ltSquuY10zGq3KCPyNOgPUnM+80tpD9qFL34PU2Ae7s+q0x3Urq
92Wsx5zkP9HANSf128j+Eo6GG2wWwJ1OSAW8I/v953+iFWS987VW7sxo58Jq
0obfvk6AH3NTvhEdXCw68VY6NUAA2+FBv6FOLti/e96+8BEgrdWjSfU9Fyb9
X0IKPAXoKL8H924udtl3b5Fkk/qdXXY7sYfcf5X8jWmn//Py5+z/PnLhJn3i
VD7ZT4tZLPGFvVwcy02pYeoLIDS4td2xj5xPppJskoYAM//E+Vz8zEW+nKLC
RTkBuF3dz1u+cLF83qXAw1ICnH3kaCP+lQub1zK9otN8WKfIqGz4Rp5Xu+7V
53/hI2XTlswT37nwaX/a8KSTj3fubTPrBsnzINiTuZ3kwW1KBX2UIS5u72qR
OkjO361rpkVfR7n4VSd7y203HyKZuUuVxrgIXkbb/oGcZ3bM9GHXcS78/KaK
Z/rz8c2mPvLaBBeBrOQl36350GjyNds0zQVFuEIlYNQLW0seXc4T4UFezuGE
30cvVJ/QUGiawcN/rcPyX8jzJyDg5199UR7ehs8z/v//n04NJT0akuRB66mx
632uF+YvLGLFLOBBn2LiGpzuicVv7x7IlONBfX1D8+9tnlDKfUIUL+SRHGWp
punvCQ2V9yafFvPg2eqQ6q/jCWtd2WUCJR7O7rM5rvvIAxsct3+nruDBTvnW
eHi7OyIk9ml6reQhdXqHYvcDd0Q/ywiM0uBhT+XEt6HT7tjFvdpSSOHhmgvO
j/m5I8u3q1JxFQ9i3ihP6eDh4VaHI5Om5H6i12fIknP1xJxbt8ScBx3VGbPP
5XNRP+E705TKw/uaO6dbdnLRvHfbto2WPHybznu3ypCLr2mF/u9tefhzdP5T
F30OFl+cp08480DVPJq95AoLG1s6mpJW83BFENXwWckZz/bHbcn14SGzaYpS
VuUEipmC/K01PEjV7uscCnLCx+N8//d+PFTFmd2+c5kOvverb9QgHiZq7p47
ou0IdNRKDYbx0ORs5pu62B4LPtxy8N7Fw5ZlOmY9Kqa49+3gXd2zPJi7bJHU
1l9GbLhaFkt85YGxUW2Wqqk7sdAxOKN9gAeDmvLq05HuxOOueVd+fePBqWKd
3+8id0JZNvQt5QcPMVojG+3UPIjm7UpmmSNkPTz0vefN9SRA3zsSOMnDl+Ur
NrW3exFLepibZpEcvn1E9mgHdzVRu+P3/mXz3CF+61mJx4HVxBa582fM57vD
2JHPPPxgNdHoNNkQvsAdQ90l2+xX+hD7iq/rNC92xw0mJ/n4qA8xFCfXf2G5
Ox6cUFtmfciXeLaoK9jJ0B3OMUZzh7atJb5utXRJMHKH1rf0rSuvrCVmN58w
qDB2h+abDS+/ta0lXLLc/xmauSNd5Yb9yaUBxHOZuuPLrNxRb66bTo0LIBok
Sup/ObpDMUWSvU87kPi2fv5NfSd3nJaJ1Ii3CySkazceD3Mm493/0sTyfwFj
AZz+VGHATIQoY+BJUkCBV/1K93xhwM0AnvzLTlJARGE8BnrLYcDO+Ygvo1hS
QECKxyBLXGLA7ljmFd5ZUkCJ4ZkvOW1iwA64Q/wYW1JA7zKsZON9YsBOdv7I
jl1SQE6QYOtqnmLAz/JzYnpiUkDWEfxbPdxiwPBR0Ui1Y1JA2z1hhAPrYsAQ
sS4v8GRSQH7KR0qD+WLAUG/p+2VnUkAVrKGErhVjwNDrXpVRbFJAoA4x3atK
Y8DwSrx7jG1SQFWufhE3V2PAEKoZYsduUkC1m2+0eWNjwFBo1C49cVJA/SQz
SiR7Y8DR5EnIKHZSQOV2JSMIp2PA8kOnrmN3UkD+HUswSLFjwBKjBJWeeFJA
GLBM2j27Y8BSYb9hFHtSQPxWPThJzmPAcsAcSE98UkDHh5uJXtdjwJIfei6K
fVJAKCC2sijgY8CyftcUxX5SQC/0C4an6GPA0t00+/9/UkA1rKDX2vBjwMtd
Sts=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{20., 0},
  Frame->True,
  FrameLabel->{None, None},
  Method->{},
  PlotRange->{{18, 74}, {-250, 150}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5755396540961323`*^9, 3.58658122459194*^9, 
  3.586967226103339*^9, 3.586969235733465*^9, 3.587092658603407*^9, 
  3.5870932852825994`*^9, 3.5870933524166546`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 4.5 Application: The tides of Io", "Title",
 CellChangeTimes->{{3.430557142957*^9, 3.430557151575*^9}, {
  3.5017457331459394`*^9, 3.5017457453136353`*^9}, {3.5017458852716403`*^9, 
  3.5017458857216663`*^9}}],

Cell["\<\
Notice that the object in bound rotation in all cases is called the \
\[OpenCurlyDoubleQuote]planet\[CloseCurlyDoubleQuote], and the other the \
\[OpenCurlyDoubleQuote]moon\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellChangeTimes->{{3.587094688904015*^9, 3.5870947351435633`*^9}}],

Cell[CellGroupData[{

Cell["Tides on Io", "Section",
 CellChangeTimes->{{3.5017459099690533`*^9, 3.501745914664322*^9}, {
  3.5870951803899875`*^9, 3.587095180598011*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.43055715363*^9, 3.430557156328*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(13\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575539815431489*^9, 3.586581226401206*^9, 
  3.5869672267474203`*^9, 3.5869692360204983`*^9, 3.5870948041498427`*^9, 
  3.587094875186367*^9, 3.587098749588394*^9, 3.5870988776887627`*^9, 
  3.587100307142278*^9}]
}, Open  ]],

Cell["Parameters ", "Text",
 CellChangeTimes->{{3.587093552070613*^9, 3.587093557286237*^9}, {
   3.587094376198496*^9, 3.587094415673232*^9}, 3.587100338895089*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", "GravitationalConstant"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", "=", 
   RowBox[{"421700", " ", "Kilometer"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "center", " ", "distance", " ", "between", " ", "Jupiter", " ", "and", " ",
     "Io"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"1821", "Kilometer"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"radius", " ", "of", " ", "Io"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]0", "=", 
   RowBox[{"3.528", " ", 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "density", " ", "of", " ", "Io"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]1", "=", 
   RowBox[{"2.0", 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "average", " ", "surface", " ", "density", " ", "of", " ", "Io", " ", 
    RowBox[{"(", "guessed", ")"}]}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"8.93*^22", "Kilogram"}]}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "of", " ", "Io"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"1.89*^27", "Kilogram"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "of", " ", "Jupiter"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4305571681029997`*^9, 3.43055718919*^9}, {
   3.430557223604*^9, 3.430557343773*^9}, {3.430557390789*^9, 
   3.430557400842*^9}, {3.430557457889*^9, 3.430557470174*^9}, {
   3.4305584975480003`*^9, 3.4305585269700003`*^9}, {3.430558608527*^9, 
   3.430558616646*^9}, {3.430558659685*^9, 3.4305586695220003`*^9}, {
   3.4305593321099997`*^9, 3.4305593404449997`*^9}, {3.430559648876*^9, 
   3.430559710543*^9}, {3.430732202724*^9, 3.43073222817*^9}, {
   3.4307324801429996`*^9, 3.4307324905950003`*^9}, {3.430732718527*^9, 
   3.43073271935*^9}, {3.5870935605096254`*^9, 3.587093610618637*^9}, {
   3.587093676638558*^9, 3.5870936836584005`*^9}, {3.587093891546343*^9, 
   3.587093893242546*^9}, 3.5870939744452906`*^9, {3.5870940538838215`*^9, 
   3.587094067280429*^9}, {3.5870941382209425`*^9, 3.5870941648231325`*^9}, {
   3.587094220188777*^9, 3.5870942343604765`*^9}, {3.5870943518355722`*^9, 
   3.5870943679225035`*^9}, {3.587094440440203*^9, 3.587094611993788*^9}, {
   3.5870946491142406`*^9, 3.587094664587098*^9}, {3.587094792468443*^9, 
   3.5870947968899713`*^9}, 3.5870948662192907`*^9, 3.587100086349785*^9}],

Cell["Distance variation in an orbit", "Text",
 CellChangeTimes->{{3.5870953168233557`*^9, 3.587095319237646*^9}, {
  3.587100410831721*^9, 3.5871004127009425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]D", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"423400", "-", "420000"}], ")"}], "Kilometer", " "}]}]], "Input",
 CellChangeTimes->{{3.587100090097234*^9, 3.5871000950098257`*^9}, 
   3.587100466446392*^9}],

Cell[BoxData[
 TemplateBox[{"3400"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.587100101215568*^9, 3.5871003074573135`*^9}]
}, Open  ]],

Cell["Gravitational range", "Text",
 CellChangeTimes->{{3.587095333542364*^9, 3.587095336421707*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hg", "=", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], "a", " ", 
    FractionBox["m", "M"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["a", "DD"], ")"}], "3"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["3", "5"], 
        FractionBox["\[Rho]1", "\[Rho]0"]}]}], ")"}], 
     RowBox[{"-", "1"}]]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.430558205119*^9, 3.430558212443*^9}, {3.430558328349*^9,
   3.4305583752209997`*^9}, {3.430558462657*^9, 3.430558468552*^9}, {
  3.430559362685*^9, 3.430559369196*^9}, {3.430559463399*^9, 
  3.430559471958*^9}}],

Cell[BoxData[
 TemplateBox[{"7054.661579333851`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.57553981600556*^9, 3.586581227232294*^9, 
  3.5869672275955167`*^9, 3.5869692370326195`*^9, 3.5870948048919325`*^9, 
  3.5870948757994385`*^9, 3.587098750175464*^9, 3.5870988782728324`*^9, 
  3.5871003077283497`*^9}]
}, Open  ]],

Cell["Centrifugal range", "Text",
 CellChangeTimes->{{3.587095340135154*^9, 3.587095343957611*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hc", "=", 
  RowBox[{
   FractionBox["1", "3"], 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["M", "m"]}], ")"}], "hg"}]}]], "Input",
 CellChangeTimes->{{3.430559481256*^9, 3.430559487722*^9}, 3.430560694248*^9}],

Cell[BoxData[
 TemplateBox[{"2351.6649675873036`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575539816113572*^9, 3.5865812273203106`*^9, 
  3.5869672277235327`*^9, 3.5869692372266436`*^9, 3.587094804996945*^9, 
  3.587094875910452*^9, 3.587098750283477*^9, 3.587098878380845*^9, 
  3.5871003078453603`*^9}]
}, Open  ]],

Cell["Maximal total range ", "Text",
 CellChangeTimes->{{3.587095515991254*^9, 3.587095526358497*^9}, 
   3.587095589942128*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hmax", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], "hc"}], "+", 
   RowBox[{
    FractionBox["2", "3"], "hg"}]}]}]], "Input",
 CellChangeTimes->{{3.430559491553*^9, 3.430559527473*^9}}],

Cell[BoxData[
 TemplateBox[{"5486.996042085001`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755398163265963`*^9, 3.5865812274402866`*^9, 
  3.58696722777954*^9, 3.5869692372766495`*^9, 3.587094805038948*^9, 
  3.587094875958459*^9, 3.587098750338482*^9, 3.587098878432852*^9, 
  3.5871003078833647`*^9}]
}, Open  ]],

Cell["Variation in maximal range", "Text",
 CellChangeTimes->{{3.587100211288777*^9, 3.58710023782096*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]hmax", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "3"}], ")"}], 
   FractionBox["\[CapitalDelta]D", "DD"], "*", "hmax"}]}]], "Input",
 CellChangeTimes->{{3.430558476949*^9, 3.430558494987*^9}, {3.430558590943*^9,
   3.430558591414*^9}, {3.43055930815*^9, 3.430559325796*^9}, {
  3.430559380337*^9, 3.430559382969*^9}, {3.430559538873*^9, 
  3.430559622572*^9}, {3.587098732629359*^9, 3.587098758004403*^9}, {
  3.587098857683364*^9, 3.587098858697485*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "132.7184245417762`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5870988786518774`*^9, 3.587100307996381*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tides on the Moon ", "Section",
 CellChangeTimes->{{3.430557142957*^9, 3.430557151575*^9}, {
   3.4305600651689997`*^9, 3.430560066352*^9}, {3.4305604260769997`*^9, 
   3.430560428531*^9}, {3.430560462762*^9, 3.430560464113*^9}, {
   3.430560881123*^9, 3.430560886545*^9}, 3.5870949930175047`*^9, {
   3.587095121160882*^9, 3.5870951292218466`*^9}, {3.5870951704377923`*^9, 
   3.587095195176762*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.43055715363*^9, 3.430557156328*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(12\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575539816744646*^9, 3.586581229310588*^9, 
  3.586967228330606*^9, 3.5869692386838183`*^9, 3.5870948763825083`*^9, 
  3.5870988222961187`*^9, 3.5870988929045877`*^9, 3.5870989264726176`*^9, 
  3.5870992956349115`*^9, 3.587100308260413*^9}]
}, Open  ]],

Cell["Parameters", "Text",
 CellChangeTimes->{{3.5871003454688764`*^9, 3.587100346796034*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", "GravitationalConstant"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", "=", "MoonOrbitRadius"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "center", " ", "distance", " ", "between", " ", "Earth", " ", "and", " ", 
    "Moon"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", "MoonRadius"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"radius", " ", "of", " ", "the", " ", "Moon"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]0", "=", 
   RowBox[{"3.346", " ", 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "density", " ", "of", " ", 
    RowBox[{"Moon", "'"}], "s", " ", "material"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]1", "=", 
   RowBox[{"0.9", "\[Rho]0"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "density", " ", "of", " ", "the", " ", 
    RowBox[{"Moon", "'"}], "s", " ", "surface", " ", "material", " ", 
    RowBox[{"(", "guessed", ")"}]}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", "MoonMass"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "of", " ", "the", " ", "Moon"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "EarthMass"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "of", " ", "the", " ", "Earth"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4305571681029997`*^9, 3.43055718919*^9}, {
   3.430557223604*^9, 3.430557343773*^9}, {3.430557390789*^9, 
   3.430557400842*^9}, {3.430557457889*^9, 3.430557470174*^9}, {
   3.4305584975480003`*^9, 3.4305585269700003`*^9}, {3.430558608527*^9, 
   3.430558616646*^9}, {3.430558659685*^9, 3.4305586695220003`*^9}, {
   3.4305593321099997`*^9, 3.4305593404449997`*^9}, {3.430559648876*^9, 
   3.430559710543*^9}, {3.430560073427*^9, 3.430560152791*^9}, {
   3.430560288135*^9, 3.4305603889300003`*^9}, {3.430560480717*^9, 
   3.4305606107720003`*^9}, {3.430560919084*^9, 3.430561031179*^9}, {
   3.430728150259*^9, 3.4307281673459997`*^9}, {3.430728237061*^9, 
   3.430728262091*^9}, {3.430730718789*^9, 3.43073071956*^9}, 
   3.430730751823*^9, {3.4307310235290003`*^9, 3.430731023895*^9}, 
   3.430732931185*^9, {3.587094889244052*^9, 3.587094971272894*^9}, {
   3.58709502457229*^9, 3.587095098433153*^9}, 3.5871001260625496`*^9}],

Cell["Distance variation in an orbit", "Text",
 CellChangeTimes->{{3.5870953168233557`*^9, 3.587095319237646*^9}, {
  3.587100410831721*^9, 3.5871004127009425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]D", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"405606", "-", "363104"}], ")"}], "Kilometer", " "}]}]], "Input",
 CellChangeTimes->{{3.43072757454*^9, 3.4307275769300003`*^9}, {
   3.5870992656653147`*^9, 3.587099291728441*^9}, {3.587100127422714*^9, 
   3.587100130161044*^9}, 3.5871004500164194`*^9}],

Cell[BoxData[
 TemplateBox[{"42502"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575539815664519*^9, 3.586581226782197*^9, 3.5869672270864544`*^9, 
   3.586969236443548*^9, 3.5870948045698924`*^9, 3.5870948755164056`*^9, 
   3.587098749887429*^9, 3.5870988779907994`*^9, {3.5870992565462217`*^9, 
   3.587099295850936*^9}, 3.587100308472437*^9}]
}, Open  ]],

Cell["Gravitational range", "Text",
 CellChangeTimes->{{3.587095333542364*^9, 3.587095336421707*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hg", "=", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], "a", " ", 
    FractionBox["m", "M"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["a", "DD"], ")"}], "3"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["3", "5"], 
        FractionBox["\[Rho]1", "\[Rho]0"]}]}], ")"}], 
     RowBox[{"-", "1"}]]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.430558205119*^9, 3.430558212443*^9}, {3.430558328349*^9,
   3.4305583752209997`*^9}, {3.430558462657*^9, 3.430558468552*^9}, {
  3.430559362685*^9, 3.430559369196*^9}, {3.430559463399*^9, 
  3.430559471958*^9}}],

Cell[BoxData[
 TemplateBox[{"42.591824697753914`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575539817278711*^9, 3.5865812298156176`*^9, 
  3.5869672290826936`*^9, 3.586969239255887*^9, 3.587094877015586*^9, 
  3.587098822741171*^9, 3.5870988933406415`*^9, 3.587098926909667*^9, 
  3.5870992961039677`*^9, 3.587100308733469*^9}]
}, Open  ]],

Cell["Centrifugal range", "Text",
 CellChangeTimes->{{3.587095340135154*^9, 3.587095343957611*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hc", "=", 
  RowBox[{
   FractionBox["1", "3"], 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox["M", "m"]}], ")"}], "hg"}]}]], "Input",
 CellChangeTimes->{{3.430559481256*^9, 3.430559487722*^9}, {3.430560635594*^9,
   3.430560656432*^9}}],

Cell[BoxData[
 TemplateBox[{"14.371960709502439`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755398175617456`*^9, 3.5865812298886075`*^9, 
  3.5869672292277126`*^9, 3.5869692394969144`*^9, 3.5870948771275983`*^9, 
  3.587098822848184*^9, 3.5870988934466543`*^9, 3.587098927017682*^9, 
  3.5870992962089806`*^9, 3.58710030884348*^9}]
}, Open  ]],

Cell["Maximal total range ", "Text",
 CellChangeTimes->{{3.587095515991254*^9, 3.587095526358497*^9}, 
   3.587095589942128*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hmax", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], "hc"}], "+", 
   RowBox[{
    FractionBox["2", "3"], "hg"}]}]}]], "Input",
 CellChangeTimes->{{3.430559491553*^9, 3.430559527473*^9}}],

Cell[BoxData[
 TemplateBox[{"33.18520336833676`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755398176097517`*^9, 3.586581229928633*^9, 
  3.586967229339726*^9, 3.5869692396069307`*^9, 3.587094877178605*^9, 
  3.5870988228921895`*^9, 3.58709889349366*^9, 3.5870989270646887`*^9, 
  3.587099296252985*^9, 3.5871003088834867`*^9}]
}, Open  ]],

Cell["Variation in maximal range", "Text",
 CellChangeTimes->{{3.587100211288777*^9, 3.58710023782096*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]hmax", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "3"}], ")"}], 
   FractionBox["\[CapitalDelta]D", "DD"], "*", "hmax"}]}]], "Input",
 CellChangeTimes->{{3.430558476949*^9, 3.430558494987*^9}, {3.430558590943*^9,
   3.430558591414*^9}, {3.43055930815*^9, 3.430559325796*^9}, {
  3.430559380337*^9, 3.430559382969*^9}, {3.430559538873*^9, 
  3.430559622572*^9}, {3.5017459393357325`*^9, 3.501745943741985*^9}, {
  3.587098909427571*^9, 3.587098913826101*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "11.00754821315019`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.587098927261712*^9, 3.587099296447009*^9, 
  3.587100308979496*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Tides of the Earth in bound rotation (static Earth)\
\>", "Section",
 CellChangeTimes->{{3.430557142957*^9, 3.430557151575*^9}, {
  3.4305600651689997`*^9, 3.430560066352*^9}, {3.4305604260769997`*^9, 
  3.430560428531*^9}, {3.430560462762*^9, 3.430560464113*^9}, {
  3.430560881123*^9, 3.430560886545*^9}, {3.430728109715*^9, 
  3.430728112642*^9}, {3.5870990263516016`*^9, 3.587099029885024*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.43055715363*^9, 3.430557156328*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(12\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.5755398180007973`*^9, 3.5865812302406545`*^9, 
  3.5869672299247956`*^9, 3.5869692403950253`*^9, 3.5870948775636506`*^9, 
  3.587099184373562*^9, 3.587099499529376*^9, 3.5870995719040594`*^9, 
  3.5871003092395277`*^9}]
}, Open  ]],

Cell["Parameters", "Text",
 CellChangeTimes->{{3.587100353708864*^9, 3.587100354940011*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", "GravitationalConstant"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", "=", "MoonOrbitRadius"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "center", " ", "distance", " ", "between", " ", "Moon", " ", "and", " ", 
    "Earth"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", "EarthRadius"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"radius", " ", "of", " ", "Earth"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]0", "=", 
   RowBox[{"5.51", " ", 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"average", " ", "mass", " ", "density", " ", "of", " ", "Earth"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]1", "=", 
   RowBox[{"4.5", " ", 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "average", " ", "mass", " ", "density", " ", "of", " ", "Earths", " ", 
    "surface", " ", "material"}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", "EarthMass"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "MoonMass"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4305571681029997`*^9, 3.43055718919*^9}, {
   3.430557223604*^9, 3.430557343773*^9}, {3.430557390789*^9, 
   3.430557400842*^9}, {3.430557457889*^9, 3.430557470174*^9}, {
   3.4305584975480003`*^9, 3.4305585269700003`*^9}, {3.430558608527*^9, 
   3.430558616646*^9}, {3.430558659685*^9, 3.4305586695220003`*^9}, {
   3.4305593321099997`*^9, 3.4305593404449997`*^9}, {3.430559648876*^9, 
   3.430559710543*^9}, {3.430560073427*^9, 3.430560152791*^9}, {
   3.430560288135*^9, 3.4305603889300003`*^9}, {3.430560480717*^9, 
   3.4305606107720003`*^9}, {3.430560919084*^9, 3.430561031179*^9}, {
   3.4307281355810003`*^9, 3.430728143531*^9}, {3.4307281808970003`*^9, 
   3.4307282280290003`*^9}, 3.4307290678380003`*^9, {3.43072920635*^9, 
   3.430729208389*^9}, 3.430729262683*^9, {3.430729646909*^9, 
   3.4307296497799997`*^9}, {3.430729728416*^9, 3.430729762175*^9}, 
   3.430732903475*^9, 3.5017460155910945`*^9, {3.5017460941325865`*^9, 
   3.501746115189791*^9}, {3.587099002457734*^9, 3.5870990061171737`*^9}, {
   3.5870990391701393`*^9, 3.5870990445617857`*^9}, {3.587099079454973*^9, 
   3.5870991777447653`*^9}, 3.587099476407602*^9, 3.5871001505894957`*^9}],

Cell["Distance variation in an orbit", "Text",
 CellChangeTimes->{{3.5870953168233557`*^9, 3.587095319237646*^9}, {
  3.587100410831721*^9, 3.5871004127009425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]D", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"405606", "-", "363104"}], ")"}], "Kilometer", " "}]}]], "Input",
 CellChangeTimes->{{3.5017461245133247`*^9, 3.501746127722508*^9}, {
   3.587100153422833*^9, 3.587100155190045*^9}, 3.587100457313295*^9}],

Cell[BoxData[
 TemplateBox[{"42502"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755398182818327`*^9, 3.5865812310637784`*^9, 
  3.5869672308519077`*^9, 3.5869692407950726`*^9, 3.5870948779516983`*^9, 
  3.5870991847116013`*^9, 3.587099499821409*^9, 3.5870995721960955`*^9, 
  3.587100310306656*^9}]
}, Open  ]],

Cell["Gravitational range", "Text",
 CellChangeTimes->{{3.587095333542364*^9, 3.587095336421707*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hg", "=", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], "a", " ", 
    FractionBox["m", "M"], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["a", "DD"], ")"}], "3"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["3", "5"], 
        FractionBox["\[Rho]1", "\[Rho]0"]}]}], ")"}], 
     RowBox[{"-", "1"}]]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.430558205119*^9, 3.430558212443*^9}, {3.430558328349*^9,
   3.4305583752209997`*^9}, {3.430558462657*^9, 3.430558468552*^9}, {
  3.430559362685*^9, 3.430559369196*^9}, {3.430559463399*^9, 
  3.430559471958*^9}}],

Cell[BoxData[
 TemplateBox[{"1.0544136576359167`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575539818793894*^9, 3.5865812322729096`*^9, 
  3.586967231294963*^9, 3.58696924120112*^9, 3.5870948783757524`*^9, 
  3.587099185021638*^9, 3.587099500088442*^9, 3.5870995724681273`*^9, 
  3.5871003117068243`*^9}]
}, Open  ]],

Cell["Centrifugal range", "Text",
 CellChangeTimes->{{3.587095340135154*^9, 3.587095343957611*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hc", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"M", "+", "m"}], 
    RowBox[{"3", "m"}]], "hg"}]}]], "Input",
 CellChangeTimes->{{3.430559481256*^9, 3.430559487722*^9}, {3.430560635594*^9,
   3.430560656432*^9}, {3.430728334856*^9, 3.430728346727*^9}}],

Cell[BoxData[
 TemplateBox[{"28.916662124836858`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575539818970913*^9, 3.5865812323759427`*^9, 
  3.5869672315159864`*^9, 3.586969241409144*^9, 3.587094878592774*^9, 
  3.5870991851886578`*^9, 3.5870995002514615`*^9, 3.587099572637146*^9, 
  3.5871003121428795`*^9}]
}, Open  ]],

Cell["Maximal total range ", "Text",
 CellChangeTimes->{{3.587095515991254*^9, 3.587095526358497*^9}, 
   3.587095589942128*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hmax", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], "hc"}], "+", 
   RowBox[{
    FractionBox["2", "3"], "hg"}]}]}]], "Input",
 CellChangeTimes->{{3.430559491553*^9, 3.430559527473*^9}}],

Cell[BoxData[
 TemplateBox[{"10.341829813369563`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755398190129194`*^9, 3.586581232408944*^9, 
  3.5869672317830205`*^9, 3.5869692416091685`*^9, 3.5870948790908346`*^9, 
  3.587099185225662*^9, 3.5870995002974653`*^9, 3.587099572680153*^9, 
  3.587100313021983*^9}]
}, Open  ]],

Cell["Variation in maximal range", "Text",
 CellChangeTimes->{{3.587100211288777*^9, 3.58710023782096*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]hmax", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "3"}], ")"}], 
   FractionBox["\[CapitalDelta]D", "DD"], "*", "hmax"}]}]], "Input",
 CellChangeTimes->{{3.430558476949*^9, 3.430558494987*^9}, {3.430558590943*^9,
   3.430558591414*^9}, {3.43055930815*^9, 3.430559325796*^9}, {
  3.430559380337*^9, 3.430559382969*^9}, {3.430559538873*^9, 
  3.430559622572*^9}, {3.5870995678285704`*^9, 3.5870995939557056`*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "3.430390015071499`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.5870995728781767`*^9, 3.5870995943237476`*^9}, 
   3.5871003132770123`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{928, 903},
WindowMargins->{{Automatic, 528}, {Automatic, 46}},
WindowFrame->"Normal",
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 106, 2, 65, "Title",
 InitializationCell->True],
Cell[1594, 39, 224, 5, 41, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[1855, 49, 144, 2, 65, "Title"],
Cell[CellGroupData[{
Cell[2024, 55, 136, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[2185, 61, 101, 2, 41, "Input"],
Cell[2289, 65, 312, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2638, 78, 74, 1, 36, "Subsection"],
Cell[2715, 81, 734, 20, 82, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3486, 106, 79, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[3590, 111, 416, 11, 61, "Input"],
Cell[4009, 124, 532, 12, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4602, 143, 142, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[4769, 149, 103, 2, 41, "Input"],
Cell[4875, 153, 335, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5247, 166, 102, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[5374, 171, 1281, 32, 105, "Input"],
Cell[6658, 205, 578, 14, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7285, 225, 97, 1, 36, "Subsection"],
Cell[7385, 228, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[7517, 233, 182, 5, 41, "Input"],
Cell[7702, 240, 757, 17, 41, "Output"]
}, Open  ]],
Cell[8474, 260, 90, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[8589, 265, 113, 3, 56, "Input"],
Cell[8705, 270, 187, 2, 41, "Output"]
}, Open  ]],
Cell[8907, 275, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[9035, 280, 307, 9, 56, "Input"],
Cell[9345, 291, 561, 12, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9979, 311, 116, 1, 65, "Title"],
Cell[CellGroupData[{
Cell[10120, 316, 77, 2, 41, "Input"],
Cell[10200, 320, 436, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10673, 335, 32, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[10730, 339, 743, 19, 99, "Input"],
Cell[11476, 360, 758, 17, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12283, 383, 97, 1, 36, "Subsection"],
Cell[12383, 386, 69, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[12477, 390, 254, 7, 61, "Input"],
Cell[12734, 399, 652, 15, 41, "Output"]
}, Open  ]],
Cell[13401, 417, 298, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[13724, 429, 239, 7, 66, "Input"],
Cell[13966, 438, 755, 17, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14758, 460, 237, 6, 58, "Input"],
Cell[14998, 468, 649, 14, 41, "Output"]
}, Open  ]],
Cell[15662, 485, 51, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[15738, 489, 114, 3, 41, "Input"],
Cell[15855, 494, 661, 14, 41, "Output"]
}, Open  ]],
Cell[16531, 511, 217, 3, 30, "Text"],
Cell[16751, 516, 511, 12, 62, "Input"],
Cell[CellGroupData[{
Cell[17287, 532, 265, 6, 41, "Input"],
Cell[17555, 540, 654, 14, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18258, 560, 230, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[18513, 567, 126, 2, 41, "Input"],
Cell[18642, 571, 487, 11, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19166, 587, 99, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[19290, 592, 1134, 24, 119, "Input"],
Cell[20427, 618, 574, 13, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21038, 636, 137, 2, 41, "Input"],
Cell[21178, 640, 810, 18, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22037, 664, 97, 1, 36, "Subsection"],
Cell[22137, 667, 177, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[22339, 673, 238, 7, 57, "Input"],
Cell[22580, 682, 935, 20, 41, "Output"]
}, Open  ]],
Cell[23530, 705, 108, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[23663, 710, 224, 6, 41, "Input"],
Cell[23890, 718, 936, 20, 41, "Output"]
}, Open  ]],
Cell[24841, 741, 144, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[25010, 748, 265, 7, 56, "Input"],
Cell[25278, 757, 750, 16, 41, "Output"]
}, Open  ]],
Cell[26043, 776, 289, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[26357, 785, 621, 15, 41, "Input"],
Cell[26981, 802, 395, 6, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27437, 815, 236, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[27698, 822, 103, 2, 41, "Input"],
Cell[27804, 826, 468, 11, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28309, 842, 99, 1, 36, "Subsection"],
Cell[28411, 845, 1205, 30, 122, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29653, 880, 97, 1, 36, "Subsection"],
Cell[29753, 883, 113, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[29891, 888, 276, 8, 57, "Input"],
Cell[30170, 898, 682, 15, 41, "Output"]
}, Open  ]],
Cell[30867, 916, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[30991, 921, 342, 11, 59, "Input"],
Cell[31336, 934, 343, 5, 41, "Output"]
}, Open  ]],
Cell[31694, 942, 131, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[31850, 949, 539, 16, 78, "Input"],
Cell[32392, 967, 678, 15, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33131, 989, 208, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[33364, 996, 125, 2, 41, "Input"],
Cell[33492, 1000, 466, 11, 21, "Message"]
}, Open  ]],
Cell[33973, 1014, 345, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[34343, 1028, 746, 25, 70, "Input"],
Cell[35092, 1055, 462, 12, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35615, 1074, 182, 2, 65, "Title"],
Cell[CellGroupData[{
Cell[35822, 1080, 104, 1, 75, "Section"],
Cell[CellGroupData[{
Cell[35951, 1085, 127, 2, 41, "Input"],
Cell[36081, 1089, 359, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36477, 1103, 100, 1, 36, "Subsection"],
Cell[36580, 1106, 726, 19, 122, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37343, 1130, 96, 1, 36, "Subsection"],
Cell[37442, 1133, 51, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[37518, 1137, 257, 7, 54, "Input"],
Cell[37778, 1146, 599, 13, 41, "Output"]
}, Open  ]],
Cell[38392, 1162, 184, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[38601, 1170, 181, 4, 41, "Input"],
Cell[38785, 1176, 606, 13, 41, "Output"]
}, Open  ]],
Cell[39406, 1192, 302, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[39733, 1201, 233, 6, 57, "Input"],
Cell[39969, 1209, 822, 20, 41, "Output"]
}, Open  ]],
Cell[40806, 1232, 162, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[40993, 1238, 198, 6, 58, "Input"],
Cell[41194, 1246, 823, 20, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42078, 1273, 30, 0, 75, "Section"],
Cell[42111, 1275, 30, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[42166, 1279, 361, 11, 57, "Input"],
Cell[42530, 1292, 556, 12, 41, "Output"]
}, Open  ]],
Cell[43101, 1307, 332, 6, 30, "Text"],
Cell[43436, 1315, 781, 21, 65, "Input"],
Cell[CellGroupData[{
Cell[44242, 1340, 314, 9, 68, "Input"],
Cell[44559, 1351, 183, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[44791, 1359, 99, 1, 75, "Section"],
Cell[CellGroupData[{
Cell[44915, 1364, 129, 2, 41, "Input"],
Cell[45047, 1368, 336, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45420, 1381, 104, 1, 36, "Subsection"],
Cell[45527, 1384, 133, 1, 30, "Text"],
Cell[45663, 1387, 414, 11, 41, "Input"],
Cell[46080, 1400, 275, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[46380, 1413, 329, 8, 56, "Input"],
Cell[46712, 1423, 876, 23, 56, "Output"]
}, Open  ]],
Cell[47603, 1449, 109, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[47737, 1454, 452, 13, 56, "Input"],
Cell[48192, 1469, 1100, 30, 78, "Output"]
}, Open  ]],
Cell[49307, 1502, 232, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[49564, 1513, 980, 30, 78, "Input"],
Cell[50547, 1545, 170, 2, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50778, 1554, 239, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[51042, 1561, 129, 2, 41, "Input"],
Cell[51174, 1565, 364, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51575, 1579, 152, 2, 36, "Subsection"],
Cell[51730, 1583, 3524, 66, 142, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55291, 1654, 97, 1, 36, "Subsection"],
Cell[55391, 1657, 493, 13, 30, "Text"],
Cell[CellGroupData[{
Cell[55909, 1674, 411, 9, 57, "Input"],
Cell[56323, 1685, 233, 3, 41, "Output"]
}, Open  ]],
Cell[56571, 1691, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[56703, 1696, 838, 15, 58, "Input"],
Cell[57544, 1713, 208, 3, 41, "Output"]
}, Open  ]],
Cell[57767, 1719, 184, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[57976, 1727, 446, 14, 56, "Input"],
Cell[58425, 1743, 231, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58693, 1752, 280, 8, 56, "Input"],
Cell[58976, 1762, 211, 3, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59224, 1770, 304, 8, 56, "Input"],
Cell[59531, 1780, 208, 3, 41, "Output"]
}, Open  ]],
Cell[59754, 1786, 465, 11, 30, "Text"],
Cell[60222, 1799, 1043, 24, 41, "Input"],
Cell[61268, 1825, 105, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[61398, 1830, 2260, 42, 65, "Input"],
Cell[63661, 1874, 22751, 379, 247, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86461, 2259, 155, 2, 36, "Subsection"],
Cell[86619, 2263, 107, 1, 30, "Text"],
Cell[86729, 2266, 658, 12, 41, "Input"],
Cell[CellGroupData[{
Cell[87412, 2282, 279, 6, 41, "Input"],
Cell[87694, 2290, 269, 5, 41, "Output"]
}, Open  ]],
Cell[87978, 2298, 567, 13, 41, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88582, 2316, 106, 1, 36, "Subsection"],
Cell[88691, 2319, 157, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[88873, 2325, 785, 20, 82, "Input"],
Cell[89661, 2347, 96066, 1576, 410, "Output"]
}, Open  ]],
Cell[185742, 3926, 246, 5, 30, "Text"],
Cell[185991, 3933, 1040, 25, 102, "Input"],
Cell[187034, 3960, 230, 5, 30, "Text"],
Cell[187267, 3967, 906, 24, 102, "Input"],
Cell[188176, 3993, 121, 3, 30, "Text"],
Cell[188300, 3998, 1210, 31, 96, "Input"],
Cell[CellGroupData[{
Cell[189535, 4033, 493, 9, 41, "Input"],
Cell[190031, 4044, 96043, 1575, 248, "Output"]
}, Open  ]],
Cell[286089, 5622, 104, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[286218, 5627, 778, 13, 62, "Input"],
Cell[286999, 5642, 354, 7, 21, "Message"],
Cell[287356, 5651, 140846, 2316, 247, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[428275, 7975, 223, 3, 65, "Title"],
Cell[428501, 7980, 289, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[428815, 7989, 149, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[428989, 7995, 118, 2, 41, "Input"],
Cell[429110, 7999, 431, 10, 21, "Message"]
}, Open  ]],
Cell[429556, 8012, 165, 2, 30, "Text"],
Cell[429724, 8016, 2651, 60, 167, "Input"],
Cell[432378, 8078, 165, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[432568, 8084, 248, 6, 41, "Input"],
Cell[432819, 8092, 467, 11, 41, "Output"]
}, Open  ]],
Cell[433301, 8106, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[433427, 8111, 663, 19, 59, "Input"],
Cell[434093, 8132, 644, 14, 41, "Output"]
}, Open  ]],
Cell[434752, 8149, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[434876, 8154, 248, 7, 56, "Input"],
Cell[435127, 8163, 642, 14, 41, "Output"]
}, Open  ]],
Cell[435784, 8180, 128, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[435937, 8186, 221, 7, 56, "Input"],
Cell[436161, 8195, 640, 14, 41, "Output"]
}, Open  ]],
Cell[436816, 8212, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[436948, 8217, 503, 10, 56, "Input"],
Cell[437454, 8229, 487, 11, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[437990, 8246, 407, 6, 75, "Section"],
Cell[CellGroupData[{
Cell[438422, 8256, 118, 2, 41, "Input"],
Cell[438543, 8260, 457, 10, 21, "Message"]
}, Open  ]],
Cell[439015, 8273, 94, 1, 30, "Text"],
Cell[439112, 8276, 2440, 54, 165, "Input"],
Cell[441555, 8332, 165, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[441745, 8338, 344, 7, 41, "Input"],
Cell[442092, 8347, 691, 15, 41, "Output"]
}, Open  ]],
Cell[442798, 8365, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[442924, 8370, 663, 19, 59, "Input"],
Cell[443590, 8391, 664, 14, 41, "Output"]
}, Open  ]],
Cell[444269, 8408, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[444393, 8413, 272, 8, 56, "Input"],
Cell[444668, 8423, 669, 14, 41, "Output"]
}, Open  ]],
Cell[445352, 8440, 128, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[445505, 8446, 221, 7, 56, "Input"],
Cell[445729, 8455, 664, 14, 41, "Output"]
}, Open  ]],
Cell[446408, 8472, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[446540, 8477, 505, 10, 56, "Input"],
Cell[447048, 8489, 510, 12, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[447607, 8507, 408, 7, 75, "Section"],
Cell[CellGroupData[{
Cell[448040, 8518, 118, 2, 41, "Input"],
Cell[448161, 8522, 437, 10, 21, "Message"]
}, Open  ]],
Cell[448613, 8535, 92, 1, 30, "Text"],
Cell[448708, 8538, 2440, 51, 167, "Input"],
Cell[451151, 8591, 165, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[451341, 8597, 294, 6, 41, "Input"],
Cell[451638, 8605, 643, 14, 41, "Output"]
}, Open  ]],
Cell[452296, 8622, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[452422, 8627, 663, 19, 59, "Input"],
Cell[453088, 8648, 641, 14, 41, "Output"]
}, Open  ]],
Cell[453744, 8665, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[453868, 8670, 279, 7, 57, "Input"],
Cell[454150, 8679, 644, 14, 41, "Output"]
}, Open  ]],
Cell[454809, 8696, 128, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[454962, 8702, 221, 7, 56, "Input"],
Cell[455186, 8711, 644, 14, 41, "Output"]
}, Open  ]],
Cell[455845, 8728, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[455977, 8733, 458, 9, 56, "Input"],
Cell[456438, 8744, 519, 12, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 4uDJb2mmz5j2vDKtF@bqjoDQ *)
