(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[    196764,       4801]
NotebookOptionsPosition[    186633,       4441]
NotebookOutlinePosition[    187104,       4459]
CellTagsIndexPosition[    187061,       4456]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Chapter 15  Viscosity (p. 243)", "Title",
 InitializationCell->True,
 CellChangeTimes->{{3.5020948321689568`*^9, 3.5020948350551214`*^9}, {
  3.587548397129208*^9, 3.5875484018287725`*^9}, {3.5875484396363087`*^9, 
  3.587548439732319*^9}}],

Cell[BoxData[
 RowBox[{"<<", "Lautrup`"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4212130499639997`*^9, 3.421213053002*^9}, 
   3.479265228395*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 15.1 Shear viscosity (p. 243)\
\>", "Title",
 CellChangeTimes->{{3.448514156382681*^9, 3.448514163670681*^9}, {
  3.50209485477625*^9, 3.5020948605675807`*^9}, {3.58754840446909*^9, 
  3.587548411012873*^9}, {3.5875484435247746`*^9, 3.5875484436517887`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Margin table of viscosities and comparison with Maxwell's expression (p. 245)\
\>", "Section",
 CellChangeTimes->{{3.448535668972*^9, 3.4485356830030003`*^9}, {
  3.502094928264453*^9, 3.5020949304315767`*^9}, {3.587548425609625*^9, 
  3.5875484367249584`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.448514165961681*^9, 3.4485141695306807`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(11\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{{3.575546928168169*^9, 3.575546997081436*^9}, 
   3.575547083354786*^9, 3.5755471614891615`*^9, {3.586582859094219*^9, 
   3.5865828862676163`*^9}, 3.58754826045481*^9, 3.5875489388842096`*^9, 
   3.5875489897593155`*^9, 3.587549438762188*^9, 3.5875543043679905`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5875488071113997`*^9, 3.587548809125642*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{"1", "Atmosphere"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T", "=", 
   RowBox[{
    RowBox[{"20.", " ", "Celsius"}], "//", 
    RowBox[{"ToUnit", "[", "Kelvin", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NA", "=", "AvogadroConstant"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rmol", "=", "MolarGasConstant"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.587548801384712*^9, {3.587549319430869*^9, 3.5875493206330156`*^9}, {
   3.5875494088696003`*^9, 3.587549409109632*^9}}],

Cell["\<\
Names and measured molar masses and viscosities\
\>", "Text",
 CellChangeTimes->{{3.587549343780793*^9, 3.5875493933807445`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"name", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<air\>\"", ",", "\"\<\!\(\*SubscriptBox[\(N\), \(2\)]\)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(O\), \(2\)]\)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(CO\), \(2\)]\)\>\"", ",", 
     "\"\<\!\(\*SubscriptBox[\(H\), \(2\)]\)\>\"", ",", "\"\<He\>\"", ",", 
     "\"\<Ne\>\"", ",", "\"\<Ar\>\""}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Mmol", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "29.0", ",", "28.0", ",", "32.0", ",", "44.0", ",", "2.0", ",", "4.0", 
      ",", "20.2", ",", "39.9"}], "}"}], " ", 
    RowBox[{"Gram", "/", "Mole"}]}]}], " ", ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "18.2", ",", "17.6", ",", "20.4", ",", "14.7", ",", "8.8", ",", "19.6", 
      ",", "31.3", ",", "22.3"}], "}"}], "Micropascal", " ", "Second"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.448535825106*^9, 3.448535826658*^9}, {3.448535870097*^9,
   3.448535872258*^9}, {3.5875487807032323`*^9, 3.5875487971832085`*^9}, {
  3.5875493774668355`*^9, 3.587549398905407*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.448536974316*^9, 3.448536980123*^9}, {
  3.5875492860228615`*^9, 3.5875492869319715`*^9}}],

Cell["Specific gas constant", "Text",
 CellChangeTimes->{{3.587548965382392*^9, 3.5875489686127768`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "=", 
  RowBox[{
   FractionBox["Rmol", "Mmol"], " ", "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.448536417598*^9, 3.448536435027*^9}, {3.448536566276*^9,
   3.448536567795*^9}, {3.5875486950829573`*^9, 3.5875487050981607`*^9}, {
  3.587548877995906*^9, 3.5875489036639853`*^9}, {3.5875489728912907`*^9, 
  3.587548973738393*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"286.70558965517245`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"296.94507500000003`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"259.826940625`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"188.96504772727275`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"4157.23105`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"2078.615525`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"411.6070346534654`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )], ",", 
   TemplateBox[{"208.38250877192985`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
              SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", 
              "\"/(\"", "\[InvisibleSpace]", 
              SuperscriptBox["\"s\"", "2"], "\[InvisibleSpace]", "\"K\"", 
              "\[InvisibleSpace]", "\")\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters squared per second squared kelvin"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox[
          SuperscriptBox["\"Meters\"", "2"], 
          RowBox[{"\"Kelvins\"", " ", 
            SuperscriptBox["\"Seconds\"", "2"]}]]}], "]"}]& )]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.587548879209051*^9, 3.587548904945137*^9}, 
   3.5875489406424227`*^9, 3.5875489916145363`*^9, 3.5875494405003963`*^9, 
   3.5875543060551944`*^9}]
}, Open  ]],

Cell["Molecular velocity", "Text",
 CellChangeTimes->{{3.5875489777968807`*^9, 3.5875489803401847`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vmol", "=", 
  RowBox[{
   SqrtBox[
    RowBox[{"3", "R", " ", "T"}]], "//", "ToSI", " "}]}]], "Input",
 CellChangeTimes->{{3.4485364921619997`*^9, 3.448536504948*^9}, 
   3.448536586854*^9, {3.448536636276*^9, 3.4485366374110003`*^9}, {
   3.5875488293110647`*^9, 3.5875488578494883`*^9}, 3.587548985115758*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"502.138656968612`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"511.026756842291`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"478.02175989452223`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"407.6583265723269`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{
             "\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
              "\"s\""}]}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"1912.087039578089`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"1352.0497119045772`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"601.6542251376534`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"428.09110869004707`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5875488596777067`*^9, 3.587548866585537*^9}, 
   3.587548910065753*^9, 3.587548941585535*^9, 3.5875489928506885`*^9, 
   3.5875494414295073`*^9, 3.587554307031311*^9}]
}, Open  ]],

Cell["Density", "Text",
 CellChangeTimes->{{3.587549015638421*^9, 3.5875490163084993`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]", "=", 
  RowBox[{
   FractionBox["p", 
    RowBox[{"R", " ", "T"}]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.448537123534*^9, 3.4485371462279997`*^9}, 
   3.58754901263506*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"1.205564785573401`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"1.16399358607087`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"1.3302783840809942`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"1.8291327781113669`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"0.08314239900506214`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"0.16628479801012427`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"0.8397382299511276`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )], ",", 
   TemplateBox[{"1.6586908601509898`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"kg\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", 
              SuperscriptBox["\"m\"", "3"]}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: kilograms per meter cubed"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Kilograms\"", 
          SuperscriptBox["\"Meters\"", "3"]]}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{3.587549021230091*^9, 3.587549442906685*^9, 
  3.587554308511487*^9}]
}, Open  ]],

Cell["Mean free path (estimate)", "Text",
 CellChangeTimes->{{3.5875490600527477`*^9, 3.587549073188325*^9}, {
  3.5875492504205914`*^9, 3.5875492559892592`*^9}, {3.587549427236806*^9, 
  3.587549428451951*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Lambda]", "=", 
  RowBox[{
   FractionBox["\[Eta]", 
    RowBox[{"0.452", "\[Rho]", " ", "vmol"}]], "//", 
   RowBox[{"ToUnit", "[", "Nanometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.448539363034*^9, 3.4485393863710003`*^9}, {
  3.448539479848*^9, 3.448539484019*^9}, {3.448540039093*^9, 
  3.448540043524*^9}, {3.575547011390153*^9, 3.575547014583536*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"66.51486940245826`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"65.46060364204034`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"70.97436766565902`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"43.61514796653201`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"122.46557557996067`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"192.8734413077586`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"137.0613504313317`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"69.48079337995782`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{{3.5755469377233143`*^9, 3.5755470172578554`*^9}, 
   3.5755470916297817`*^9, 3.5755471696741447`*^9, {3.5865828634477463`*^9, 
   3.5865828903030787`*^9}, 3.587548269807931*^9, 3.587548869409876*^9, 
   3.5875489452029676`*^9, 3.5875489965591307`*^9, 3.5875494449659324`*^9, 
   3.587554310558733*^9}]
}, Open  ]],

Cell["Molecular diameter", "Text",
 CellChangeTimes->{{3.587549089268255*^9, 3.587549091508523*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "=", 
  RowBox[{
   SqrtBox[
    FractionBox["Mmol", 
     RowBox[{
      SqrtBox["2"], "\[Pi]", " ", "\[Rho]", " ", "NA", " ", "\[Lambda]"}]]], "//", 
   RowBox[{"ToUnit", "[", "Nanometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4485371573199997`*^9, 3.448537175042*^9}, 
   3.5875490856888266`*^9, 3.587549314661299*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"0.3676515871265667`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.370600340136052`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.35591398283333736`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.45402225502311483`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.2709497798567851`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.2159034597752122`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.25611694522516987`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )], ",", 
   TemplateBox[{"0.35971904524035636`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"nm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: nanometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Nanometers\""}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{{3.575546940716672*^9, 3.5755470385264072`*^9}, 
   3.5755470946511436`*^9, 3.5755471727395115`*^9, {3.586582865005906*^9, 
   3.5865828918803062`*^9}, 3.5875482726762733`*^9, 3.5875488713141036`*^9, 
   3.587548948172323*^9, 3.587548999492481*^9, 3.5875490979642982`*^9, 
   3.587549447903286*^9, 3.587554313551094*^9}]
}, Open  ]],

Cell["Margin table", "Text",
 CellChangeTimes->{{3.587549230246172*^9, 3.5875492321323957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"name", ",", 
     RowBox[{"\[Eta]", "//", "NoUnit"}], ",", 
     RowBox[{"\[Lambda]", "//", "NoUnit"}], ",", 
     RowBox[{"d", "//", "NoUnit"}]}], "}"}], "//", "Transpose"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.448539993744*^9, 3.44854001896*^9}, {3.448540053106*^9, 
   3.448540082785*^9}, 3.475551975258218*^9, {3.502095171203348*^9, 
   3.502095203881217*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"air\"\>", "18.2`", "66.51486940245826`", "0.3676515871265667`"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(N\\), \\(2\\)]\\)\"\>", "17.6`", 
     "65.46060364204034`", "0.370600340136052`"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(O\\), \\(2\\)]\\)\"\>", "20.4`", 
     "70.97436766565902`", "0.35591398283333736`"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(CO\\), \\(2\\)]\\)\"\>", "14.7`", 
     "43.61514796653201`", "0.45402225502311483`"},
    {"\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(2\\)]\\)\"\>", "8.8`", 
     "122.46557557996067`", "0.2709497798567851`"},
    {"\<\"He\"\>", "19.6`", "192.8734413077586`", "0.2159034597752122`"},
    {"\<\"Ne\"\>", "31.3`", "137.0613504313317`", "0.25611694522516987`"},
    {"\<\"Ar\"\>", "22.3`", "69.48079337995782`", "0.35971904524035636`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5755469408756914`*^9, 3.5755470088048434`*^9}, 
   3.5755470417217927`*^9, 3.57554709480116*^9, 3.575547172908532*^9, {
   3.586582865062954*^9, 3.586582891966287*^9}, 3.587548272773286*^9, 
   3.5875488721021986`*^9, 3.5875489483713493`*^9, 3.5875489995964947`*^9, 
   3.5875491052841763`*^9, 3.5875494479982977`*^9, 3.587554313903135*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 15.2 Velocity-driven planar flow (p. 246)\
\>", "Title",
 CellChangeTimes->{{3.502099603919885*^9, 3.50209961868773*^9}, {
  3.5875494914315085`*^9, 3.5875494961810784`*^9}}],

Cell[CellGroupData[{

Cell["\<\
 Example 15.1 Curling (page 247)\
\>", "Section",
 CellChangeTimes->{
  3.4212955692080755`*^9, {3.587549469366861*^9, 3.587549508964613*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(12\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.5755472105120444`*^9, {3.58658286522893*^9, 3.5865828922943287`*^9}, 
   3.5875482730373173`*^9, {3.587549603467952*^9, 3.587549624993535*^9}, 
   3.5875498134561453`*^9, 3.5875500343206477`*^9, 3.587550075327566*^9, 
   3.5875501204559813`*^9, 3.587550201754736*^9, 3.587554314395194*^9}]
}, Open  ]],

Cell["Parameters", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["U", "0"], "=", 
   RowBox[{"3", " ", 
    RowBox[{"Meter", "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"initial", " ", "speed", " ", "of", " ", "the", " ", "stone"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"20", " ", "Kilogram"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "of", " ", "the", " ", "stone"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"700", " ", 
    SuperscriptBox["Centimeter", "2"]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"contact", " ", "area", " ", "of", " ", "stone"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"40", " ", "Meter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "rink"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"1", 
    RowBox[{"Gram", "/", 
     SuperscriptBox["Centimeter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"density", " ", "of", " ", "water"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Eta]", "=", 
   RowBox[{"1.79", " ", "Milli", " ", "Pascal", " ", "Second"}]}], 
  RowBox[{"(*", " ", 
   RowBox[{"at", " ", "0", " ", "Celsius"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.587549587516038*^9, 3.5875496216411324`*^9}, {
  3.587549759949727*^9, 3.5875497748885193`*^9}, {3.587549990615403*^9, 
  3.5875500273558116`*^9}, {3.587550063837189*^9, 3.587550197347209*^9}}],

Cell["Thickness ", "Text",
 CellChangeTimes->{{3.5875499764387026`*^9, 3.58754998218039*^9}, 
   3.5875500315403132`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"L", " ", "\[Eta]", " ", "A"}], 
    RowBox[{
     SubscriptBox["U", "0"], "M", " "}]], "//", 
   RowBox[{"ToUnit", "[", "Micrometer", "]"}]}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"83.53333333333333`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"\[Micro]m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: micrometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Micrometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575547211374148*^9, {3.5865828656120214`*^9, 3.5865828930864897`*^9}, 
   3.5875482737494044`*^9, {3.587549604333055*^9, 3.5875496258526354`*^9}, 
   3.5875498143052473`*^9, 3.5875500350727386`*^9, 3.587550076092658*^9, 
   3.5875501212320757`*^9, 3.5875502025358295`*^9, 3.5875543155523324`*^9}]
}, Open  ]],

Cell["Time scale for stopping", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]", "=", 
  RowBox[{
   RowBox[{
    FractionBox["L", 
     SubscriptBox["U", "0"]], "//", "ToSI"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.4212955555140753`*^9, 3.4212955562800756`*^9}}],

Cell[BoxData[
 TemplateBox[{"13.333333333333334`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"s\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: seconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Seconds\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755472114911623`*^9, {3.58658286566899*^9, 3.5865828932144833`*^9}, 
   3.5875482739254255`*^9, {3.5875496044480677`*^9, 3.587549625961649*^9}, 
   3.58754981441226*^9, 3.5875500351817513`*^9, 3.587550076202673*^9, 
   3.5875501213420873`*^9, 3.5875502026458426`*^9, 3.587554315717352*^9}]
}, Open  ]],

Cell["Reynolds number", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reynolds", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"\[Rho]", " ", 
     SubscriptBox["U", "0"], "d"}], "\[Eta]"], "//", "ToSI"}]}]], "Input"],

Cell[BoxData["139.99999999999997`"], "Output",
 CellChangeTimes->{
  3.575547211911211*^9, {3.5865828658710566`*^9, 3.586582893429515*^9}, 
   3.587548274314472*^9, {3.5875496048621187`*^9, 3.587549626346695*^9}, 
   3.587549814799309*^9, 3.5875500355397944`*^9, 3.587550076561714*^9, 
   3.587550121714133*^9, 3.5875502030138865`*^9, 3.587554316141403*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Case: Shear wave (p. 247)", "Section",
 CellChangeTimes->{{3.502099706015725*^9, 3.5020997098799458`*^9}, {
  3.5875502465831156`*^9, 3.5875502498765106`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(9\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575547212290258*^9, {3.586582866046034*^9, 3.586582893628552*^9}, 
   3.5875482745815043`*^9, {3.587549605189161*^9, 3.587549626651732*^9}, 
   3.587554316605462*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters ", "Subsection",
 CellChangeTimes->{3.587550511155859*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Nu]", "air"], "=", 
   RowBox[{"1.53", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"viscosity", " ", "of", " ", "air"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Nu]", "water"], "=", 
   RowBox[{"1.0", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], 
  RowBox[{"(*", " ", 
   RowBox[{"viscosity", " ", "of", " ", "water"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]", "=", 
   RowBox[{"2", " ", "\[Pi]", " ", "1000", " ", "Hertz"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"circular", " ", "frequency"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.587550335898832*^9, 3.5875503364248943`*^9}, {
  3.5875505064272933`*^9, 3.587550523654359*^9}, {3.5875505905703897`*^9, 
  3.587550621544106*^9}, {3.587550656525303*^9, 3.5875506592916355`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1.53", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "5"}]]}], ",", 
      RowBox[{"1.0", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]]}]}], "}"}], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"viscosities", " ", "of", " ", "air", " ", "and", " ", "water"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]", "=", 
   RowBox[{"2", " ", "\[Pi]", " ", "1000", " ", "Hertz"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"circular", " ", "frequency"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.587550335898832*^9, 3.5875503364248943`*^9}, {
  3.5875505064272933`*^9, 3.587550523654359*^9}, {3.5875505905703897`*^9, 
  3.587550621544106*^9}, {3.587550656525303*^9, 3.5875506592916355`*^9}, {
  3.5875507046770806`*^9, 3.587550741401486*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results ", "Subsection",
 CellChangeTimes->{{3.587550450758614*^9, 3.5875504529488764`*^9}, {
   3.587550667861663*^9, 3.5875506708690233`*^9}, 3.5875509046600757`*^9}],

Cell["Wave number and wavelength", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", 
   SqrtBox[
    FractionBox["\[Omega]", 
     RowBox[{"2", "\[Nu]"}]]]}], ";"}], "\n", 
 RowBox[{"\[Lambda]", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "k"], "//", 
   RowBox[{"ToUnit", "[", "Millimeter", "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"0.43848086662897323`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: millimeters"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )], ",", 
   TemplateBox[{"0.11209982432795858`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: millimeters"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755472125582895`*^9, {3.586582866313097*^9, 3.5865828938685856`*^9}, 
   3.5875482748275347`*^9, {3.5875496054421883`*^9, 3.5875496268797607`*^9}, 
   3.5875507508196173`*^9, 3.58755431743356*^9}]
}, Open  ]],

Cell["Penetration depth", "Text",
 CellChangeTimes->{{3.5875504193328457`*^9, 3.587550427300799*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "=", 
  RowBox[{
   FractionBox["1", "k"], "//", 
   RowBox[{"ToUnit", "[", "Micrometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4212985684300756`*^9, 3.4212985758490753`*^9}, {
  3.5021025711085987`*^9, 3.502102571515622*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"69.78639737521918`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"\[Micro]m\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: micrometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Micrometers\""}], "]"}]& )], ",", 
   TemplateBox[{"17.841241161527712`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"\[Micro]m\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: micrometers"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Micrometers\""}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575547212725309*^9, {3.5865828663801327`*^9, 3.5865828939565525`*^9}, 
   3.5875482749295444`*^9, {3.5875496054921956`*^9, 3.5875496269267645`*^9}, 
   3.587550793337719*^9, 3.5875543176305823`*^9}]
}, Open  ]],

Cell["Transverse speed of sound", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["C", "T"], "=", 
  RowBox[{
   FractionBox["\[Omega]", "k"], "//", "ToSI"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"0.4384808666289732`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"0.11209982432795858`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.575547212875327*^9, {3.5865828664371233`*^9, 3.586582894020584*^9}, 
   3.5875482750515594`*^9, {3.587549605592206*^9, 3.5875496270177765`*^9}, 
   3.587550884783692*^9, 3.587554317903614*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Margin figure (p. 248 top)", "Section",
 CellChangeTimes->{{3.502099737945551*^9, 3.5020997559365797`*^9}, {
  3.5875509851107297`*^9, 3.5875509928526573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(8\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755472148905706`*^9, {3.5865828675742645`*^9, 3.5865828945406537`*^9}, 
   3.587548275672633*^9, {3.5875496062672873`*^9, 3.587549627661853*^9}, 
   3.58755108031315*^9, 3.587551144975911*^9, 3.5875512041880136`*^9, 
   3.587551350454565*^9, 3.587551389749278*^9, 3.5875543181656475`*^9}]
}, Open  ]],

Cell["\<\
Check that the following expression for velocity satisfies the diffusion \
equation\
\>", "Text",
 CellChangeTimes->{
  3.4222366849123945`*^9, 3.4222370441333942`*^9, {3.587551048053282*^9, 
   3.5875510566293087`*^9}, {3.587551099524457*^9, 3.587551130020115*^9}, 
   3.587551263060077*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", 
   SqrtBox[
    FractionBox["\[Omega]", 
     RowBox[{"2", "\[Nu]"}]]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["v", "x"], "=", 
   RowBox[{
    SubscriptBox["U", "0"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "k"}], " ", "y"}]], 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"k", " ", "y"}], "-", 
      RowBox[{"\[Omega]", " ", "t"}]}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    SubscriptBox["v", "x"]}], "\[Equal]", " ", 
   RowBox[{"\[Nu]", " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[PartialD]", "y"], "2"], 
     SubscriptBox["v", "x"]}]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{
  3.587551141127446*^9, {3.587551197082164*^9, 3.5875511988893805`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.575547215324621*^9, {3.5865828676612616`*^9, 3.586582894573654*^9}, 
   3.587548275725642*^9, {3.5875496063132935`*^9, 3.58754962770586*^9}, 
   3.587551080441166*^9, 3.5875511450639195`*^9, 3.5875512042820272`*^9, 
   3.5875513505615783`*^9, 3.58755138984029*^9, 3.587554318204651*^9}]
}, Open  ]],

Cell[TextData[{
 "Plot for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", 
    RowBox[{"2", "\[Pi]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (\[Lambda]=1)"
}], "Text",
 CellChangeTimes->{{3.5875512577804446`*^9, 3.5875512585485373`*^9}, {
  3.587551318052677*^9, 3.587551336068838*^9}, {3.5875513694838495`*^9, 
  3.587551375772601*^9}, {3.5875514295410547`*^9, 3.5875514330124702`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", " ", "2"}], "\[Pi]", " ", "y"}], "]"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Pi]", "  ", "y"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "0.7"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25"}], ",", "1"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "->", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"HoldForm", "[", 
        SubscriptBox["v", "x"], "]"}]}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<viscosity-transversewave\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "120"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.390121692683355*^9, {3.421297847579076*^9, 3.4212978505420756`*^9}, {
   3.422236693097394*^9, 3.422236695094394*^9}, {3.422236731408394*^9, 
   3.422236777339394*^9}, {3.4222369696623945`*^9, 3.422236969746394*^9}, 
   3.4309107576426*^9, {3.47555222513251*^9, 3.4755522347340593`*^9}, {
   3.4755523598502154`*^9, 3.475552359967222*^9}, {3.475552441176867*^9, 
   3.475552441270872*^9}, {3.4766956590470085`*^9, 3.4766956664424314`*^9}, {
   3.4792653028380003`*^9, 3.479265303043*^9}, {3.5020997692643423`*^9, 
   3.502099797164938*^9}, {3.587551339749281*^9, 3.5875513461100435`*^9}, {
   3.587551379872095*^9, 3.5875514132551003`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.5755472157706776`*^9, {3.5865828678603015`*^9, 3.586582894733671*^9}, 
   3.5875482761476903`*^9, {3.5875496065353193`*^9, 3.5875496279288855`*^9}, 
   3.587551080661194*^9, 3.587551145282946*^9, 3.587551204499051*^9, 
   3.5875513507756042`*^9, {3.5875513900543156`*^9, 3.5875514148812957`*^9}, 
   3.5875543184306793`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1Xc4lf/7APBD+pCUCsnKzGiQCCVuWiQrESklo09KGRmFrzKqE2nXR8je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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["y", TraditionalForm], 
    FormBox[
     TagBox[
      SubscriptBox["v", "x"], HoldForm], TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 0.7}, {-0.25, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.575547215775677*^9, {3.586582867863262*^9, 3.5865828947366533`*^9}, 
   3.5875482761516933`*^9, {3.5875496065403194`*^9, 3.5875496279328856`*^9}, 
   3.587551080669196*^9, 3.5875511452899466`*^9, 3.587551204506052*^9, 
   3.5875513507836037`*^9, {3.587551390060315*^9, 3.5875514148882937`*^9}, 
   3.5875543184356804`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Margin figure (p. 248 bottom)", "Section",
 CellChangeTimes->{{3.5020998940964823`*^9, 3.502099906831211*^9}, {
  3.587551164742281*^9, 3.587551171140049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(8\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575547216976819*^9, {3.58658286806033*^9, 3.5865828949397078`*^9}, 
   3.587548276549739*^9, {3.5875496068063507`*^9, 3.587549628186916*^9}, 
   3.5875512164294825`*^9, 3.587554318781721*^9}]
}, Open  ]],

Cell["Check that the following satisfies the diffusion equation", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["v", "x"], "[", 
    RowBox[{"y_", ",", "t_"}], "]"}], "=", 
   RowBox[{
    SubscriptBox["v", "0"], 
    FractionBox["a", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       RowBox[{"4", "\[Nu]", " ", "t"}]}]]], 
    RowBox[{"Exp", "[", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["y", "2"], 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"4", "\[Nu]", " ", "t"}]}]]}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "t"], 
    RowBox[{
     SubscriptBox["v", "x"], "[", 
     RowBox[{"y", ",", "t"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"\[Nu]", " ", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[PartialD]", "y"], "2"], 
     RowBox[{
      SubscriptBox["v", "x"], "[", 
      RowBox[{"y", ",", "t"}], "]"}]}]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.4766948709319315`*^9, 3.4766948817435493`*^9}, {
  3.4789174290352273`*^9, 3.478917434642548*^9}, {3.478957151131844*^9, 
  3.478957159243308*^9}, {3.587551184960709*^9, 3.587551211803928*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.5755472171538415`*^9, {3.5865828684613667`*^9, 3.5865828949796667`*^9}, 
   3.587548276616749*^9, {3.5875496068513565`*^9, 3.5875496282309213`*^9}, 
   3.587551216564498*^9, 3.5875543188827324`*^9}]
}, Open  ]],

Cell["\<\
Convenient values for illustration\
\>", "Text",
 CellChangeTimes->{{3.5875512393822393`*^9, 3.5875512464370832`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["v", "0"], "=", 
   RowBox[{"a", "=", 
    RowBox[{"\[Nu]", "=", "1"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4789174663703623`*^9, 3.478917480733184*^9}, {
  3.478917608172473*^9, 3.478917609740563*^9}}],

Cell["Plot Gaussians of different widths", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["v", "x"], "[", 
       RowBox[{"y", ",", "0"}], "]"}], ",", 
      RowBox[{
       SubscriptBox["v", "x"], "[", 
       RowBox[{"y", ",", "1"}], "]"}], ",", 
      RowBox[{
       SubscriptBox["v", "x"], "[", 
       RowBox[{"y", ",", "5"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "8"}], ",", "8"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       SubscriptBox["v", "x"]}], "}"}]}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<viscosity-momentumdiffusion\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "140"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4789175051115785`*^9, 3.478917545360881*^9}, {
   3.4789176191250997`*^9, 3.478917735184738*^9}, {3.4789177750860205`*^9, 
   3.4789178047237153`*^9}, {3.47891785742873*^9, 3.4789179054684772`*^9}, 
   3.4789191817074747`*^9, {3.4789571779723787`*^9, 3.4789571828396573`*^9}, {
   3.4792653361070004`*^9, 3.479265336644*^9}, {3.5014918584900284`*^9, 
   3.501491890454857*^9}, {3.50149192915207*^9, 3.5014919528724265`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.57554721746988*^9, {3.586582868678363*^9, 3.5865828951657076`*^9}, 
   3.587548276944788*^9, {3.5875496071553946`*^9, 3.5875496285269585`*^9}, 
   3.587551216865535*^9, 3.5875543191937695`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwUV3c41t8btvd4X5tkhRAyUsjnnE92ykwqu6LsrCQ7SUNJKikjUfSl7DKS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     "]]}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJw1mnk0lV/Ux8s8z7PrXhQhY4kozz4pmTImZcgUDSqZEpVZoomEIhkjMqQQ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     "]]}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJw12Hk0VV/YB/AiKSQUUu69IWNSImM8R0kiiYjKkH6lTBUp/CTjlchMGUuh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["y", TraditionalForm], 
    FormBox[
     SubscriptBox["v", "x"], TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.575547217474881*^9, {3.5865828686793633`*^9, 3.586582895167717*^9}, 
   3.587548276949789*^9, {3.5875496071653957`*^9, 3.5875496285369596`*^9}, 
   3.587551216872535*^9, 3.5875543192047706`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Case: Growth of a boundary layer (p. 248)\
\>", "Section",
 CellChangeTimes->{{3.5020999819685087`*^9, 3.5020999893189287`*^9}, {
  3.5875514691248026`*^9, 3.587551476484686*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(6\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575547217748912*^9, {3.5865828694375124`*^9, 3.5865828953787727`*^9}, 
   3.587548277214821*^9, {3.587549607494433*^9, 3.587549628871998*^9}, 
   3.587551487568015*^9, 3.58755188264342*^9, 3.587554319503807*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumption", "Subsection",
 CellChangeTimes->{{3.4766967543006535`*^9, 3.476696761426061*^9}, {
  3.5021000069039345`*^9, 3.502100008488025*^9}}],

Cell["Convert from s to y and back", "Text",
 CellChangeTimes->{{3.5875515270287504`*^9, 3.587551535668788*^9}}],

Cell[BoxData[{
 RowBox[{"do", ":=", 
  RowBox[{
   RowBox[{"#", "/.", 
    RowBox[{"s", "\[Rule]", 
     FractionBox["y", 
      SqrtBox[
       RowBox[{"\[Nu]", " ", "t"}]]]}]}], "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"undo", ":=", 
  RowBox[{
   RowBox[{"#", "/.", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"s", " ", 
      SqrtBox[
       RowBox[{"\[Nu]", " ", "t"}]]}]}]}], "&"}]}]}], "Input",
 CellChangeTimes->{{3.4766959511807175`*^9, 3.476696043415993*^9}, {
  3.4789192108291397`*^9, 3.4789192119932065`*^9}, {3.47895725753793*^9, 
  3.4789572598370614`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["v", "x"], "=", 
   RowBox[{
    RowBox[{"U", " ", 
     RowBox[{"f", "[", "s", "]"}]}], "//", "do"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4766959384999924`*^9, 3.4766959465754547`*^9}, {
  3.476695990085943*^9, 3.4766959907869835`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"zero", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "t"], 
      SubscriptBox["v", "x"]}], "-", 
     RowBox[{"\[Nu]", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[PartialD]", "y"], "2"], 
       SubscriptBox["v", "x"]}]}]}], "//", "undo"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4766948851907463`*^9, 3.4766948869628477`*^9}, {
  3.4766960225748014`*^9, 3.4766960581328354`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "zero"}], "   ", 
   RowBox[{"t", "/", "U"}]}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.4766960600969477`*^9, 3.4766960715166006`*^9}, {
   3.4789192761718774`*^9, 3.4789192834472933`*^9}, 3.47895726715548*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "s", " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "s", "]"}]}]], "Output",
 CellChangeTimes->{
  3.57554721781592*^9, {3.5865828696375275`*^9, 3.586582895408764*^9}, 
   3.5875482773528366`*^9, {3.5875496075544405`*^9, 3.587549628935008*^9}, 
   3.5875514877170343`*^9, 3.5875518827874365`*^9, 3.5875543197188344`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution", "Subsection",
 CellChangeTimes->{{3.4766967662853394`*^9, 3.476696767260395*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "s_", "]"}], "=", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["\[Pi]"]], 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "s", "\[Infinity]"], 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["u", "2"], "4"]}], "]"}], 
     RowBox[{"\[DifferentialD]", "u"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.476696459411787*^9, 3.4766965344200773`*^9}, {
   3.478919764151788*^9, 3.478919773383316*^9}, {3.478957361053851*^9, 
   3.4789573838131523`*^9}, {3.478957507515228*^9, 3.478957511030429*^9}, {
   3.4914506628929996`*^9, 3.4914506755950003`*^9}, 3.5021000344245086`*^9}],

Cell[BoxData[
 RowBox[{"Erfc", "[", 
  FractionBox["s", "2"], "]"}]], "Output",
 CellChangeTimes->{
  3.575547218512003*^9, {3.5865828707946887`*^9, 3.586582895976793*^9}, 
   3.5875482783809605`*^9, {3.587549608063501*^9, 3.5875496294520693`*^9}, 
   3.5875518832814956`*^9, 3.587554320402915*^9}]
}, Open  ]],

Cell["Slope at zero", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]", "=", 
  RowBox[{
   RowBox[{"f", "'"}], "[", "0", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SqrtBox["\[Pi]"]]}]], "Output",
 CellChangeTimes->{
  3.575547218818042*^9, {3.586582871034724*^9, 3.5865828960518365`*^9}, 
   3.5875482786499925`*^9, {3.5875496082005186`*^9, 3.587549629641092*^9}, 
   3.5875518833224993`*^9, 3.587554320495926*^9}]
}, Open  ]],

Cell["Series expansions for small s", "Text",
 CellChangeTimes->{{3.444115065190612*^9, 3.444115068281612*^9}, {
  3.587551601828726*^9, 3.5875516038439665`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"f", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4914507187139997`*^9, 3.491450719031*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox["s", 
    SqrtBox["\[Pi]"]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "s", "]"}], "2"],
    SeriesData[$CellContext`s, 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`s, 0, {1, -Pi^Rational[-1, 2]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.575547218706028*^9, {3.5865828709436493`*^9, 3.586582895992803*^9}, 
   3.587548278514977*^9, {3.5875496080995073`*^9, 3.5875496294860725`*^9}, 
   3.5875518833565054`*^9, 3.587554320575937*^9}]
}, Open  ]],

Cell["Series expansion for large s", "Text",
 CellChangeTimes->{{3.5875516118449287`*^9, 3.587551616004425*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"f", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.444115079011612*^9, 3.444115085845612*^9}, {
  3.491450697803*^9, 3.4914506990179996`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["s", "2"], "4"]}]], " ", 
  RowBox[{"(", 
   InterpretationBox[
    RowBox[{
     FractionBox["2", 
      RowBox[{
       SqrtBox["\[Pi]"], " ", "s"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "s"], "]"}], "2"],
      SeriesData[$CellContext`s, 
       DirectedInfinity[1], {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`s, 
     DirectedInfinity[1], {2 Pi^Rational[-1, 2]}, 1, 2, 1],
    Editable->False], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5755472187740345`*^9, {3.5865828710006695`*^9, 3.5865828960368853`*^9}, 
   3.587548278589986*^9, {3.5875496081645145`*^9, 3.587549629551081*^9}, 
   3.5875518834205112`*^9, 3.5875543209249763`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"f", "[", "s", "]"}], ",", "1", ",", 
      RowBox[{"1", "+", 
       RowBox[{"\[Gamma]", " ", "s"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", "4.2"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "->", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"HoldForm", "[", 
        RowBox[{"f", "\"\<(\>\"", "s", "\"\<)\>\""}], "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dashed"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.3901416973129997`*^9, {3.444115240331612*^9, 3.444115242298612*^9}, {
   3.444115275115612*^9, 3.4441153524606123`*^9}, {3.444115419646612*^9, 
   3.4441154541856117`*^9}, {3.444115556238612*^9, 3.444115575149612*^9}, {
   3.444115611130612*^9, 3.444115649564612*^9}, {3.444116189406612*^9, 
   3.4441162076926117`*^9}, {3.4755520300063496`*^9, 3.475552043186103*^9}, {
   3.4755522674249287`*^9, 3.475552295896558*^9}, {3.4755523321246295`*^9, 
   3.4755523322396364`*^9}, {3.4755524473522205`*^9, 3.475552447417224*^9}, 
   3.47659318395967*^9, {3.476696781394203*^9, 3.47669678150721*^9}, {
   3.478914504035927*^9, 3.4789145127414246`*^9}, {3.478920485968074*^9, 
   3.478920506151228*^9}, {3.4789205512808094`*^9, 3.478920552092856*^9}, 
   3.478920727277876*^9, {3.4789209912759757`*^9, 3.4789209918440084`*^9}, {
   3.478957942147087*^9, 3.478957942220092*^9}, {3.4789581064044824`*^9, 
   3.4789581067615027`*^9}, {3.4848243687539997`*^9, 3.48482436949*^9}, {
   3.4914508059040003`*^9, 3.491450810606*^9}, {3.5014919878474274`*^9, 
   3.5014920453917184`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVi3s0FGgcQMcYwnh8ZEsTeWUbj+i0Fdn4fW1ISPJWhNZYM95KhBpECcn7
keQZamWXhnVWNgdhNnlTE4ZiSJZBKstg2z/uuef+cVUvBtrSiAQCwe4b//uz
8KFHRsQwY90M8emtLT5oZey+r7XbATjxSS/Ja3xowUU5AgoNvjh51Oxc4UNK
zsUsHiUUHOWsmXof+LDSckL+LSUeopUs9rv38qHCmWU3SMkCNbop5XkRH6JL
/S71UR5Cpf3+qBvH+TDfaS7cS6mDfL38iAM3FoChfyRefPMFtBuxRt/M/AO7
OG5jlo69kHdl0yidMQfeYh0zzelDEN54vO+31VnI4enJDOARiBaKnj7i/wFc
LNkd82YTcEXM1KyTOANvIiKy8feToLZN/HhaLA+sJjddtVZ50FzvtYa3T0Hd
YYLN3bwPcJsnJxve/h6Qe0xfy6U5MH2oKWNPfwceIUxmsNICiI7KvtbTmwBb
98r0EddFSFPqGXsrxYX5xd4qWscSeA479V8oH4HYr/puT3Z9Amnl9LLqWA6k
znLtXRNW4DxRYqzN+jUohAd2Oi5+BvlPlZz2E0OQH2ncL42/wmjx9VOZYQOQ
wzitrlu1CvdrNz7HlvRBSvc9CTJhDWiltZqNYr2woUQ9eiZoHTpnx2yeDHXB
tHjhJJcjAFdZ0g3WFBv+Ztjv1dHehINHiwWHz3XAvj9OVU3kbgGL/W/9i542
gGfGNM0wAtboW2PIlLQA1ff0wYQ9QphewBLp+bUZumUEJZRBIfzqpPr64OUm
WFpgc5OuEXGy/TniFvVP6GvV/+vAYWF8Ujf48r75eljwvnc+clYY/56nuvhA
jgUJJoptZWkkvD7dYFL5pAa4O417hcxFsO99WQNHVjXUajArjJZFMH9Ksb17
8DG0CtUdU84TxYEZbj8kBlVA6kBi6CHrbTjg+omWCZ0yGBlnXqV+3YYn1RRX
/KKK4f07eVWbajHsN/fc+uqbAvDew85wdBHHop6tx4iVeUDVDGkjCklgkQay
d5lUNpRrNua+r5fATclpFZXl6VDspW5Q7EHGrRMLsfldd8ElSzsyQ0ES27iT
Q/IqEsE6kxql/UoS+0pNZRY53ITmVybmJaFSOCIg6cLjiVjgCwgNVjrSWD5F
peboOSbke48uDw1L47jne+YemkZA3IOqOdJ1GTxqFpi8InIF5L2l257uQrhf
rsaxQTkEpuLGzER3I2y4INMQIBcCrNIqtrMiwtQYu4X9IiHg8M6iZ2MPwt7k
lbb2j8GQ7Xrr7cm9CFeQtid51geDgh1haUQXYUmTDFH9M8GgiJeVSCYI15JD
co1vBYEGZTjMPgDhUsPXI27KAVC7LOfSHYhw5C8zhpaiAWD88oyheTDCoVzb
LMt5f3COYgt+vIxwEDFNPL7RH5K5z2LUIxC+bZaQwnH2h5WS0qTleIRnyIYK
m9l+0KYdXJhagDCn5zRpXMUXzpKqoyUKEda1surYLuEL3NGPnnFFCNvQmRsu
nxiwesdrb3jpt9/TLJPSzgCdRadH7o8QXl1SUfP1Y0Amy/ipbh3CJLZSEjyj
g+qdyMzKeoR7CzZFbpbToZrWEKrWgLDECxXDsVQ6dO44aLCjEeFip/SiJhod
BOEaTRvNCBf0h1FNER1un734IKwFYamWWD207gM7tAqZS60Ij3tYZM3xfODA
iMJPvHaEDTTMbQYafaDpqYO6eyfCmjlad8fLfcAiOZ3EYSP8xVKNIEjzgWGv
Hp7ty2/t/10u9ZoP/Gwk2dHVhXBM4qIlzccH/gMzZGPF
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/ZXZZKUtU7kdAxh8sG9YnFN8UWqpPYz/9oQH8wWp
rXB+lrlZK+e/o3C+5M3Yu95hF+D8NI7jzw9MugrnT3+qz3/Z4TacH+l98vhb
twdw/o2qqmkOao/hfJ/H/2K0fjyF87eaMgT0z3wB5wvEN148VPwazk8oqq8v
lH0H5wfFr5h0O+YDwv0fLqxJPf4Rzm/6bh67VvIznD/h5b2QmI4vcL5ERf6J
sA9f4fzZ1XaX+By+I/yT5aust+YHnN93bhYXN8MvOP+vrIalf8FvOP8Z5/zH
927+gfNPZYWo6Gj/g/PVt3uueTDjP5xvv8cuVbOcwQHG18j2NeqQY4Tzz/H/
WSR1BcH/+O7kve5aJjj/4mHzfQamzHD+u7RZ0dUvEfwOF5kjSyaywPn3xO0u
MHqwwvmbVOuX235C8A8zbrWRn8kG50+43FVq4scO59++X1+p8R3Bf/RQRDFg
HQecnyZ3cnJYJCfCP5pFR5gYueD8ZZq7ZzzahuAvTFG2WJjADedHTtWunizB
A+f7TdGo0T6L4B846+KxqJQXzn//h2GHjw4fnD877c6nq9cQ/JZ5a16z1PHD
+SJpfEc2SwrA+apS18pD8hD8I9qF8yfMRfCTbXmOnzmD4AMAH136Vg==
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAA9QM0qT0Cdz4ukwnm///vPyqTG5wq
G1U/eLV9ywv67z/CQKCX/BplP8LX8bAX9O8/jpdileUadT9WHNp7L+jvP/TC
QxTaGoU/fqWqEV/Q7z+nWLRT1BqVP8+3Sz2+oO8/gKNsc9EapT9v3I2UfEHv
P+3ISAPQGrU/sCUSQ/mC7j9qNzaFCf7FP06jzt3l5ew/Gdld3UtW0D+66PAr
MmTrP2YIx+fAktU/uAGTWw/q6T+X5S8P00DbP9IF6cjfT+g/WUvJx+1G4D+6
0aTpD9HmP9h6epZAJuM/vogUSDMy5T9M4/5cKvjlP1QTBIjnmuM/tTUAUI+Z
6D+4ZVl7+x7iPxBfgdHCc+s/OKNirAKD4D9gcn9/cR3uPwpRoyHTBN4/Ul+o
kttc8D/MAoGtwhLbP+3w0Kxlx/E/xIrGtJjg1z+C9zddrRnzP1qi1yIu5dQ/
kOneVFyI9D8mkFAMqqnRPxh4b8hW8PU/MEqScY/6zD+bez7SDkD3P0iTGphJ
D8c/l2pNIy6s+D/QiHK10KPAP47OmgoLAPo/IDvDQK1LtT/9HSg5T3D7PwB7
gQimnqA/a++0kfhb/D8AAAAAAAAAAGLO4Kc=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["s", TraditionalForm], 
    FormBox[
     TagBox[
      RowBox[{"f", " ", "\"(\"", " ", "s", " ", "\")\""}], HoldForm], 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 4.2}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.5755472189110518`*^9, {3.586582871121711*^9, 3.5865828960888057`*^9}, 
   3.587548278754003*^9, {3.5875496083335333`*^9, 3.587549629736102*^9}, 
   3.5875518834665165`*^9, 3.587554320974984*^9}]
}, Open  ]],

Cell["99% position", "Text",
 CellChangeTimes->{{3.5875517362768583`*^9, 3.5875517425166063`*^9}, {
  3.5875517765166855`*^9, 3.58755178480468*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s99", "=", 
  RowBox[{"s", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "s", "]"}], "\[Equal]", "0.01"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "4"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4790035968838744`*^9, 3.479003625146491*^9}, {
  3.491450856828*^9, 3.491450857434*^9}}],

Cell[BoxData["3.6427727354368993`"], "Output",
 CellChangeTimes->{
  3.575547218948058*^9, {3.586582871141672*^9, 3.5865828961128397`*^9}, 
   3.5875482787950077`*^9, {3.5875496083625393`*^9, 3.5875496297721076`*^9}, 
   3.5875518835125227`*^9, 3.5875543210189877`*^9}]
}, Open  ]],

Cell["Front position", "Text",
 CellChangeTimes->{{3.5875517919405355`*^9, 3.5875517942118073`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfront", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.4790042616118946`*^9, 3.4790042635460052`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot2", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"{", 
    RowBox[{"Dotted", ",", "Black", ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s99", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"s99", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(s\), \(99\)]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"s99", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.5"}], ",", "0"}], "}"}]}], "]"}], ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"sfront", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"sfront", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<\!\(\*SubscriptBox[\(s\), \(front\)]\)\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"sfront", ",", "0.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.5"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478920652562602*^9, 3.478920710268903*^9}, {
   3.4789207429347715`*^9, 3.478920878848545*^9}, 3.4789209105183563`*^9, {
   3.478921023958845*^9, 3.478921047485191*^9}, {3.4789211029043603`*^9, 
   3.4789211085116816`*^9}, {3.478921151256126*^9, 3.4789211875362015`*^9}, {
   3.4789212249583416`*^9, 3.4789212649046264`*^9}, {3.4789579948491015`*^9, 
   3.4789580397196684`*^9}, {3.479003629556743*^9, 3.4790036537751284`*^9}, {
   3.479003685990971*^9, 3.479003699742758*^9}, {3.4790037399920597`*^9, 
   3.479003748931571*^9}, {3.4790037931451*^9, 3.479003793576124*^9}, {
   3.479004131511453*^9, 3.4790041321664906`*^9}, {3.4790041818713336`*^9, 
   3.4790042108899937`*^9}, {3.4790042495082026`*^9, 3.479004357992407*^9}, {
   3.4793524973428*^9, 3.4793525016208*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], Dashing[{0, Small}], 
   LineBox[{{3.6427727354368993`, 0}, {3.6427727354368993`, 1}}], 
   InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(s\\), \\(99\\)]\\)\"\>", \
{3.6427727354368993`, 0.5}, {-1.5, 0}], LineBox[{{2, 0}, {2, 1}}], 
   InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(s\\), \\(front\\)]\\)\"\>", \
{2, 0.5}, {-1.5, 0}]}]], "Output",
 CellChangeTimes->{
  3.575547219008065*^9, {3.58658287118371*^9, 3.586582896135812*^9}, 
   3.5875482788520164`*^9, {3.5875496084065423`*^9, 3.5875496298251143`*^9}, 
   3.58755188355853*^9, 3.587554321067994*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"plot1", ",", "plot2", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], "//", "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<viscosity-stokeslayer\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478920714969172*^9, 3.478920728780962*^9}, {
   3.478920886022956*^9, 3.4789208897831707`*^9}, {3.4789209306395073`*^9, 
   3.4789209566909976`*^9}, {3.478921002809635*^9, 3.4789210028766394`*^9}, {
   3.4789210755107937`*^9, 3.47892108750848*^9}, {3.4789211219084473`*^9, 
   3.478921128303813*^9}, 3.4789211607536693`*^9, {3.4789580608478765`*^9, 
   3.4789580609878845`*^9}, {3.479003766764591*^9, 3.4790038308852587`*^9}, {
   3.479003902910378*^9, 3.4790039035844164`*^9}, {3.479003945938839*^9, 
   3.47900401432075*^9}, 3.479004203418566*^9, {3.479265345583*^9, 
   3.479265375237*^9}, {3.484824325616*^9, 3.484824343679*^9}, {
   3.484824390047*^9, 3.484824404682*^9}, {3.491450886301*^9, 
   3.491450887051*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.575547219220089*^9, {3.5865828713497405`*^9, 3.58658289627483*^9}, 
   3.5875482790750437`*^9, {3.5875496086015673`*^9, 3.5875496300281386`*^9}, 
   3.5875518837735558`*^9, 3.58755432127802*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwVi3s0FGgcQMcYwnh8ZEsTeWUbj+i0Fdn4fW1ISPJWhNZYM95KhBpECcn7
keQZamWXhnVWNgdhNnlTE4ZiSJZBKstg2z/uuef+cVUvBtrSiAQCwe4b//uz
8KFHRsQwY90M8emtLT5oZey+r7XbATjxSS/Ja3xowUU5AgoNvjh51Oxc4UNK
zsUsHiUUHOWsmXof+LDSckL+LSUeopUs9rv38qHCmWU3SMkCNbop5XkRH6JL
/S71UR5Cpf3+qBvH+TDfaS7cS6mDfL38iAM3FoChfyRefPMFtBuxRt/M/AO7
OG5jlo69kHdl0yidMQfeYh0zzelDEN54vO+31VnI4enJDOARiBaKnj7i/wFc
LNkd82YTcEXM1KyTOANvIiKy8feToLZN/HhaLA+sJjddtVZ50FzvtYa3T0Hd
YYLN3bwPcJsnJxve/h6Qe0xfy6U5MH2oKWNPfwceIUxmsNICiI7KvtbTmwBb
98r0EddFSFPqGXsrxYX5xd4qWscSeA479V8oH4HYr/puT3Z9Amnl9LLqWA6k
znLtXRNW4DxRYqzN+jUohAd2Oi5+BvlPlZz2E0OQH2ncL42/wmjx9VOZYQOQ
wzitrlu1CvdrNz7HlvRBSvc9CTJhDWiltZqNYr2woUQ9eiZoHTpnx2yeDHXB
tHjhJJcjAFdZ0g3WFBv+Ztjv1dHehINHiwWHz3XAvj9OVU3kbgGL/W/9i542
gGfGNM0wAtboW2PIlLQA1ff0wYQ9QphewBLp+bUZumUEJZRBIfzqpPr64OUm
WFpgc5OuEXGy/TniFvVP6GvV/+vAYWF8Ujf48r75eljwvnc+clYY/56nuvhA
jgUJJoptZWkkvD7dYFL5pAa4O417hcxFsO99WQNHVjXUajArjJZFMH9Ksb17
8DG0CtUdU84TxYEZbj8kBlVA6kBi6CHrbTjg+omWCZ0yGBlnXqV+3YYn1RRX
/KKK4f07eVWbajHsN/fc+uqbAvDew85wdBHHop6tx4iVeUDVDGkjCklgkQay
d5lUNpRrNua+r5fATclpFZXl6VDspW5Q7EHGrRMLsfldd8ElSzsyQ0ES27iT
Q/IqEsE6kxql/UoS+0pNZRY53ITmVybmJaFSOCIg6cLjiVjgCwgNVjrSWD5F
peboOSbke48uDw1L47jne+YemkZA3IOqOdJ1GTxqFpi8InIF5L2l257uQrhf
rsaxQTkEpuLGzER3I2y4INMQIBcCrNIqtrMiwtQYu4X9IiHg8M6iZ2MPwt7k
lbb2j8GQ7Xrr7cm9CFeQtid51geDgh1haUQXYUmTDFH9M8GgiJeVSCYI15JD
co1vBYEGZTjMPgDhUsPXI27KAVC7LOfSHYhw5C8zhpaiAWD88oyheTDCoVzb
LMt5f3COYgt+vIxwEDFNPL7RH5K5z2LUIxC+bZaQwnH2h5WS0qTleIRnyIYK
m9l+0KYdXJhagDCn5zRpXMUXzpKqoyUKEda1surYLuEL3NGPnnFFCNvQmRsu
nxiwesdrb3jpt9/TLJPSzgCdRadH7o8QXl1SUfP1Y0Amy/ipbh3CJLZSEjyj
g+qdyMzKeoR7CzZFbpbToZrWEKrWgLDECxXDsVQ6dO44aLCjEeFip/SiJhod
BOEaTRvNCBf0h1FNER1un734IKwFYamWWD207gM7tAqZS60Ij3tYZM3xfODA
iMJPvHaEDTTMbQYafaDpqYO6eyfCmjlad8fLfcAiOZ3EYSP8xVKNIEjzgWGv
Hp7ty2/t/10u9ZoP/Gwk2dHVhXBM4qIlzccH/gMzZGPF
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/ZXZZKUtU7kdAxh8sG9YnFN8UWqpPYz/9oQH8wWp
rXB+lrlZK+e/o3C+5M3Yu95hF+D8NI7jzw9MugrnT3+qz3/Z4TacH+l98vhb
twdw/o2qqmkOao/hfJ/H/2K0fjyF87eaMgT0z3wB5wvEN148VPwazk8oqq8v
lH0H5wfFr5h0O+YDwv0fLqxJPf4Rzm/6bh67VvIznD/h5b2QmI4vcL5ERf6J
sA9f4fzZ1XaX+By+I/yT5aust+YHnN93bhYXN8MvOP+vrIalf8FvOP8Z5/zH
927+gfNPZYWo6Gj/g/PVt3uueTDjP5xvv8cuVbOcwQHG18j2NeqQY4Tzz/H/
WSR1BcH/+O7kve5aJjj/4mHzfQamzHD+u7RZ0dUvEfwOF5kjSyaywPn3xO0u
MHqwwvmbVOuX235C8A8zbrWRn8kG50+43FVq4scO59++X1+p8R3Bf/RQRDFg
HQecnyZ3cnJYJCfCP5pFR5gYueD8ZZq7ZzzahuAvTFG2WJjADedHTtWunizB
A+f7TdGo0T6L4B846+KxqJQXzn//h2GHjw4fnD877c6nq9cQ/JZ5a16z1PHD
+SJpfEc2SwrA+apS18pD8hD8I9qF8yfMRfCTbXmOnzmD4AMAH136Vg==
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAA9QM0qT0Cdz4ukwnm///vPyqTG5wq
G1U/eLV9ywv67z/CQKCX/BplP8LX8bAX9O8/jpdileUadT9WHNp7L+jvP/TC
QxTaGoU/fqWqEV/Q7z+nWLRT1BqVP8+3Sz2+oO8/gKNsc9EapT9v3I2UfEHv
P+3ISAPQGrU/sCUSQ/mC7j9qNzaFCf7FP06jzt3l5ew/Gdld3UtW0D+66PAr
MmTrP2YIx+fAktU/uAGTWw/q6T+X5S8P00DbP9IF6cjfT+g/WUvJx+1G4D+6
0aTpD9HmP9h6epZAJuM/vogUSDMy5T9M4/5cKvjlP1QTBIjnmuM/tTUAUI+Z
6D+4ZVl7+x7iPxBfgdHCc+s/OKNirAKD4D9gcn9/cR3uPwpRoyHTBN4/Ul+o
kttc8D/MAoGtwhLbP+3w0Kxlx/E/xIrGtJjg1z+C9zddrRnzP1qi1yIu5dQ/
kOneVFyI9D8mkFAMqqnRPxh4b8hW8PU/MEqScY/6zD+bez7SDkD3P0iTGphJ
D8c/l2pNIy6s+D/QiHK10KPAP47OmgoLAPo/IDvDQK1LtT/9HSg5T3D7PwB7
gQimnqA/a++0kfhb/D8AAAAAAAAAAGLO4Kc=
      "]]}}, 
   {GrayLevel[0], Dashing[{0, Small}], 
    LineBox[{{3.6427727354368993`, 0}, {3.6427727354368993`, 1}}], 
    InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(s\\), \\(99\\)]\\)\"\>", \
{3.6427727354368993`, 0.5}, {-1.5, 0}], LineBox[{{2, 0}, {2, 1}}], 
    InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(s\\), \\(front\\)]\\)\"\>", \
{2, 0.5}, {-1.5, 0}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["s", TraditionalForm], 
    FormBox[
     TagBox[
      RowBox[{"f", " ", "\"(\"", " ", "s", " ", "\")\""}], HoldForm], 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{0, 1},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.575547219249091*^9, {3.5865828713517246`*^9, 3.586582896290874*^9}, 
   3.5875482790800433`*^9, {3.5875496086135693`*^9, 3.5875496300391383`*^9}, 
   3.587551883779554*^9, 3.5875543212840223`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 15.4 Classification of flows (p. 253)\
\>", "Title",
 CellChangeTimes->{{3.502100358928069*^9, 3.5021003659274693`*^9}, {
  3.58755190348092*^9, 3.587551908548527*^9}}],

Cell[CellGroupData[{

Cell["\<\
Example 15.4 Water pipe (p. 253)\
\>", "Section",
 CellChangeTimes->{{3.5021003778011484`*^9, 3.502100380399297*^9}, {
  3.502100425112855*^9, 3.502100431464218*^9}, {3.5875519197668753`*^9, 
  3.587551923652339*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(17\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575547289532525*^9, 3.5755474207712746`*^9, {3.586582871773805*^9, 
   3.586582896500907*^9}, 3.5875482793640766`*^9, 3.587552282697421*^9, 
   3.587554321553054*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters ", "Subsection",
 CellChangeTimes->{3.5875521044870367`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"1.", "\[Times]", 
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]]}], ",", 
      RowBox[{"7.4", "\[Times]", 
       SuperscriptBox["10", 
        RowBox[{"-", "5"}]]}]}], "}"}], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "viscosities", " ", "of", " ", "water", " ", "and", " ", "olive", " ", 
    "oil"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"d", "=", 
   RowBox[{"1.25", " ", "Centimeter"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"A", "=", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox["d", "2"]}], "4"]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Q", "=", 
   RowBox[{"100", 
    RowBox[{
     SuperscriptBox["Centimeter", "3"], "/", "Second"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.587552142476596*^9, 3.587552195062904*^9}, {
  3.587552274271409*^9, 3.5875522787969522`*^9}}],

Cell["Average velocity", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", "=", 
  RowBox[{
   RowBox[{
    FractionBox["Q", "A"], "//", "ToSI"}], "//", "N"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"0.8148733086305042`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            "\"s\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters per second"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.57554728998158*^9, 3.575547421195324*^9, {3.586582872212845*^9, 
   3.5865828966539316`*^9}, 3.5875482797581244`*^9, 3.5875522000175*^9, 
   3.587552283055462*^9, 3.5875543219340982`*^9}]
}, Open  ]],

Cell["Reynolds number", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reynolds", " ", "=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"U", " ", "d"}], "\[Nu]"], "//", "ToSI"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10185.916357881304`", ",", "137.64751834974734`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5755472901776037`*^9, 3.575547421396347*^9, {3.5865828723158617`*^9, 
   3.586582896753931*^9}, 3.5875482799811506`*^9, 3.5875522003755407`*^9, 
   3.587552283416507*^9, 3.5875543223421483`*^9}]
}, Open  ]],

Cell["Olive oil", "Text",
 CellChangeTimes->{{3.502100470016423*^9, 3.5021004718875303`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{"6.7", "  ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", "=", 
  RowBox[{
   RowBox[{
    FractionBox["Q", "A"], "//", "ToSI"}], "//", "N"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"0.8148733086305042`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            "\"s\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters per second"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575547290381628*^9, 3.5755474216053734`*^9, {3.5865828725028515`*^9, 
   3.586582896857901*^9}, 3.587548280195178*^9, 3.5875522005825663`*^9, 
   3.587552283619532*^9, 3.5875543227781987`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reynolds", " ", "=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"U", " ", "d"}], "\[Nu]"], "//", "ToSI"}]}]], "Input"],

Cell[BoxData["0.15202860235643736`"], "Output",
 CellChangeTimes->{
  3.5755472905766497`*^9, 3.5755474218323984`*^9, {3.5865828729899426`*^9, 
   3.586582896956914*^9}, 3.587548280413204*^9, 3.5875522007765894`*^9, 
   3.587552283813555*^9, 3.5875543233652697`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Table 15.2 Reynolds numbers (p. 254)\
\>", "Section",
 CellChangeTimes->{{3.4215059348059998`*^9, 3.421505940101*^9}, {
  3.502101370663937*^9, 3.5021013742801437`*^9}, {3.587552672133147*^9, 
  3.5875526751405077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5021020950803714`*^9, 3.502102097937535*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(6\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755472909967017`*^9, 3.5755474222694516`*^9, {3.586582873236943*^9, 
   3.5865828971219893`*^9}, 3.5875482807022386`*^9, 3.5875522841375923`*^9, 
   3.5875543236273026`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5875526805171537`*^9, 3.5875526919725266`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"system", "=", 
   RowBox[{"{", 
    RowBox[{
    "ship", ",", "submarine", ",", "jetplane", ",", "bluewhale", ",", "car", 
     ",", "swimminghuman", ",", "jogginghuman", ",", "herring", ",", 
     "golfball", ",", "pingpongball", ",", "fly", ",", "flea", ",", "gnat", 
     ",", "bacterium"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fluid", "=", 
   RowBox[{"{", 
    RowBox[{
    "water", ",", "water", ",", "air", ",", "water", ",", "air", ",", "water",
      ",", "air", ",", "water", ",", "air", ",", "air", ",", "air", ",", 
     "air", ",", "air", ",", "water"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"size", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "345", ",", "170", ",", "71", ",", "33", ",", "5", ",", "2", ",", "1", 
      ",", "0.3", ",", "0.043", ",", "0.040", ",", "0.01", ",", "0.001", ",", 
      "0.001", ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}], "}"}], "//", "N"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"velocity", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "15", ",", "12", ",", "250", ",", "10", ",", "30", ",", "1", ",", "3", 
      ",", "1", ",", "40", ",", "10", ",", "1", ",", "3", ",", "0.1", ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]]}], "}"}], "//", "N"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"w", "=", 
   RowBox[{
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"1.54", "\[Times]", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"viscosity", "=", 
   RowBox[{"{", 
    RowBox[{
    "w", ",", "w", ",", "a", ",", "w", ",", "a", ",", "w", ",", "a", ",", "w",
      ",", "a", ",", "a", ",", "a", ",", "a", ",", "a", ",", "w"}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.502101419936755*^9, 3.5021014589389863`*^9}, {
  3.5021015518282995`*^9, 3.5021015886204033`*^9}, {3.5021016458196754`*^9, 
  3.502101797077327*^9}, {3.502101880801115*^9, 3.5021018826052184`*^9}, {
  3.5021019610947075`*^9, 3.5021019737164297`*^9}, {3.502102131819473*^9, 
  3.5021021343076153`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reynolds", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"velocity", "\[Times]", "size"}], "viscosity"], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.502101592351617*^9, 3.502101637772215*^9}, {
  3.5021018084049745`*^9, 3.502101809092014*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5.175`*^9", ",", "2.04`*^9", ",", "1.1525974025974023`*^9", ",", "3.3`*^8",
    ",", "9.740259740259739`*^6", ",", "2.`*^6", ",", "194805.19480519477`", 
   ",", "300000.`", ",", "111688.31168831166`", ",", "25974.02597402597`", 
   ",", "649.3506493506493`", ",", "194.8051948051948`", ",", 
   "6.493506493506493`", ",", "0.00001`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755472910597076`*^9, 3.5755474223154573`*^9, {3.5865828733489895`*^9, 
   3.586582897145979*^9}, 3.58754828081225*^9, 3.5875522841926003`*^9, 
   3.5875543236803074`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "system", ",", "fluid", ",", "size", ",", "velocity", ",", "viscosity", 
     ",", "Reynolds"}], "}"}], "//", "Transpose"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.502101818343543*^9, 3.5021018464171486`*^9}, {
  3.5021019049684973`*^9, 3.502101944554762*^9}, {3.502102119282756*^9, 
  3.502102120721838*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"ship", "water", "345.`", "15.`", "1.`*^-6", "5.175`*^9"},
    {"submarine", "water", "170.`", "12.`", "1.`*^-6", "2.04`*^9"},
    {"jetplane", "air", "71.`", "250.`", "0.0000154`", 
     "1.1525974025974023`*^9"},
    {"bluewhale", "water", "33.`", "10.`", "1.`*^-6", "3.3`*^8"},
    {"car", "air", "5.`", "30.`", "0.0000154`", "9.740259740259739`*^6"},
    {"swimminghuman", "water", "2.`", "1.`", "1.`*^-6", "2.`*^6"},
    {"jogginghuman", "air", "1.`", "3.`", "0.0000154`", "194805.19480519477`"},
    {"herring", "water", "0.3`", "1.`", "1.`*^-6", "300000.`"},
    {"golfball", "air", "0.043`", "40.`", "0.0000154`", "111688.31168831166`"},
    {"pingpongball", "air", "0.04`", "10.`", "0.0000154`", 
     "25974.02597402597`"},
    {"fly", "air", "0.01`", "1.`", "0.0000154`", "649.3506493506493`"},
    {"flea", "air", "0.001`", "3.`", "0.0000154`", "194.8051948051948`"},
    {"gnat", "air", "0.001`", "0.1`", "0.0000154`", "6.493506493506493`"},
    {"bacterium", "water", "1.`*^-6", "0.00001`", "1.`*^-6", "0.00001`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5755472911067147`*^9, 3.575547422354463*^9, {3.586582873372957*^9, 
   3.586582897163987*^9}, 3.587548280855257*^9, 3.5875522842426043`*^9, 
   3.587554323715314*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 15.5 Flight of the robofly (p. 255)\
\>", "Section",
 CellChangeTimes->{{3.502101135305475*^9, 3.502101137567605*^9}, {
  3.5875528989153557`*^9, 3.5875529157163734`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(24\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575547291388749*^9, {3.575547349424711*^9, 3.575547362496282*^9}, 
   3.5755474226284943`*^9, {3.5865828735700197`*^9, 3.586582897327961*^9}, 
   3.5875482811432915`*^9, 3.587553157698409*^9, {3.587553303184863*^9, 
   3.5875533165934725`*^9}, 3.5875543239743433`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters for Fly and Robofly", "Subsection",
 CellChangeTimes->{
  3.587553002902836*^9, {3.5875533465700717`*^9, 3.5875533523727655`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1.54", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "5"}]]}], ",", 
      RowBox[{"1.15", "\[Times]", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}], "}"}], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"viscosity", " ", "of", " ", "air", " ", "and", " ", "oil"}], " ", 
   "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", "Millimeter"}], ",", 
     RowBox[{"19", " ", "Centimeter"}]}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"wing", " ", "lengths"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"50", " ", "Hertz"}], ",", " ", 
     RowBox[{"166", " ", "Millihertz"}]}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"flapping", " ", "frequencies"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.575547355968497*^9, 3.575547357711705*^9}, {
  3.5875529252745194`*^9, 3.587552929274*^9}, {3.58755297887095*^9, 
  3.587553119163785*^9}, {3.587553272766215*^9, 3.587553311079811*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.587553167414576*^9, 3.5875531682926784`*^9}}],

Cell["Average velocity estimate", "Text",
 CellChangeTimes->{3.587553185684764*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Pi]", " ", "L", " ", "f"}], "//", "ToSI"}], "//", 
   "N"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"0.6283185307179586`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"0.09908583229422208`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            
            RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", 
              "\[InvisibleSpace]", "\"s\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: meters per second"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5755472915587687`*^9, {3.575547349711745*^9, 3.5755473627753134`*^9}, 
   3.575547422802517*^9, {3.586582873692009*^9, 3.586582897452976*^9}, 
   3.587548281919385*^9, 3.5875531580174465`*^9, {3.587553303497903*^9, 
   3.5875533169025106`*^9}, 3.5875543243183837`*^9}]
}, Open  ]],

Cell["Reynolds number", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reynolds", " ", "=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"U", " ", "L"}], "\[Nu]"], "//", "ToSI"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"163.19961836830095`", ",", "163.70702726871474`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5755472917517905`*^9, {3.575547349899768*^9, 3.575547362978339*^9}, 
   3.575547423001539*^9, {3.5865828738040466`*^9, 3.586582897550032*^9}, 
   3.587548282122408*^9, 3.587553158366487*^9, {3.587553303855945*^9, 
   3.5875533172625537`*^9}, 3.587554324836447*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 15.6 Application: Viscous attenuation of sound (p. 257)\
\>", "Title",
 CellChangeTimes->{{3.502102723009287*^9, 3.5021027341359234`*^9}, {
  3.5875534481202545`*^9, 3.5875534572853546`*^9}}],

Cell[CellGroupData[{

Cell["Viscous amplitude attenuation coefficient", "Section",
 CellChangeTimes->{{3.5021027962804775`*^9, 3.50210280471996*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(5\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755474407896748`*^9, {3.5865828746771593`*^9, 3.5865828979570394`*^9}, 
   3.5875482829005027`*^9, 3.5875543253365088`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theory", "Subsection",
 CellChangeTimes->{{3.5875534736373167`*^9, 3.5875534766766815`*^9}}],

Cell["Density variation", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]p", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[Kappa]"}], " ", "x"}]], 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"k", " ", "x"}], "-", 
      RowBox[{"\[Omega]", " ", "t"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.429691615615979*^9, 3.4296916200149794`*^9}, {
  3.489207369624*^9, 3.489207370013*^9}}],

Cell["Equation of motion", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"zero", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[PartialD]", "t"], "2"], "\[CapitalDelta]p"}], "-", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["c", "0"], "2"], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[PartialD]", "x"], "2"], "\[CapitalDelta]p"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      SubscriptBox["\[Omega]", "0"]], " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[PartialD]", "x"], "2"], 
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], "\[CapitalDelta]p"}]}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4296916568179793`*^9, 3.4296917306079793`*^9}}],

Cell["Simplify result", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zero1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"zero", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Kappa]", " ", "x"}]]}], "//", "Expand"}], "//", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"k", " ", "x"}], "-", 
          RowBox[{"t", " ", "\[Omega]"}]}], "]"}], ",", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"k", " ", "x"}], "-", 
          RowBox[{"t", " ", "\[Omega]"}]}], "]"}]}], "}"}]}], "]"}], 
    "&"}]}]}]], "Input",
 CellChangeTimes->{3.4296915752499795`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "-", 
     RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SubsuperscriptBox["c", "0", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["\[Kappa]", "2"], " ", 
      SubsuperscriptBox["c", "0", "2"]}], "+", 
     FractionBox[
      RowBox[{"2", " ", "k", " ", "\[Kappa]", " ", "\[Omega]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "-", 
     RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "k", " ", "\[Kappa]", " ", 
      SubsuperscriptBox["c", "0", "2"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["k", "2"], " ", "\[Omega]"}], 
      SubscriptBox["\[Omega]", "0"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], " ", "\[Omega]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.575547441003702*^9, {3.5865828752122245`*^9, 3.5865828979850836`*^9}, 
   3.587548283029519*^9, 3.5875543258075643`*^9}]
}, Open  ]],

Cell["Kill second order terms", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zero1", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Kappa]", "2"], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Kappa]", " ", "\[Omega]"}], "\[Rule]", "0"}]}], "}"}]}], "//",
    "Expand"}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"k", " ", "x"}], "-", 
         RowBox[{"t", " ", "\[Omega]"}]}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"k", " ", "x"}], "-", 
         RowBox[{"t", " ", "\[Omega]"}]}], "]"}]}], "}"}]}], "]"}], 
   "&"}]}]], "Input",
 CellChangeTimes->{{3.4296929260149794`*^9, 3.4296929591549797`*^9}, {
  3.4296930488179793`*^9, 3.4296930692649794`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "-", 
     RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SubsuperscriptBox["c", "0", "2"]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"k", " ", "x"}], "-", 
     RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "k", " ", "\[Kappa]", " ", 
      SubsuperscriptBox["c", "0", "2"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["k", "2"], " ", "\[Omega]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5755474410497055`*^9, {3.586582876078294*^9, 3.5865828980030875`*^9}, 
   3.5875482830795245`*^9, 3.587554325848568*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Margin figure (p. 258)", "Section",
 CellChangeTimes->{{3.5021036558166404`*^9, 3.502103674660718*^9}, {
  3.587553900701556*^9, 3.5875539031728535`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(9\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.5755474413277407`*^9, {3.5865828763723307`*^9, 3.586582898172098*^9}, 
   3.587548283349557*^9, 3.5875543261126003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{"-", "y"}], "]"}], 
     RowBox[{"Cos", "[", " ", 
      RowBox[{"2", " ", "Pi", " ", "y"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "3"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1.15"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "->", 
     RowBox[{"{", 
      RowBox[{"x", ",", "\[CapitalDelta]\[Rho]"}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<compressible-dampedwave\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.390121671772355*^9, {3.429694789108979*^9, 3.429694805313979*^9}, 
   3.4309108229175997`*^9, {3.479268218025*^9, 3.479268218648*^9}, {
   3.489207415826*^9, 3.489207546546*^9}, {3.4892076512980003`*^9, 
   3.4892076522349997`*^9}, {3.501492339128519*^9, 3.501492370527315*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.5755474415667677`*^9, {3.58658287710949*^9, 3.586582898319085*^9}, 
   3.587548283598587*^9, 3.5875543263476305`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVV3k8VO8blcHQRlmKSlLJN0VJQniuUkqFSkRlTQmhoiTZkmQtRUK2bGPf
FfIaS7axL0N2g+xjH7LM7/7+ms/53Ps+zznnOfeZew+Y2NwwY2VhYbEnsLD8
/3f5ivU3LRtbZcW7B/qYTDp43j8i3iCmAYZT2yS0l+lQNz1k4SdmAIP+a7r3
Z+gwk33e10rMGpIPde392UcHd4H5vXfFnMGt8f2IfCEdmrNuVgcuukICY7Dm
aSYd7v857sGgusMOX7HjjxLw+v8NrpSEe8J8+6nzAYF0qK1UH74p5g8DnOl5
v83okPZip9Zdtg8Q0yjvNatHhxc+Lqn+ix/AXDDiU9c1OnBm65nPUwNB2apZ
eVqGDkdZt/cWhQcD8Wq4Fh8LHWyinldrikXA/I/nR0K8p0EuhybmvisS7Gsv
fGp2nAaW++Ln9NmiwDH7CGejxTRUvwiK9F2MAilDAg+/+jToR9roz1JjYITn
RFk9+zQ4TR9sLAiPhybzWKOzT6fAyOHPxk3+BCj8bPq+wmAKVFk/Hp/yS4BG
2sKCwJUp2Caw4b3fJRFsZowyeA5OQYRSxwUP4yQw6zQOeNg4CWRf38JrYmmg
Eq9XNygyCcXjnZQtpDSIdIs9xcc5CUWXjvRWS6TD57gpXU76BNxhNWb5vjsD
riQLGikUTcCt4lXR/cKZUP7xuGTjzQlQlz1pvuu/bHhrVSUg5DAOp8TC54iQ
D0HDoX2LX0ZBuu3c6gPXfDDyc4HzDqNwwmOM8JucD5cSsi8Y3R4FyUFZfg/V
H3DnpOby5t2jIB7RdIZF/SfYeD2ZlAz6C3sFiK+XtQvBwM85ZMe7EWDneEoc
s0Aw8zdt142rQzB62YV7PgHB28a6zN7/hqDGz3fX+hCCaXFh/WvEIaj0bvnk
JVUCezuNrjaTaeCzc/p7OKkE2KPz1z1O04BP9GB5+Tcy/Kk34OjfNQhiKn5s
/J5lIFNZc4cjuA8uuxi/zdWphOUW+hVHZhvkvzTriWuqBy3lII3A6wkQr2xJ
FZqrB1l1eX0+SiwEE540BexsgKu34/QT1GLguZ9TxcubDSBdwPf0hEcoyEZ/
Sr3W1gCLB0PbjMQc4c5Qf7GjVSNUX3+xxeRlFPqzhTtA1LYJPj0M5j1mXYhu
TO/Yes+1CTYqtpVdDC1CNY187798aIJzQtmcLhW/UEGQ0JutmU2QXeC+EbG1
BIXuF3uxNNsENq7sc+36pUj/lJJhzbNmuOpVp7uz/zfq1LeUevqiBa44TwTr
vm1A3oNqVl88WyBx0a5pnaURKVgcIhUFtQB9PFVkOzSi8Jc9osScFviLvg8/
LGhERiGaAuEzLfD4cZ7KQmoT+tt2ar3iUSucKHwZxefVgha11moE77aBasCP
h2R2Korv6CCCZRtsZxHYtPssFekY5ared2wDzfq/5SK2VPTDxro4LaQNbqu+
c1HrpCIn//7M821t8KrbvrM/oQMRKOUhjzXawfrii4yN03/QDjW/B2SMCv8x
iyxmeHuQKqkIJK5TIdhQiSfwXA9y2DK5O8iYCmKyeht1tj2ov0G91tydCuNn
T4XyUnpQxm3OEzzlVGjfZn23/nUv0rJ4s2Kg1gErgsr3aur6kAclq7lKtwP8
H4ktzy72oR+Sg8nS5h0Q0i7LpG7vRyLzmAHH+w4wjJ8Dxul+NPNqozS1pgOW
fdI28t360Qe/l75r1zohpXOSTYp7AJXTE80eGHRCQbaT2cT+AbR8vUO50boT
WIUm4p+cGEBGAmdmvwd0Atl1n2+X1gA6Eblw60pTJ/CzKsPBgAF0f9MhqdyB
TvB6+G/T8YgBFGJ6k3P/XCfUDLySYUkdQCziWQVzO/+A1oZ7IWvNAGrMsNkf
qv0HuLeGnH6xaRCx8UYuE8z+QCdJQ6d2+yCSs69vemz/B84quoeN7hlEUfLH
PVSC/0A+6ndwPj2IbEvHR0epf+AKxIwIPBhEPK1mWWfudIHWmmkao2gQYVMq
49qWXfCRl8857Td+P4ew6NNXXdAkpXfpROMgapJr/5gS1gUzbffaPw8OosBv
F58c6O6C6z6d8oNsNFSaJ0pSnuwCza1ExdmtNDTfsNF/Z60L2MZ69Wr5aEib
NV8reG83aLxfYx04SEP8D4+c2HKvG2LiWvoDgYYuuhLMxR93Q+j3oMDVCzT0
/Gtf5IXX3WDUcTZG6ioNtdd+4Xb91g2TYQSOf7o0xDH8TO1bajd4jTfYfrhH
Q2c2NF0KfnXDo1NtD+ZMaCjkBCd9oacbtMUeHhF8TENVl4fEdk53A1dW9Nbe
JzS0bFJiILXRDXqytlnWz2lIL8ih/pFwDzzkDnOcd6Yh7zRtjneSPUDZFV74
152GCipPKMcq98D7rJf/EjxpSOjfaGqvQQ98CnfI8fWjIXXeiuFV6x64ECJ+
I/MDDTkei94n6NIDB0lN0jGfaCjpwutbsgE9gOgz5obBNNRloOd3M7IHCNnO
xLEQGtrqcLrCNr0HYmanDkAYDSl+3LHuh3rAYU6CYvyNhqySpmSSG3pgqSVS
6HokDYWXVVtV9fXAW6GjotuiaYjSHRc7TO+BaaVDy0ExNLS26NbNytILtaeN
sia+09AxbgM+EZ5emGUTf7g9jobuiStcVRLphanzSsc3cOyvIuChf6IX3iR1
7CmMp6Fi/bnCF1gvKISQ1C8k0ND0s/r5z1q9MBPW1hSOY2G/JIkso17w+Meo
JuNYI97TtMG2F9xkDlzNwbEzMgmbdMXre7c/scNxWodyC9fHXtj1ZsctVhz3
zQptORLdC16PgMcA78ezhXFONbMXOFqx4nc4H+xQi6MxuRcSRR85usTSkK1S
epZzUy++b5yNLuB6onR8xsMGeiGjP8+3E9ffaPNQ9OdsL6i6Fe1RjKKhTe/P
67dv6gPN+4lHH0fQkHTM/sD5HX1Qr8FGtQqnIZPC1Woe0T5gLa9WPhtKQ4Gt
1E2S0n1g4Grs2vEFz/NUtvyVc30QPx9ToBpEQwdFrEhvTfrgIH9CsHcADfn2
Hoj2e9IHu+YSJMJ9aWgpnBoS5NoHx1iHPd68x/MmeN4rLqIPwh9fo7fg+TnZ
seySmor/77T3yyq50FBocNqL3KI+2F/pku70Cp8vr9DDij998FJQLNb5GQ21
NTUY1I3h9X/s0lOxoSHlD2912pb74HrAaMYfCxry8lyOebqlH05QjYo/GtPQ
HcL9QPf/+uFitGow3zUa+jCo7M9xsh/+8kfGBajRUDlZ0Ntbrh/KqUfUB1Vo
SNK1wS1QrR/EZIKbtsvSEMu6wpMYs354QVky9tpLQzLd/I/FHvdD4SZyVBk/
DT0qnDFPsuuHZ8Thl9TtNNT8Mt4o600/PH9w9s17FhqKW9qhVRrdD06VRT+F
8P3wp23yykVSP9gIL34Q/jOItudWqtVk9EPU0R+Ca02DyOHZa2hG/fBfWFSj
KnkQqc+MSg729ANM7+ngiRhE02NoG6vQAAD97qUcrUEkWh3K5XlgAIzom37e
vziIdBPt2Tf/NwBNWYcVZ88OopIHEus75AagpLdDKFJsEH2iBU8e0BmAxyw5
qTf+DSC5nse1KoEDIOC/7KUUNoDS/nvKbx46AEeF3z7K9htAh54/N/SPGYCv
It0HWV0HEA+3y/yfrAEQ2u7FLnF/AI1hH/bYtQxA5P5DSRlHB1BobJZlPN8g
7DyYUPMrox+tWTK2bPkyCHFPdHiZqn3o6Y/VWycjBwFOKq4RDvShUTaWKN2E
QYi0vxBQvdaLWr9xysTmDwJ2UTQzJLsXpTYI3lXqGATpk9J/tYV7kcEpxRQb
QRqsHIx8lDfajcj/XK+2htFA/DT11U/tP6hV8OmSzXcatNmcVks59geNyJlG
bUmmQdnCTtXnbH/Q1hcXFs4V0CAnLyXgY3Yn0pnnCs/soMGg0v3YWe5OND4R
OOHPPwSGltUjP8lUxNcT6305YAgmtMh5blvbkDmqqip2H4aKc293ZaTXo6+m
CUL8Rn/B9/5VceNjacjqyu7SY+Z/IdNJXH9nVApSPvX+kartX/i7bFWmwpeM
Blktfzxz/QuBJAO5oxsJ6FiMpE5z1F+wvN/S9b4jGhX3534MGPgLpzVMb44n
eSLavXLOzaajIJo+UC4qGgN5F05nHLAchVuKdbdJX76D1/F4Xflno3CGTHuL
bY2DY+vv4s3fjIJUvfrbT3MJ8Dz8imrl91GYODq4YJudCpxdzS4eQ6MgXOIr
FumWA8dvDyxtmI3B34m8ynYTBOE7YcPn8Rhk2VQ5S7CUwOa6cHZB+zHQTPpt
G6NRAqMqt/lOeYzBl879MVnjJRAr0XDyYcwY2FV7j1zdXwpCzCKrht4xYNLW
DWdflgNHfMhgpO44rAaN1FrPVoG90dLYMcNx4LCP1OOUrYYhIe3Znw/GITTx
es0lx2ogB3CztNqPQ8WX+eCiTTXg9NJzH+fncfDvODRsurUW5q7a3bZtHIeH
Hzb3avPUQe+8Zj12eQImXhs3c5o3gv8e6kHb6xPwPeCnbolnIyifN3gZqTcB
tczGJ4pxjRAZaHVo49EE2IS0hLkNNILRyfeOhd4T0LVhZqeg2wQ061IxWcoE
zN27tq50phk+B192MmudAC2z8nrxG82gWtzY9Ll7Arj6Mh60WTVD7LY+p/nJ
CZh2+6D5LLoZHqSsNmdsm4Qr0Q8WfxFbYHRMxkVCcxKc/w7b2Fa1QMiOolZ9
3UkQ0B7hedjXApfkzx/1NpyEF3O5JvuWWoDkdb1t1GYSanJCUqpEW8HiiLVE
/IdJIMUGbt31shWm7idQRZongSemc9ZZsA0ifCWPa/2ZhPFDmTZmx9pAIyfX
3WVwEuiB89hmaIM0Qvnx3rlJYNW9H+lv2ga2Mf1vwnin4Ju3GXIltcFcn+AJ
gVtTsOWo2UuW/9pBxJQhs//eFNjt7Kx0O9MOmiOt8uJmUyCzUfhf2YV2SJkM
OK9gPwXGT/R2eRq3w4MVdl2DoCmwMq5X3xrcDp+daHcefpuCsMBtA34x7VDG
LDGyjZuCqQ1Px4Y0vD6Hk4V77hSwVMkUBv5uhz87517Ht03Bg3mdbMH5duAM
bnBP75mCuE21EWHr7XBGMPXdj+EpKFVhj+8hUuHzfvOPNYtTkLXILhKzhwql
MReCW9anQDLAIerQYSrMHj4Y1o1/R9YOct5+KEkFjWO9sdP80/C7Id3/OP4e
7ZReSGLsm4ZX5uYimZeokCz9NY1FbBqqJty2L2pRgVNe+8dO2WlwneiVKDai
AvlCTa2sDn5e8ztZ5zUVZqoSGsFgGgKKnnv1vqGC8NW3bZceTMPLNR/eI95U
cLyB9ek/n4YHq8O5/4KokNi2b8jUeRqmVAym34ZRgXp7ddTKcxocnZyPN0dR
QcYwb845eBrG2uM505KoYDL4ifEuAr9eGVWjlE6Fj2ZP1j7ETwP/rcN9/tlU
KBnV2BSaNg2ShDj96HwqTFse4/ieNw030w/fsC+kwl4615aU4mn4wXOuazOi
wpWnf7lzf0+Dpex/W01KcX6L5XzF9dOgzRax6liB83OIEaxsnwa29KWSW1X4
d8Kqi3Bj7zRcld1rN1dDBXaXewc7R6bhe+/749frcL6sZ8UHp6fhOukqx9MG
nO/b3ccnlqbBoZZ1960mKnzgXDq5sDENgwe7nP41UwH5tMiuc9AhO/2zpkkr
znd75lkObjoMrL9O9m3D+Qb6Y9y76BAYbZfysp0K6vxWF3bvp8O170PW/1Gp
8DLksvqBI3Rgm63kDsdx4p4jmkel6PheiktpwnF7BJv2qTN0+HM20LQGx2yi
g7cVgQ4U2+M3PXF8Kg7du6BGh0T576HsODYR/2aioUkHkUdJepfwfh+SHR/q
6tJBAfPI0MD53Nl0gdJmQAddK6N3UjhfMV3uk9oP6PBANnlLN65nNqUzqPkx
HaoUm25r43qLWGP/adnTAQTivUNwP97dtjZscKIDx5Dpr0TcrxtpcuXXPOhw
jpa07W0tFfaxEf6j+NAhf9015Hg1FUb16vzUP9GhW+/6q5jfVNynL3NVoXSQ
G59ooZVRwZndRFcthg4H1jxKZkuowJe5JKKaSQfX+eeNzwqo0MdBflv6gw4V
MkelR/OokHTXZxwrocOWqoDY//C8AKdIjlIDHXimjRT5kqmw2WB8d1E7HQRT
z3z/FU+F1uyc1wq9dHA/GvxNJoYKFoaX1c5M0UGgYaTFJ4QKp3N5U3IXcD5S
F7WtPlGBZUsvj8waHV7Vc8wK+eP5uiP/OIR9Bj6Qvmyl4d+dJzwjInW5ZkBz
d1XzmhMVBDIJzQLbZmC7rKDq8HMqDHDUywbxzYA7/CkQtaDCiywTlsCDM7Dv
HYFHW4MKd3sqpa8fmYFQ8p/zfy9S4RzncTMeiRkwq393XR2osNWAUe0vjd8/
ZhriKkWFGC7fTz4qM5Duf0U+axsVvGRmK9QvzABr/PuIKjYqPDbUWea6PAP3
Tz0VzVhtB7lckXteWjOQyM8hNT/aDvVGuWJvDWfAgbV+swa5HXJ8hPRUTWeA
41jMzrm8dvia5+JDeDgDnAXcn8xT2uH+VvUZN+sZ6FD7kVGH77t/+b0/nV/P
gKtiyK3Xj9pBjJvzmkPYDDRtu78UyoHvyxm3eK/IGVjy6t5ksNwG0s2rzJDv
MyC3/8vS9FgbQBA962fyDIRccwl5RWmD23uou1cLZ6BUT6DoYkAbeB+JH3rd
PQMtXMcSe7a0AQ+XiLJ//wzkG0wmfvvXCsHjX79EDM3AaOuJDKmxVvie6qeO
Jmfg13zdcE1FKxSdss9gWZ+B9mQtr2GnVpgGVac3+2bh1sUW77HBFrA7UNz2
6cAs2KntHhmvb4F/rHJSsYdngaNfvaC0oAWIvyUGy4/PQtB144Wljy0gcpX3
EofyLPAtUOtfKrfAjduDvO8NZqFEWXD+6IdmyLN1TfaPnIWTvUJiOrubwLtw
Jkfv+yxon940aLCpCQw5jIsPJcyCXMWtjivjjcAZrtJUkIb3C21wbClsBP1K
VsbIr1lgPLaujbrXCBv73p6D7lk44Mmm0CXXABdq33fSd88Bub/1svoOCrQe
/kS8HjgH/PJu7R3aFXDoTYv4va/z8LP/5ivjoAS4nUU4+eDbPBxhWFiKxcaD
78ApeZvoeWBVX0w9mh0Hi/D5shtpHoI69G7/a/oOv9e0LeJ+zoPK3mv7lnZG
waPn7clTnfOQrrJ5S8alj5D2qFPSWWgB0moPh7xOf4cGQ7jOvBNegN2FA2Y+
533Qrip5+CC6AJLFas/ftvkjV7FQzZijC6A+eG/afyUQXafp2/5WWIAkF9ND
TK5QtHC3O3P7nQXQb211vr/yHclr9clEhi2AO4Pop5uVgYpG2adMIhdA1bKD
N5U3Eym7HYsT+74AY5Xs39LsMpFq1kv+tKQFOCZfO5N1Ogtp8PEtFf1cgIWB
C09Ts7ORScel/D/UBXAd09/WGpGHfIyy5AX4FkGZFIg9O16Etq90zHbuWoQx
rIiN400R+vCRSfq2ZxH80g/+PNFRhIJLrwodPrgISXJ9RVfcfqGoQ3//nZJe
hOMzpite9cUoZ3RP0XWtRRiaq1e4lVSCemzfKvv5LkJlkdvKVo4yxFJSsi/m
wyLc/9r8rONYGTrEvbaW93kRPs22Zt27WYYsUp8W9ofj5++6v/wcWYaWxwzl
ZFIX4cCd16dSZMrRTlMF6a66RTg7xflK83oFks2y3zHTtAiTUc73Q59VIL1N
mTNs7Ytg7fPFKCyoAkVFHkmX7F2EOdl7pcUdFeh4N98x9+lFaGDc+vH2zm90
6Rb98H/cS3DAyiV+4kYlsow9yq7MuwQRDlt13Wwrkf+82dCNXUvgMXTvQo1f
JWr72B3jtH8JJLofqdpXViKT+ur9jVJLEJv+oFviTBV6rRYr+EJrCYKdDCkb
xGoUFdy37KO9BAlbJux+iFSj8mGhjqjbS9AgOmN6UL4abfb4GFxjtARK+4tz
tz6qRiElzrzCT5ZgZXNjwdGKapQlr7et4uMSZKjMJL+xrkGH5rzDPwctwX2O
cp5V1xoUlFQkcf/rEqQPfus99qkGOewRUSdEL8G4ic8nlFeDlNdHPFUyluDS
/NGvUf9qUEbuboEdOUvQ9tPfYXxzLTpgrR7Xn78EF0N6/KaFahFbX2qZC8Lr
S5KvHlaoRbUldizF9UtwJC2o/6p9LVJ8GR/g17wEdDuqlPmbWpR2skP4XvsS
sLVZJSl9rEWBMWeV1nqW4HiypPiulFp024PVUWFqCfqxw188emtRjaIM1+bZ
JTD2/un3ZLwWnV00C+lcWIJk+X+U3Uu1SPhBdZ7D2hJkEYcheCsFDal9mM/b
wgABfd3ma7IUpMNS6u7JzYB+ImNoG0ZBlT/md+jwMvD/7yEPr8sUlPSf7olF
IQbcCncMTb1DQXsHvVC5MANeU3zFb9+nIL/QAo3PogzQiim2+2VFQbZbhB+f
OsoAwf5h5x9OFDRYprnGKsmAjUoufQ0PCrrp5ObTfJIBuW6k45E+FCQ7NUR6
Is+ASpBnPvlKQYlxAvIqSgwISubevxBJQUIGl6p4VBgg2XX81cl4ClqvTx5J
v8QANs1X0r2ZFGT9rsfe5SoDrPjO5lzLp+Bf9tzsmlq4vgIT5FBEQTeWsc/C
2gxY4k8xNyRTUHnG04PTugxwYblfsek33v9RbNavOwyg9TyaMKyhoIQD7Sp+
hgzgE5OafVlPQd6B8kbHHjIgwCRoeaCNgtbULemrFgy4Ykr/70QnBT0mfHOu
tWbApZmXoQrdFNRbWL8t7CleL/+l6aY+CtKyY/lm8ZwBe4NLIzwGKKj0mPQx
BUcGKPLnPyinUdCpYdNCLmcG2E+ptZcMU1DstyD1TjcGaL+Z53T8S0ECOpWd
iW9x/80qhGZGKeiiYixm9p4BT/pTK/aNU9ALUbeEA34MCEv7J7plAveP02B7
7wcGcI1EafzAcce0gn3oZwbs2CtgdniSgrjadnXrhOD6xzXf3MCxQuHCOd5w
Bvx7VvYbcGwR3URqiGTAx7/3r03h58PepfH4fmfAY0LC6Ts4pjz2eXEpgQGh
wY4R7/H+azfNe9mSGbCJVSPBYYyCjitcuEBOY8D7H1ttxXG+BiKiKa+zGKBT
LCz4dYSC/DmYOxXyGCBzxLysZoiC0GTXy6WfDJD7fOnDr0EKmmn+0Z/1iwFO
GaHRT/opSORnkJoNmQH7UrMF//bgfkY+TZOoYIBmkcke4S4KcnuryT9axYBC
n5lqgQ4KyrI85hRLwfNRLHy5qRXP33UumlEjA9xMj/y61kRBvHIjl/e1MkDs
aZG6bx0FqQqXZXRSGZCtSNzlV01BceNOzjf6GNA9nMPaXkJB7Y16w9tpDDA0
LLAWxvPEkS97tXYE9y/7Z9Z/eN7M38wIqk4zIHn7nNH7FAo6uvd+7ul1Buxy
iS178pmC9FlV9s6xLMMuxUi9Nj8K8hnd9yaNbRmsTlK51z0paDKHqnVk6zLU
vfZ+/9WBgtKvXZncvWcZMsR3u2/Rw/N8Svxmm/AykLdu+vtZi4J4hNgLPoou
w8bg00aaGgU9HSl+t/noMgQb/DfRfJqCZFykD67JLYNEZaL16nYKMjPj9v6h
uAz7+5IP5rFRUPCVyRk7bBnKxoy6z/yrRYxd8cVTasuQa3hM5ONQLSrIENTv
01mG8IV3jlF5tQgGWT6W2i2D3ODzzUZatYjHZU640WEZerrOYs9VatHgnqGU
HqdlELbyunxNuhZ53KqsWvZYhk/udgvKvPh+qvJjkQpahtAR7S9yzTVIJ13I
Nix3GZYMg1h/q9Yg8atbNxJ/LgNbNtvUFukatDK67pP3axkOb+jr7dpfg8JF
BxKaKpbBcf7GvMtyNRoISugjti9DZVX0cFRiNbJyktG0W1oG3VOJE+YbVUhZ
UKzH7d8ymOzprj82WoW483ZZBmwsg7/XwxuFTVUoi/7PM4ljBS5pDwTIx1Yh
hgm5uF9gBTrO6mqUX6xC7pc1JK+dWYHOXFstQ/dK9FXAfJuYwwqoqPkri7RX
oB97ta5Mv1qBmKDre6oKK1CHqNz7PJcV0FcMvnolugLtluJkV3u3AtrvPQeG
LCtQsFri2sPgFbjSu+36Y2Y5+uwwOkHKWQHLh15Zu0TKkf8f85rjsysgbBkV
tn65FLlHPHp32uIfaJ6M03v3vQh9qw/57W+7CmE+HXXf9saivT8xQpDdKmS7
/bB1fv8dhX8fhTCHVSCWCnK+WIpBYQ5yPxNcV6G6rLkstzEafRXtSC75sAqD
J9I4RbdFoqDnuz7OZayCxbbrS/TZIOQnHHxHZ3YV7kfohVfy2KLX1p9m9j1d
g5CgeI6MgxGgXnqyp9d+DZYPiw8/2xUJuwUaqyNfrsEmY+XDGHsU5Pza+v2A
2xoM1QpWnWZEwfhWz1uHP6xB8740m9T2GLid7FBwLG0NanoCf257Ew8yo/c8
zo6vgfbwfFWjTyqwKq7Zrk2twQn+8trQ5VRoDAi992t2DTReFgrS76eB5Rmq
LKysgeRSYcYpxXSI8dQaO8e5DnLu4Wa+TzOA5/B5DXWxdZizaIjs4s6CCWPx
3Xom6yDgcjGrUzAX9K26JCwfrIN3ibT7oau5UPXcH15brMM3iYMEYedciPNZ
eBD9dB3ufJXK3jOQC4a5Jblj7usgvvL1nNz3PGjh1Lvp+H0dnp80lUjd9QPO
8W596JuwDkVhT7ULVX9Axj7kGJG8DrcvKe149uQH+EkfjinNXgcemRDR3uof
oHZ3dmZz+ToMbWAjoc9/QmH6e/+woXVwmncxs0MFcLRAMSZ1dB0yR3IrV0cK
IKScnosm18GmlyNRfHsh2Hfe6qEtrENt3tCmp3cKQYogeuwY+wYE+Mgf/zVb
CN91CqqLDm9AKa+6Mde2X7DT+HFP/X8bQNs5Y9ko+QtcLUVm+49vQPfkxqi8
1i+45+q5m112A/ehOmz+4y/YlXTj4bWLG+CoplK1zlMMPuvjbL0PNiAbcyjT
XC+GS08+VyVZbMDuV8/Wb+1CwDas5PvCegOe3xCe5zyJwJnygXfH8w2w2+it
sDNFYBsmK6r6dgNelQocNClHcJy7f5jn/QbYHDmkSelCMO7+ntTjuwFi+ZXZ
g3MITC26T7z4vAFSkmsrXDwloCPvDknfN4DPOdjn/NkS4E2VILxI2IC/49Sh
xAsl0CjS9vt88gb06b0/OaRZApc5xTV6sjZguY0vpNu0BBSpdXd5SjdA2YDz
Zuv7EhC1F3R83r8BK7e4vXrrSqBvtFTp/NAGdDFcdWLaSiD8rtUmnlG8f3g4
t2JPCfCrIi8SfQNej/y8OjtRApy8Zl+6Nzagd/vHm6ZEMlR4br9DYmWChemv
tvZtZHD/ly/8nIMJz34vGYvwkWF1YHM893YmbAmXTT8tQobpjIycc/uYsL6B
Gh7JkiH5kL4D9wEm1PwNu+F/lgzmIQTF7kNM0L8oK/AeI8OAi06Z/TEmWPI1
uW1SJ0PEPNPz3AkmJD6rOeuiQQb9hyR1bhkmlCY+02+5QYZWjbWmxLNMWLRP
ntrQJ8PH0rgge2CCBA/Hi3YDMmjIauqdO8+EWGaCv4cJGSr3xfR3qeP9faWD
7z8ig8fHK7GJGkx4Mpv5LdiKDBj74kP7G0zYlB5nEmlDhoJJNfp2fSZMRwzp
nrYng6x/uHfVPSbwyxoczXtBhiyp2cPuxkxovxfuxe1IBsmmC+SzZkyg+ra4
qDiRgfQ09O6iOROk7bz2XXUmwyE+OiPNiglvigJspFzJEJV7/pO5LRP0Srd5
TLiRYa9uiKSoHRNEbzx/5PqGDCHLk9VdL5jw1dRXctqDDHyhKmZBr5jg0mo8
KONJhg9ng1k0XZgwKar7WfsdGbb2jIdxvmEC15E92te8yPDOGc6UejLhJCXp
5P73ZGAV+dz8ypsJ4dVaSjU4diaPPj7tz4Sn+nHvNLzJ8M9EiYv+kQmmi34H
UnD8nC0wNjEI94+gtJeG47m4ETD5ygTHLyffz+PYWu1s155vTJATPePYg+Px
0YDnbVFMSP3PbFM0js28h3YExDJh97rwSWUc90vIp15KZEL8I969uXj/u3V+
l1hTmHDVWrGNHccd1oO0wnQmAL3X5gTOX5vnjIt9NhN6zL2ZMri+xkwfIal8
vF7M7hBeXP/Vm/25owVMMDJIvUbB/alakLkeU8yEfdx5Moa4f6rB7yfvlDIh
0GPMmIL7W3Km9x3/bybci1Ab58X9V+yUPthQjed3dTftND6fU3u79c41MeFV
a7QTFz7PtF8nFldbmXDA7ublQnzeRw3ffsjtwOuvWvaq4XkQjZGsFO9ngiqz
vWgWz0vE+TcmgzQmuPbeleF+TAahYep62F8mHCtNbyRakGGnuJsMN50JLBxi
VG9TMvhXtzVUzTFBMzj5Cb8RGTZbHrV0X8Lz2U/++OouGTaltUQvruP9ePV+
/9Emw7LgJ6I1BwumtYev5u95MuRZKLWpc7JgEqH7b18HMtgV/o05spkFa9Xi
UPiiQIaZu4rKA9tYsDO+jmY/TpDhb+SwnTY/CzaiWn/v5h4yxM4EnDu5iwW7
FZ7jE8NPBhMVBZ7tgizYydSTk/XcZOgd9E+u3MuCsfFz/kQEMrQflhtUOMSC
xTAfFbGNl8BQk9V5TIwFc8m9R04eLIG519GxF8RZsD7hP3+PdpUAd/vmh1rH
WDDW8ewzWbUlcMmzZ8JMhgXTvV17aSypBApG3Bc/qLJga8/CH+wzKYGqwHyd
4IssWOSJq/l6t0ugXXkyP+wSC8ZRU/3bVqME5oNvOcZfZcFshtdapBRK4Jia
OLNQmwWr1a7/tMRdApEJdZx/77NgovJOE98eIUi7yWox+QDXv5Mu//U6giKm
bO2sOQvWrKLUqimPoEM3ym/NigV72HL76QwRwU7OZzt32rNgd/YHC26OKQYP
8917ld6yYKt2JMpS9S8w/89U6lMcC5a2o2fee6IQhDd/GrVPYMEmuYQXOuoK
oWW8NPo2iQU7MfveYSm9EJRTRPmEU1mw/NDtz6OfFQKv1OByYg4Lpv9ISoK8
XADFMsalxWUs2OBfEY8X/34CH2Z4a3yABXtMPpNypTcfyDp3XqkIb8I6rgnN
uStmw6nb4yS+6E0YbyO1108hCqzeXKQq7WHFdITULmytckPL3k1/9+5jxaDQ
8orrqjt6G3h3eVWYFWv01whTkPRAEdFPBQtEWbEShnKXw0dP1Igi7sgeZcUq
QgurujR80Km1pT5JeVZsZ8a1iejrgeifXcLofl1WLGTLLSi8HoY8naRXNm6z
Yr/VX8bm94QhXo9fXL36rFhuuc2szKNwdOxTy9FwA1Zsr8dNwzTnb8ggk2m1
+wErdhawJLfvkYg8pTvLY8+KRSXx8k+ORSOvB5z/Nn1ixaqkKr3eDsUhs+p9
EVxBrJgXrXfxj1g8Onfs1LkdX1ix5sY4gTbzeLQ6e89bJIwVu8H71jl3Ih5Z
v84Wgu+smLvWDwfBqQR067PBWadsVmxyJ4s3Ry8JSTOe9b3JZcXSW0f+WQsl
oe3679/45LNidEVWqp1OEqran1MbWojrSRoT161LQorJXHd/lrFixl+xfou8
ZCRamuO01MKKfSZ7Eh3sUxHzUI3IRhsrxjlO4PBKTkXd7/rK2TtYMbHwXQZS
A6ko+NrmbfzdrBhqLyKfu5KGuDoNv50aYsUC+7wkngmloxn65mLbBdxf9ZQo
/RsZ6Nc+Y+Y4HwFroTc3WmRnIiz3yWqDAAETvU7ELv/OROVX3Rk5uwmYe9zh
p0sdmYjy6jvdeS8BU/QyaClaz0TdncN9Ow8RsBKZwY8M1Sy0FmRRonCKgMFd
aq1ATRZyPf6qaP9pAmb6JdO9szMLsVX4/GA7Q8AM6VxsFmNZaOtCSka9AgEr
VH4jt0DMRntv0KNMzhEwm6dt51LOZaOz2+3cvK8TsK198zLf07JRcZzHa5ub
BOz0QUkp5cJsdE4p6KX2LQImXTv7NL4yG6lb5T0R1iNgF0VWfvf2ZSP9mmXj
LCMCduV34+XpbTmo15jL4IsJrvf22On53TnIZEVQ3+k+AVuOPKpbcTAHWYif
vXHRnICpG30+0ySXgxw9X5/7Y0PALrjIOL8zykEb+/yV0RMC5mn9RXjpUQ5y
z41QiH1GwDp0k9ZOPstB3kNI2voFAXsUEeW8420OCj3HepDVBedj0r/FNj4H
Cf/Zuf+vKwG7GpvLeTktB8U8ObiH4k7ATgXJmdNzc1BSlCpvsCcB22EpbBFb
noN+bngSjvoTMInl2GsZfTnIf/bApzMfCJiIzjPJlyM4/6Ei0QuBBOwNh84k
x1QO2lwzp2IUjGNT81NPVnC9RX5Nj0MIWKvr7o5rzByUnS5u/CqUgNlOd3+g
s+Wiu0EGrsERuB7lnU7u3LnohNcKd2wUAcujpNU/48tFbK8+R2bGEDArvjz7
o4K5KNWoppgST8CCX+QRRw/kIvebZhp/EvE8fHmxi344F+lcZOn9m0TA1Fyl
Kwr/y0UbErLrrOkEzKPBQj3+RC5qFm7y5ckkYA6bla6Un8pFCTus9gpn4/PP
zVRMlM1FTmzEFIlcAjZ9pkvmhnwu0mJEn5XPJ2C8XHfUS8/mokPjirUXfxIw
1uPGn5eVctFyN1VfuxCvn5J8dBFyEaXh6bjxL9zfbZ6Hf6jkoujSbY42iIBl
V1V9Uzmfi57nJnK9JhMwHXJHykfVXKSeeP6rdxkBs8yPt0q8kIuEw3rFQyoI
2KaiNMbbi7lozu/lj7hKAvYvhmF+VC0X/Xblu5RdjV+329kdhOOwZ+nUkloC
JvdH8HEVjm0fqD+sryNg9YGZcqU4VtUbXupqIGCv/rDffYPj3VddPceaCFhl
Z83CFhxPKu8RYLQQMA0exQN38X4lJ/Pi2Nrx88V7WOxwPkGHrp/e2UHAxLWy
Mm7ifC12TZbv/4PnmVx3Y/VcLlLe/E77eDcBY+Mkc1jieneuHxhS6CVgBQ6m
UzG4HyP0omeX+gnYHgke8e+4XwWDugSdQQJWfC+uwxL3M6BtLtB0iICROt4c
WJfLRfer/ESfjBCwAQ3/w7r4POQKxbOcRwnYcLE4pyM+r61pZSq+4wRMqPnM
lBk+z/4og6avkwTs2lmRFaHjuei95+eZnBkCJiPvKziA58HgpZRr6Rye//ib
L+fwvEhb1XA3LhCwuQbH4Lp9uejPdRapiWUC5hzdFDuA5y1NNax4+R8B486U
GBbiyUVvzshqcKwTsOp/cm7CW3LRsX1Wjw9sYsOW8jhs37LkIhYe4rokgQ2r
J5Txj/3LQa2sMb6K7GyYwYj4r12LOej1KDVZl4sN+6HAU9Q+moPqs8+P++1g
w26fXlXpr8OfX6Wc4Y+8bBgX7/VNZb9zkGzloYEgfjZMTb6fxQ7loIg/7B3f
BNmwW6/VbVUyctDjTVUVqQfYsOEV/wX/gBwk4iNHzjzIhr3xYf8y6on35yMV
5R5mw1JfudJ2OOcgRXHv7F//sWHY51XZVssctFXzanTdSTYsoZ+dfd+FHFTS
URTedAq/HtN5ckUhB9mZHA9pO82GxZrG+MSfyEHd9tsDeuTZMHOffH/7PTko
ObzRaUqFDcsyXTQdn8b33bj27W032LAAJR3mXb9stPGs4uYObTZsIsBa6b5r
NspaP63Jr8OGXfTUXYBn2Uhox66L+/TZsHfj7sn2t7PR2JnOU8dN2LB9DeGP
+kWykdfbe9zXnrJhuzPDnYdJWahC5MFv30A2zCl/SkcrIhOJ9DUJWn9mwy71
CDr6+2Uix29KjzWD2TDBlJMXU50y0Qkhfr6doWzYoXrWZD/9TBTOW278JZoN
c8tbetzHl4nsOETXozPYsAtbn4ctvslAhyZ7TuXXs2H0fQEWbaFpyCP/VvTA
ZnZsWX4He8IpEjrRdMVrYis7VhCW5MDKSkJd4yo2i9vZsSeJNZ6nGxORtLCk
EhcvO9attr/xkFUi6vPg6Dyxhx3jDruYLBeTgBRu5PO4SrBjt1MZ5gXEeDQz
udtV+Co7phmcYq5ZFIPuinYb3PFjx6JgdG9v5xe0mie1R4LIgX2THsyuntcB
yfClCk4uDoxe1XJYZOQuGLn9sh3ZzIGB0qvyHxbGUH7lyu/o7RxYXoroFctb
D8G3/8GT3QIcmIlMY2KnzxPYuzmikv0wB5bglupnefg1KN7batd/jgO75CW0
HWt6D9bnWoSLVTmwnsV3EmWu3hB1JLQ67CIHNjAWJ1kg5QNsc0f266pzYE8K
sLENH1+geJ6vqbvOgY3W8aWUKAXA3QxHkUIjDuxrxvp3n3OB4EQYowQ5c2Ah
8Zprrte+wMZ5hS3hrhxYiljoxaXoL+Dm4XM5xp0D09hvnkxY+gKe7JK/0zw5
MPmmlyeHwkMggPgMVfpzYC4rgS+Shr9CzJb1zJUI/P6ZJ2WlJuFQzbvjyz2E
6w2Rqfn4Jgquapu0mZI5MPG2zt+F8VFQ/zmb16KMA+uKFO9NrI6CZn6dD88r
ObBPDiPWtdujoXtX2PuABg7MLPkAWSI4Gmb2HHYi93Fgiz0/qeJfY0DgkLzx
YRYi9rt28tpP61jAvr5lcLISsfw1yZCdXrHwaHuz3ySBiL+fSUefjI6FomWL
gmwiEXtyxeZVSXMsmNSF857jJmJOxjtVhU/FQdpzlt8GwkRs2trwW9loHHRM
XL17ToSIhVwOeGC1EQebjL/OHRYlYt8stxh18saD9hXp/VOHiVjL+J7PTKV4
+Lf/vsOr40SMceXbrGNAPFysrjwaokjE4kr6B4WPJICtMh/5lTIRU6Nec2OV
T4Cv2Ua6hhgR2xnIe4OkngCT31beiKkSMfGQMgPscQIEPpXoyblCxCivAng+
pSdA0d8Xz0KuEbErWdn/BaAEGL5bzuWkScQeubRIaDQkgJzaPdnzN4mY56HO
Rr7pBOjdExDQpE/Ect76sZeLJwLnx67DuXeJWGKCSk27bCKc5BAvCjEgYs0b
3ddTVBPBY6Zk1NCEiG1/dCA60jARjlbMqUw/ImJcLWkHEgITQVsBOposidgz
+5CuhohEeJ3uY537mIi5fJG8VZiUCI1fD4U5PSFifU9YPvwhJ8ILa52FzS+J
mPkdH2eFqUTYK3u/SuwVEWunS8bGLydCyfqT8HOvidjsz5Zvvwkk2Oznp+ro
RsT2gMlJUUESpGuH7Q5+Q8RypV/03TtIAu29pMnMt0RM5cfg+2vHSRCRXP55
7D1+3obAfhkjwflnzebsvkRsX5LRjPZlEowq9Cse8CdiHcam2/hvkEC6ZnXo
diARs5hxEcoyIcHvUenTVaFE7I1qrZGxKwksMzCuoXAi9vepeTbPOxLwOGj0
MCOI2Hej6Co7PxLoEy3envlOxJSa9APvfCUBs/6F3s04InZP0suuN4IEscFv
j9skELH+FJKdQCwJpg5Ht8UnE7HHYfHS8akkCJxKI5WmEjHd2ruHNjJJIJtb
9Lo3nYhFnC0M25JHgi6nmuv/MomYiXhITv1PEriqdhwWyCFi//H7+qj9IsHh
rSMrJ/OImI7ArNLzEhLUtMzXXftBxEJ3D47pl5HAJmxTzKMCnL+YQtpiBQn4
TLmfvy0iYuFpn5IuVpHg59F96tHFRIxKVmNeqyGBwdxR4V8lREz+9uO6LRQS
EArk5jpKidi6X4esax0JEt0u/l4oJ2IyA4IGyfUkuHZZO5Snkoh9evz6gV8D
CeZ4TKyPVRMxQ7HNdmKNJAjusDl3qRaf73a35Oc4Phv1WuB+HRHb9uSutDOO
+x/6jLs0ELHhnQ2SSjj2kPpaHNZExFIelVVm4/X+Y8QH5rfgeaP8OTSI96sv
znnQ0kbE9GKsrKtwPs88SxXoVCJmFvS27gHOd7dG4/Ytf4hYduGI5S9czy/+
3kGxbiImWMFmR8H1mvRM5J3rxZ/nQ8Qdn3+TgBi34m3QT8TSFCqt+cpJkGJF
NHQcJGJsLxt+XiOT4LoM/6ngIXw/+Ojvx4pJsLQqSswawbHjjbqJAhKElZ3o
qhslYjz1mnNa+STAfJTTx8Zxf9JDftlkk8BbSF/3AJ2IeUR4ELuSSCA1+FBC
aZaIMeV4Ro/Ek6CVZM+8PU/EZjLzpKWiSSAs/zHhA4OIvSi0bXocTIIylshX
KStE7J1+nm/cBxKYV6VoVq0SMU3Rl64h3iTY+qHg4NA6EVupmx246EGCTN0q
BpNJxAby10cyXpPgf+mfKj4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["\[CapitalDelta]\[Rho]", TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 3}, {-1, 1.15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic},
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.575547441618775*^9, {3.5865828771124773`*^9, 3.5865828983210864`*^9}, 
   3.587548283603587*^9, 3.5875543263516283`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 15.7 Viscous attenuation in air and water (p. 259)\
\>", "Section",
 CellChangeTimes->{{3.502102993215742*^9, 3.5021030059514704`*^9}, {
  3.587553924421405*^9, 3.5875539285328965`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CleanGlobal", "[", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(3\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{{3.5755474419038076`*^9, 3.5755474601689987`*^9}, 
   3.575547573548602*^9, {3.5865828774205027`*^9, 3.5865828984901505`*^9}, 
   3.5875482838776197`*^9, 3.5875543267126713`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5875539501664915`*^9, 3.5875539513956385`*^9}, {
  3.5875540176225863`*^9, 3.587554019396798*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1.8", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "5"}]]}], " ", ",", 
      RowBox[{"1.0", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]]}]}], "}"}], "Pascal", " ", "Second"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"viscosities", " ", "of", " ", "air", " ", "and", " ", "water"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Zeta]", "=", "\[Eta]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["c", "0"], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"343.", ",", "1500."}], "}"}], " ", 
    RowBox[{"Meter", "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"sound", " ", "velocities"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1.2", ",", "1000"}], "}"}], " ", 
    RowBox[{"Kilogram", "/", 
     SuperscriptBox["Meter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", "densities", " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{
    RowBox[{"10", " ", "Megahertz"}], "//", "ToSI"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]", "=", 
   RowBox[{"2", "\[Pi]", " ", "\[Nu]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4296932417449794`*^9, 3.4296932538089795`*^9}, {
   3.4296939662719793`*^9, 3.4296939694709797`*^9}, {3.5021031209960504`*^9, 
   3.5021031218601*^9}, 3.5021031740110826`*^9, {3.502103746516828*^9, 
   3.502103795164611*^9}, {3.575547455472436*^9, 3.575547456032502*^9}, {
   3.587553965544338*^9, 3.587554013262063*^9}, {3.5875541602066946`*^9, 
   3.5875542180636377`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5875540304861326`*^9, 3.5875540313802357`*^9}}],

Cell["Base frequency", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Omega]", "0"], "=", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      SubscriptBox["c", "0"], "2"], 
     SubscriptBox["\[Rho]", "0"]}], 
    RowBox[{"\[Zeta]", "+", 
     RowBox[{
      FractionBox["4", "3"], "\[Eta]"}]}]], "//", "ToSI"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"3.361399999999999`*^9"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{"\"per \"", "\[InvisibleSpace]", "\"second\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: reciprocal seconds"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["1", "\"Seconds\""]}], "]"}]& )], ",", 
   TemplateBox[{"9.642857142857144`*^11"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{"\"per \"", "\[InvisibleSpace]", "\"second\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: reciprocal seconds"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["1", "\"Seconds\""]}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{{3.575547442669901*^9, 3.575547460832079*^9}, 
   3.575547574210682*^9, {3.5865828779655495`*^9, 3.58658289880916*^9}, 
   3.587548284529698*^9, 3.5875542522447367`*^9, 3.587554327677788*^9}]
}, Open  ]],

Cell["Decay parameter", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Kappa]", "=", 
  FractionBox[
   SuperscriptBox["\[Omega]", "2"], 
   RowBox[{"2", 
    SubscriptBox["\[Omega]", "0"], 
    SubscriptBox["c", "0"]}]]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"1712.0459840832943`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{"\"per \"", "\[InvisibleSpace]", "\"meter\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: reciprocal meters"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["1", "\"Meters\""]}], "]"}]& )], ",", 
   TemplateBox[{"1.3646860406444543`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", 
            RowBox[{"\"per \"", "\[InvisibleSpace]", "\"meter\""}]}], 
          "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
      "Unit: reciprocal meters"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", 
         FractionBox["1", "\"Meters\""]}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{{3.575547442908928*^9, 3.575547461026103*^9}, 
   3.575547574405705*^9, {3.5865828780925875`*^9, 3.5865828989041624`*^9}, 
   3.5875482847547255`*^9, 3.5875542526117806`*^9, 3.587554328149844*^9}]
}, Open  ]],

Cell["Attenuation length", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "\[Kappa]"], "//", 
  RowBox[{"ToUnit", "[", "Millimeter", "]"}]}]], "Input",
 CellChangeTimes->{{3.502103132363701*^9, 3.5021031343558145`*^9}, 
   3.5021035520917077`*^9, {3.5021038100194607`*^9, 3.502103811921569*^9}, {
   3.5755475596159325`*^9, 3.5755475660257015`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"0.5840964607825323`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: millimeters"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )], ",", 
   TemplateBox[{"732.7692745561928`"},
    "QuantityUnit",
    DisplayFunction->(TooltipBox[
      StyleBox[
       RowBox[{#, "\[InvisibleSpace]", 
         StyleBox[
          RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
       ShowStringCharacters -> False], "Unit: millimeters"]& ),
    InterpretationFunction->(RowBox[{"Quantity", "[", 
       RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{{3.575547443131955*^9, 3.5755474610701065`*^9}, {
   3.575547566610771*^9, 3.575547574457713*^9}, {3.5865828781565933`*^9, 
   3.586582898928161*^9}, 3.5875482848117323`*^9, 3.5875542526777897`*^9, 
   3.5875543283968763`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1069, 902},
WindowMargins->{{68, Automatic}, {Automatic, 18}},
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 246, 4, 65, "Title",
 InitializationCell->True],
Cell[1734, 41, 167, 4, 41, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[1938, 50, 276, 5, 65, "Title"],
Cell[CellGroupData[{
Cell[2239, 59, 271, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[2535, 68, 127, 2, 41, "Input"],
Cell[2665, 72, 483, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3185, 87, 100, 1, 36, "Subsection"],
Cell[3288, 90, 578, 15, 102, "Input"],
Cell[3869, 107, 139, 3, 30, "Text"],
Cell[4011, 112, 1126, 28, 82, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5174, 145, 142, 2, 36, "Subsection"],
Cell[5319, 149, 105, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[5449, 154, 364, 7, 56, "Input"],
Cell[5816, 163, 6997, 166, 65, "Output"]
}, Open  ]],
Cell[12828, 332, 104, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[12957, 337, 336, 7, 45, "Input"],
Cell[13296, 346, 4862, 125, 41, "Output"]
}, Open  ]],
Cell[18173, 474, 91, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18289, 479, 218, 6, 55, "Input"],
Cell[18510, 487, 5405, 140, 65, "Output"]
}, Open  ]],
Cell[23930, 630, 211, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[24166, 637, 389, 8, 56, "Input"],
Cell[24558, 647, 3712, 87, 41, "Output"]
}, Open  ]],
Cell[28285, 737, 100, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[28410, 742, 354, 9, 78, "Input"],
Cell[28767, 753, 3740, 87, 41, "Output"]
}, Open  ]],
Cell[32522, 843, 96, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[32643, 848, 449, 11, 41, "Input"],
Cell[33095, 861, 1646, 31, 156, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34814, 900, 192, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[35031, 908, 152, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[35208, 916, 59, 1, 41, "Input"],
Cell[35270, 919, 510, 11, 21, "Message"]
}, Open  ]],
Cell[35795, 933, 26, 0, 30, "Text"],
Cell[35824, 935, 1575, 43, 145, "Input"],
Cell[37402, 980, 121, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[37548, 986, 233, 7, 58, "Input"],
Cell[37784, 995, 745, 15, 41, "Output"]
}, Open  ]],
Cell[38544, 1013, 39, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[38608, 1017, 224, 6, 58, "Input"],
Cell[38835, 1025, 724, 15, 41, "Output"]
}, Open  ]],
Cell[39574, 1043, 31, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[39630, 1047, 170, 5, 59, "Input"],
Cell[39803, 1054, 357, 5, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40209, 1065, 165, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[40399, 1071, 77, 2, 41, "Input"],
Cell[40479, 1075, 386, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40902, 1090, 75, 1, 36, "Subsection"],
Cell[40980, 1093, 1093, 30, 86, "Input"],
Cell[42076, 1125, 976, 25, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43089, 1155, 174, 2, 36, "Subsection"],
Cell[43266, 1159, 42, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[43333, 1163, 296, 10, 102, "Input"],
Cell[43632, 1175, 1117, 26, 41, "Output"]
}, Open  ]],
Cell[44764, 1204, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[44890, 1209, 259, 6, 56, "Input"],
Cell[45152, 1217, 1129, 26, 41, "Output"]
}, Open  ]],
Cell[46296, 1246, 41, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[46362, 1250, 127, 4, 54, "Input"],
Cell[46492, 1256, 1432, 37, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47985, 1300, 166, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[48176, 1306, 77, 2, 41, "Input"],
Cell[48256, 1310, 509, 11, 21, "Message"]
}, Open  ]],
Cell[48780, 1324, 302, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[49107, 1335, 848, 29, 110, "Input"],
Cell[49958, 1366, 342, 5, 41, "Output"]
}, Open  ]],
Cell[50315, 1374, 410, 11, 30, "Text"],
Cell[CellGroupData[{
Cell[50750, 1389, 1564, 36, 82, "Input"],
Cell[52317, 1427, 515, 10, 21, "Message"],
Cell[52835, 1439, 6594, 118, 260, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59478, 1563, 165, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[59668, 1569, 77, 2, 41, "Input"],
Cell[59748, 1573, 411, 10, 21, "Message"]
}, Open  ]],
Cell[60174, 1586, 73, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[60272, 1590, 1152, 36, 88, "Input"],
Cell[61427, 1628, 254, 4, 41, "Output"]
}, Open  ]],
Cell[61696, 1635, 128, 3, 30, "Text"],
Cell[61827, 1640, 260, 7, 41, "Input"],
Cell[62090, 1649, 50, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[62165, 1653, 1396, 34, 62, "Input"],
Cell[63564, 1689, 384, 8, 21, "Message"],
Cell[63951, 1699, 48598, 809, 260, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[112598, 2514, 189, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[112812, 2522, 77, 2, 41, "Input"],
Cell[112892, 2526, 431, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113360, 2541, 151, 2, 36, "Subsection"],
Cell[113514, 2545, 112, 1, 30, "Text"],
Cell[113629, 2548, 572, 17, 84, "Input"],
Cell[114204, 2567, 293, 8, 41, "Input"],
Cell[114500, 2577, 475, 14, 41, "Input"],
Cell[CellGroupData[{
Cell[115000, 2595, 271, 6, 41, "Input"],
Cell[115274, 2603, 538, 13, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[115861, 2622, 98, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[115984, 2627, 670, 17, 65, "Input"],
Cell[116657, 2646, 298, 6, 54, "Output"]
}, Open  ]],
Cell[116970, 2655, 29, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[117024, 2659, 103, 3, 41, "Input"],
Cell[117130, 2664, 302, 7, 61, "Output"]
}, Open  ]],
Cell[117447, 2674, 162, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[117634, 2680, 235, 6, 41, "Input"],
Cell[117872, 2688, 577, 15, 59, "Output"]
}, Open  ]],
Cell[118464, 2706, 112, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[118601, 2711, 294, 7, 41, "Input"],
Cell[118898, 2720, 848, 25, 66, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[119795, 2751, 26, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[119846, 2755, 1956, 42, 62, "Input"],
Cell[121805, 2799, 4011, 77, 268, "Output"]
}, Open  ]],
Cell[125831, 2879, 148, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[126004, 2885, 368, 10, 41, "Input"],
Cell[126375, 2897, 269, 4, 41, "Output"]
}, Open  ]],
Cell[126659, 2904, 100, 1, 30, "Text"],
Cell[126762, 2907, 142, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[126929, 2914, 1936, 44, 62, "Input"],
Cell[128868, 2960, 592, 11, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129497, 2976, 1109, 20, 62, "Input"],
Cell[130609, 2998, 385, 8, 21, "Message"],
Cell[130997, 3008, 4352, 83, 268, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[135422, 3099, 186, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[135633, 3107, 227, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[135885, 3116, 77, 2, 41, "Input"],
Cell[135965, 3120, 387, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136389, 3135, 77, 1, 36, "Subsection"],
Cell[136469, 3138, 1000, 32, 125, "Input"],
Cell[137472, 3172, 32, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[137529, 3176, 124, 4, 56, "Input"],
Cell[137656, 3182, 771, 18, 41, "Output"]
}, Open  ]],
Cell[138442, 3203, 31, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[138498, 3207, 144, 4, 56, "Input"],
Cell[138645, 3213, 331, 7, 41, "Output"]
}, Open  ]],
Cell[138991, 3223, 93, 1, 30, "Text"],
Cell[139087, 3226, 212, 7, 43, "Input"],
Cell[CellGroupData[{
Cell[139324, 3237, 124, 4, 56, "Input"],
Cell[139451, 3243, 776, 18, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140264, 3266, 144, 4, 56, "Input"],
Cell[140411, 3272, 266, 4, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[140738, 3283, 230, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[140993, 3292, 127, 2, 41, "Input"],
Cell[141123, 3296, 394, 10, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141554, 3311, 102, 1, 36, "Subsection"],
Cell[141659, 3314, 2213, 58, 187, "Input"],
Cell[CellGroupData[{
Cell[143897, 3376, 273, 7, 58, "Input"],
Cell[144173, 3385, 593, 11, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144803, 3401, 395, 10, 41, "Input"],
Cell[145201, 3413, 1727, 34, 270, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146989, 3454, 189, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[147203, 3462, 77, 2, 41, "Input"],
Cell[147283, 3466, 489, 11, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147809, 3482, 147, 2, 36, "Subsection"],
Cell[147959, 3486, 1213, 35, 84, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149209, 3526, 97, 1, 36, "Subsection"],
Cell[149309, 3529, 83, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[149417, 3534, 144, 5, 41, "Input"],
Cell[149564, 3541, 1508, 38, 41, "Output"]
}, Open  ]],
Cell[151087, 3582, 31, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[151143, 3586, 144, 4, 56, "Input"],
Cell[151290, 3592, 401, 8, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[151764, 3608, 209, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[151998, 3616, 127, 1, 75, "Section"],
Cell[CellGroupData[{
Cell[152150, 3621, 77, 2, 41, "Input"],
Cell[152230, 3625, 344, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152611, 3639, 98, 1, 36, "Subsection"],
Cell[152712, 3642, 33, 0, 30, "Text"],
Cell[152748, 3644, 426, 12, 41, "Input"],
Cell[153177, 3658, 34, 0, 30, "Text"],
Cell[153214, 3660, 691, 22, 58, "Input"],
Cell[153908, 3684, 31, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[153964, 3688, 670, 21, 41, "Input"],
Cell[154637, 3711, 1318, 40, 61, "Output"]
}, Open  ]],
Cell[155970, 3754, 39, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[156034, 3758, 832, 26, 43, "Input"],
Cell[156869, 3786, 946, 30, 61, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[157876, 3823, 160, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[158061, 3829, 77, 2, 41, "Input"],
Cell[158141, 3833, 340, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158518, 3847, 1116, 28, 62, "Input"],
Cell[159637, 3877, 308, 7, 21, "Message"],
Cell[159948, 3886, 18983, 320, 258, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[178980, 4212, 204, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[179209, 4220, 77, 2, 41, "Input"],
Cell[179289, 4224, 393, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179719, 4238, 153, 2, 36, "Subsection"],
Cell[179875, 4242, 1786, 50, 147, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181698, 4297, 99, 1, 36, "Subsection"],
Cell[181800, 4300, 30, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[181855, 4304, 312, 11, 68, "Input"],
Cell[182170, 4317, 1311, 31, 43, "Output"]
}, Open  ]],
Cell[183496, 4351, 31, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[183552, 4355, 188, 6, 61, "Input"],
Cell[183743, 4363, 1305, 31, 41, "Output"]
}, Open  ]],
Cell[185063, 4397, 34, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[185122, 4401, 318, 6, 56, "Input"],
Cell[185443, 4409, 1138, 26, 73, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature uxDj3h7B#@T7SBguT7lN0uAn *)
